@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-  
+
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -28,7 +28,8 @@
 #include "mod-udp-internal.h"
 
 char *
-_mod_udp_repr (_udp_context_t * udp_context, lw6cnx_connection_t * connection)
+_mod_udp_repr (_mod_udp_context_t * udp_context,
+	       lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
