@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-  
+
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -34,11 +34,11 @@
  * try and identify the objects in their on per-process lists,
  * structures, Guile object, whatever they use.
  */
-static u_int32_t seq_id = 0;
+static volatile u_int32_t seq_id = 0;
 
 /**
  * lw6dsp_create_backend
- * 
+ *
  * @argc: argc as passed to @main
  * @argv: argv as passed to @main
  * @gfx_backend_name: the id/name of the gfx backend to use
@@ -110,7 +110,7 @@ lw6dsp_create_backend (int argc, const char *argv[],
 
 /**
  * lw6dsp_destroy_backend
- * 
+ *
  * @dsp_backend: the dsp_backend object to free
  *
  * Frees all ressources used by a dsp_backend object. Note that you must
@@ -164,7 +164,7 @@ lw6dsp_destroy_backend (lw6dsp_backend_t * dsp_backend)
  * Return value: a newly allocated string, must be freed.
  */
 char *
-lw6dsp_repr (lw6dsp_backend_t * dsp_backend)
+lw6dsp_repr (const lw6dsp_backend_t * dsp_backend)
 {
   char *ret = NULL;
   _lw6dsp_data_t *data = NULL;
@@ -207,7 +207,7 @@ lw6dsp_repr (lw6dsp_backend_t * dsp_backend)
  * Return value: 1 if success, 0 if error.
  */
 int
-lw6dsp_init (lw6dsp_backend_t * dsp_backend, lw6dsp_param_t * param,
+lw6dsp_init (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param,
 	     lw6gui_resize_callback_func_t resize_callback)
 {
   int ret = 0;
@@ -347,7 +347,7 @@ lw6dsp_quit (lw6dsp_backend_t * dsp_backend)
  * Return value: 1 if success, 0 if error.
  */
 int
-lw6dsp_update (lw6dsp_backend_t * dsp_backend, lw6dsp_param_t * param)
+lw6dsp_update (lw6dsp_backend_t * dsp_backend, const lw6dsp_param_t * param)
 {
   int ret = 1;
   _lw6dsp_data_t *data = NULL;
@@ -375,7 +375,7 @@ lw6dsp_update (lw6dsp_backend_t * dsp_backend, lw6dsp_param_t * param)
 			  _x_
 			  ("calling display_update too often, no frame drawn between two calls"));
 	      /*
-	       * We go idle for a very short time, this will just avoid the 
+	       * We go idle for a very short time, this will just avoid the
 	       * caller to get stuck in 100% CPU greedy loops.
 	       */
 	      lw6sys_idle ();
