@@ -364,8 +364,8 @@ void
 _mod_gl1_hud_floating_display_hud (mod_gl1_utils_context_t * utils_context,
 				   _mod_gl1_hud_floating_context_t *
 				   floating_context,
-				   lw6gui_look_t * look,
-				   lw6ker_game_state_t * game_state,
+				   const lw6gui_look_t * look,
+				   const lw6ker_game_state_t * game_state,
 				   lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl1_hud_floating_context_begin_hud (utils_context, floating_context);
@@ -380,8 +380,8 @@ _mod_gl1_hud_floating_display_hud (mod_gl1_utils_context_t * utils_context,
 void
 mod_gl1_hud_floating_display_hud (mod_gl1_utils_context_t * utils_context,
 				  void *hud_context,
-				  lw6gui_look_t * look,
-				  lw6ker_game_state_t * game_state,
+				  const lw6gui_look_t * look,
+				  const lw6ker_game_state_t * game_state,
 				  lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl1_hud_floating_display_hud (utils_context,
@@ -556,8 +556,8 @@ void
 _mod_gl1_hud_floating_display_score (mod_gl1_utils_context_t * utils_context,
 				     _mod_gl1_hud_floating_context_t *
 				     floating_context,
-				     lw6gui_look_t * look,
-				     lw6ker_game_state_t * game_state,
+				     const lw6gui_look_t * look,
+				     const lw6ker_game_state_t * game_state,
 				     lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl1_hud_floating_context_begin_score (utils_context, floating_context);
@@ -573,8 +573,8 @@ _mod_gl1_hud_floating_display_score (mod_gl1_utils_context_t * utils_context,
 void
 mod_gl1_hud_floating_display_score (mod_gl1_utils_context_t * utils_context,
 				    void *hud_context,
-				    lw6gui_look_t * look,
-				    lw6ker_game_state_t * game_state,
+				    const lw6gui_look_t * look,
+				    const lw6ker_game_state_t * game_state,
 				    lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl1_hud_floating_display_score (utils_context,
