@@ -33,7 +33,7 @@
  * Theorically, there could be a race condition if several threads used
  * this, in practice, very rare, and, moreover, few consequences.
  */
-static u_int32_t seq_id = 0;
+static volatile u_int32_t seq_id = 0;
 
 /**
  * lw6gui_menu_new
@@ -53,8 +53,8 @@ static u_int32_t seq_id = 0;
  * Return value: a pointer to the newly allocated object.
  */
 lw6gui_menu_t *
-lw6gui_menu_new (char *title, char *help, char *popup, char *esc,
-		 int enable_esc)
+lw6gui_menu_new (const char *title, const char *help, const char *popup,
+		 const char *esc, int enable_esc)
 {
   lw6gui_menu_t *menu = NULL;
 
@@ -217,7 +217,7 @@ lw6gui_menu_memory_footprint (lw6gui_menu_t * menu)
  * Return value: a string describing the object, must be freed.
  */
 char *
-lw6gui_menu_repr (lw6gui_menu_t * menu)
+lw6gui_menu_repr (const lw6gui_menu_t * menu)
 {
   char *repr;
 
@@ -233,16 +233,16 @@ lw6gui_menu_repr (lw6gui_menu_t * menu)
  *
  * @menu: a pointer to the menu.
  * @title: the new title, you can free it after calling the function,
- *   an internal copy will be made. 
+ *   an internal copy will be made.
  *
  * Change the title of the menu.
- * Use this function to change the title, don't try to access the 
+ * Use this function to change the title, don't try to access the
  * struct directly. The idea is to have safe memory management.
  *
  * Return value: none
  */
 void
-lw6gui_menu_set_title (lw6gui_menu_t * menu, char *title)
+lw6gui_menu_set_title (lw6gui_menu_t * menu, const char *title)
 {
   LW6SYS_FREE (menu->title);
   menu->title = lw6sys_str_copy (lw6sys_str_empty_if_null (title));
@@ -258,16 +258,16 @@ lw6gui_menu_set_title (lw6gui_menu_t * menu, char *title)
  *
  * @menu: a pointer to the menu.
  * @help: the new help, you can free it after calling the function,
- *   an internal copy will be made. 
+ *   an internal copy will be made.
  *
  * Change the help of the menu.
- * Use this function to change the help, don't try to access the 
+ * Use this function to change the help, don't try to access the
  * struct directly. The idea is to have safe memory management.
  *
  * Return value: none
  */
 void
-lw6gui_menu_set_help (lw6gui_menu_t * menu, char *help)
+lw6gui_menu_set_help (lw6gui_menu_t * menu, const char *help)
 {
   LW6SYS_FREE (menu->help);
   menu->help = lw6sys_str_copy (lw6sys_str_empty_if_null (help));
@@ -283,16 +283,16 @@ lw6gui_menu_set_help (lw6gui_menu_t * menu, char *help)
  *
  * @menu: a pointer to the menu.
  * @popup: the new popup, you can free it after calling the function,
- *   an internal copy will be made. 
+ *   an internal copy will be made.
  *
  * Change the popup of the menu. That is to say, its popup.
- * Use this function to change the popup, don't try to access the 
+ * Use this function to change the popup, don't try to access the
  * struct directly. The idea is to have safe memory management.
  *
  * Return value: none
  */
 void
-lw6gui_menu_set_popup (lw6gui_menu_t * menu, char *popup)
+lw6gui_menu_set_popup (lw6gui_menu_t * menu, const char *popup)
 {
   LW6SYS_FREE (menu->popup);
   menu->popup = lw6sys_str_copy (lw6sys_str_empty_if_null (popup));
@@ -769,7 +769,7 @@ lw6gui_menu_update_display_range (lw6gui_menu_t * menu,
 
       /*
        * Here there are more items in the menu than the max
-       * displayable number. 
+       * displayable number.
        */
       menu->nb_items_displayed = max_displayed_items;
 
@@ -1073,7 +1073,7 @@ lw6gui_menu_is_same (const lw6gui_menu_t * menu_a,
  * Return value: a pointer to the new menu.
  */
 lw6gui_menu_t *
-lw6gui_menu_dup (lw6gui_menu_t * menu)
+lw6gui_menu_dup (const lw6gui_menu_t * menu)
 {
   lw6gui_menu_t *ret = NULL;
   lw6gui_menuitem_t *item = NULL;
@@ -1141,7 +1141,7 @@ lw6gui_menu_dup (lw6gui_menu_t * menu)
  * @src: the source menu
  *
  * Synchronizes two menus, this supposes that they represent the same menu, but
- * simply in a different state. This function does not really copy src to dst, it 
+ * simply in a different state. This function does not really copy src to dst, it
  * has a special behavior, indeed everything is copied from src to dst, except
  * the @first_item_displayed and @nb_items_displayed which are taken from dst
  * and copied to src. This is because in practise, those values are updated
