@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-  
+
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -38,7 +38,7 @@
  * Return value: 1 if OK, 0 if outside
  */
 int
-lw6gui_point_is_inside_rect (lw6gui_point_t point, lw6gui_rect_t * rect)
+lw6gui_point_is_inside_rect (lw6gui_point_t point, const lw6gui_rect_t * rect)
 {
   return (point.x >= rect->x1 && point.x < rect->x2 && point.y >= rect->y1
 	  && point.y < rect->y2);
