@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-  
+
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -1249,6 +1249,7 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_GET_ENTRIES);
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_SERVER_START);
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_CLIENT_JOIN);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_REFRESH_PEER);
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_DISCONNECT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_UPDATE_INFO);
   lw6sys_list_push_back (list, LW6DEF_C_LW6P2P_NODE_CALIBRATE);
@@ -1332,7 +1333,9 @@ update_advanced (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_LOG_LEVEL);
   lw6sys_list_push_back (list, LW6DEF_TARGET_FPS);
   lw6sys_list_push_back (list, LW6DEF_IO_PER_SEC);
+  lw6sys_list_push_back (list, LW6DEF_NET_PER_SEC);
   lw6sys_list_push_back (list, LW6DEF_COMMANDS_PER_SEC);
+  lw6sys_list_push_back (list, LW6DEF_SCREENSHOTS_PER_MIN);
   lw6sys_list_push_back (list, LW6DEF_LOADER_SLEEP);
   lw6sys_list_push_back (list, LW6DEF_PILOT_LAG);
   lw6sys_list_push_back (list, LW6DEF_MEMORY_BAZOOKA_SIZE);
@@ -1362,6 +1365,8 @@ update_advanced (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_DEMO);
   lw6sys_list_push_back (list, LW6DEF_BENCH);
   lw6sys_list_push_back (list, LW6DEF_BENCH_VALUE);
+  lw6sys_list_push_back (list, LW6DEF_LOCAL_BENCH_DELTA);
+  lw6sys_list_push_back (list, LW6DEF_NETWORK_BENCH_DELTA);
   lw6sys_list_push_back (list, LW6DEF_MAX_LOCAL_BENCH_VALUE);
   lw6sys_list_push_back (list, LW6DEF_MAX_NETWORK_BENCH_VALUE);
   lw6sys_list_push_back (list, LW6DEF_MAGIC_NUMBER);
