@@ -37,7 +37,7 @@
  * try and identify the objects in their on per-process lists,
  * structures, Guile object, whatever they use.
  */
-static u_int32_t seq_id = 0;
+static volatile u_int32_t seq_id = 0;
 
 /*
  * The sequence generation is done by a function since seq_id is
@@ -56,7 +56,7 @@ _lw6ker_game_state_set_id (_lw6ker_game_state_t * game_state)
 }
 
 _lw6ker_game_state_t *
-_lw6ker_game_state_new (_lw6ker_game_struct_t * game_struct,
+_lw6ker_game_state_new (const _lw6ker_game_struct_t * game_struct,
 			lw6sys_progress_t * progress)
 {
   _lw6ker_game_state_t *ret = NULL;
@@ -67,7 +67,14 @@ _lw6ker_game_state_new (_lw6ker_game_struct_t * game_struct,
     {
       _lw6ker_game_state_set_id (ret);
       ret->game_struct = game_struct;
-      ret->rounds = 0;
+
+      /*
+       * We initialize total_rounds now, we will possibly increment
+       * it later if we need to make the game longer because
+       * there's only one team present.
+       */
+      ret->total_rounds = game_struct->rules.rounds_per_sec *
+	game_struct->rules.total_time;
 
       _lw6ker_map_state_init (&(ret->map_state),
 			      &(ret->game_struct->map_struct),
@@ -90,11 +97,12 @@ _lw6ker_game_state_new (_lw6ker_game_struct_t * game_struct,
  * Return value: newly created object.
  */
 lw6ker_game_state_t *
-lw6ker_game_state_new (lw6ker_game_struct_t * game_struct,
+lw6ker_game_state_new (const lw6ker_game_struct_t * game_struct,
 		       lw6sys_progress_t * progress)
 {
   return (lw6ker_game_state_t *)
-    _lw6ker_game_state_new ((_lw6ker_game_struct_t *) game_struct, progress);
+    _lw6ker_game_state_new ((const _lw6ker_game_struct_t *) game_struct,
+			    progress);
 }
 
 void
@@ -136,7 +144,7 @@ lw6ker_game_state_free (lw6ker_game_state_t * game_state)
 
 void
 _lw6ker_game_state_point_to (_lw6ker_game_state_t * game_state,
-			     _lw6ker_game_struct_t * game_struct)
+			     const _lw6ker_game_struct_t * game_struct)
 {
   int i;
 
@@ -165,10 +173,10 @@ _lw6ker_game_state_point_to (_lw6ker_game_state_t * game_state,
  */
 void
 lw6ker_game_state_point_to (lw6ker_game_state_t * game_state,
-			    lw6ker_game_struct_t * game_struct)
+			    const lw6ker_game_struct_t * game_struct)
 {
   _lw6ker_game_state_point_to ((_lw6ker_game_state_t *) game_state,
-			       (_lw6ker_game_struct_t *) game_struct);
+			       (const _lw6ker_game_struct_t *) game_struct);
 }
 
 int
@@ -198,7 +206,7 @@ lw6ker_game_state_memory_footprint (lw6ker_game_state_t * game_state)
 }
 
 char *
-_lw6ker_game_state_repr (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_repr (const _lw6ker_game_state_t * game_state)
 {
   char *ret = NULL;
 
@@ -229,7 +237,7 @@ _lw6ker_game_state_repr (_lw6ker_game_state_t * game_state)
 
 /**
  * lw6ker_game_state_repr
- * 
+ *
  * @game_state: the game_state to query
  *
  * Gives a readable representation of the object.
@@ -237,14 +245,14 @@ _lw6ker_game_state_repr (_lw6ker_game_state_t * game_state)
  * Return value: newly allocated string, must be freed
  */
 char *
-lw6ker_game_state_repr (lw6ker_game_state_t * game_state)
+lw6ker_game_state_repr (const lw6ker_game_state_t * game_state)
 {
   return _lw6ker_game_state_repr ((_lw6ker_game_state_t *) game_state);
 }
 
 int
 _lw6ker_game_state_can_sync (_lw6ker_game_state_t * dst,
-			     _lw6ker_game_state_t * src)
+			     const _lw6ker_game_state_t * src)
 {
   int ret = 0;
 
@@ -285,15 +293,15 @@ _lw6ker_game_state_can_sync (_lw6ker_game_state_t * dst,
  */
 int
 lw6ker_game_state_can_sync (lw6ker_game_state_t * dst,
-			    lw6ker_game_state_t * src)
+			    const lw6ker_game_state_t * src)
 {
   return _lw6ker_game_state_can_sync ((_lw6ker_game_state_t *) dst,
-				      (_lw6ker_game_state_t *) src);
+				      (const _lw6ker_game_state_t *) src);
 }
 
 int
 _lw6ker_game_state_sync (_lw6ker_game_state_t * dst,
-			 _lw6ker_game_state_t * src)
+			 const _lw6ker_game_state_t * src)
 {
   int ret = 0;
 
@@ -326,6 +334,7 @@ _lw6ker_game_state_sync (_lw6ker_game_state_t * dst,
 	  dst->moves = src->moves;
 	  dst->spreads = src->spreads;
 	  dst->rounds = src->rounds;
+	  dst->total_rounds = src->total_rounds;
 	  dst->max_reached_teams = src->max_reached_teams;
 	  dst->over = src->over;
 	}
@@ -356,14 +365,15 @@ _lw6ker_game_state_sync (_lw6ker_game_state_t * dst,
  * Return value: 1 on success, 0 on error
  */
 int
-lw6ker_game_state_sync (lw6ker_game_state_t * dst, lw6ker_game_state_t * src)
+lw6ker_game_state_sync (lw6ker_game_state_t * dst,
+			const lw6ker_game_state_t * src)
 {
   return _lw6ker_game_state_sync ((_lw6ker_game_state_t *) dst,
-				  (_lw6ker_game_state_t *) src);
+				  (const _lw6ker_game_state_t *) src);
 }
 
 _lw6ker_game_state_t *
-_lw6ker_game_state_dup (_lw6ker_game_state_t * game_state,
+_lw6ker_game_state_dup (const _lw6ker_game_state_t * game_state,
 			lw6sys_progress_t * progress)
 {
   _lw6ker_game_state_t *ret;
@@ -414,15 +424,16 @@ _lw6ker_game_state_dup (_lw6ker_game_state_t * game_state,
  * Return value: newly created object
  */
 lw6ker_game_state_t *
-lw6ker_game_state_dup (lw6ker_game_state_t * game_state,
+lw6ker_game_state_dup (const lw6ker_game_state_t * game_state,
 		       lw6sys_progress_t * progress)
 {
   return (lw6ker_game_state_t *)
-    _lw6ker_game_state_dup ((_lw6ker_game_state_t *) game_state, progress);
+    _lw6ker_game_state_dup ((const _lw6ker_game_state_t *) game_state,
+			    progress);
 }
 
 void
-_lw6ker_game_state_update_checksum (_lw6ker_game_state_t *
+_lw6ker_game_state_update_checksum (const _lw6ker_game_state_t *
 				    game_state, u_int32_t * checksum)
 {
   _lw6ker_game_struct_update_checksum (game_state->game_struct, checksum);
@@ -433,12 +444,13 @@ _lw6ker_game_state_update_checksum (_lw6ker_game_state_t *
   lw6sys_checksum_update_int32 (checksum, game_state->moves);
   lw6sys_checksum_update_int32 (checksum, game_state->spreads);
   lw6sys_checksum_update_int32 (checksum, game_state->rounds);
+  lw6sys_checksum_update_int32 (checksum, game_state->total_rounds);
   lw6sys_checksum_update_int32 (checksum, game_state->max_reached_teams);
   lw6sys_checksum_update_int32 (checksum, game_state->over);
 }
 
 u_int32_t
-_lw6ker_game_state_checksum (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_checksum (const _lw6ker_game_state_t * game_state)
 {
   u_int32_t ret = 0;
 
@@ -459,9 +471,10 @@ _lw6ker_game_state_checksum (_lw6ker_game_state_t * game_state)
  * Return value: 32-bit checksum
  */
 u_int32_t
-lw6ker_game_state_checksum (lw6ker_game_state_t * game_state)
+lw6ker_game_state_checksum (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_checksum ((_lw6ker_game_state_t *) game_state);
+  return _lw6ker_game_state_checksum ((const _lw6ker_game_state_t *)
+				      game_state);
 }
 
 /**
@@ -475,7 +488,7 @@ lw6ker_game_state_checksum (lw6ker_game_state_t * game_state)
  * Return value: none.
  */
 void
-lw6ker_game_state_get_shape (lw6ker_game_state_t * game_state,
+lw6ker_game_state_get_shape (const lw6ker_game_state_t * game_state,
 			     lw6sys_whd_t * shape)
 {
   (*shape) = ((_lw6ker_game_state_t *) game_state)->map_state.shape;
@@ -491,7 +504,7 @@ lw6ker_game_state_get_shape (lw6ker_game_state_t * game_state,
  * Return value: the width.
  */
 int
-lw6ker_game_state_get_w (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_w (const lw6ker_game_state_t * game_state)
 {
   return ((_lw6ker_game_state_t *) game_state)->map_state.shape.w;
 }
@@ -506,7 +519,7 @@ lw6ker_game_state_get_w (lw6ker_game_state_t * game_state)
  * Return value: the height.
  */
 int
-lw6ker_game_state_get_h (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_h (const lw6ker_game_state_t * game_state)
 {
   return ((_lw6ker_game_state_t *) game_state)->map_state.shape.h;
 }
@@ -521,7 +534,7 @@ lw6ker_game_state_get_h (lw6ker_game_state_t * game_state)
  * Return value: the depth.
  */
 int
-lw6ker_game_state_get_d (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_d (const lw6ker_game_state_t * game_state)
 {
   return ((_lw6ker_game_state_t *) game_state)->map_state.shape.d;
 }
@@ -611,12 +624,13 @@ lw6ker_game_state_unregister_node (lw6ker_game_state_t * game_state,
 }
 
 int
-_lw6ker_game_state_node_exists (_lw6ker_game_state_t * game_state,
+_lw6ker_game_state_node_exists (const _lw6ker_game_state_t * game_state,
 				u_int64_t node_id)
 {
   int ret = 0;
 
-  ret = (_lw6ker_node_array_get (&(game_state->node_array), node_id) != NULL);
+  ret =
+    (_lw6ker_node_array_get_ro (&(game_state->node_array), node_id) != NULL);
 
   return ret;
 }
@@ -640,14 +654,14 @@ lw6ker_game_state_node_exists (lw6ker_game_state_t * game_state,
 }
 
 int
-_lw6ker_game_state_get_node_info (_lw6ker_game_state_t *
+_lw6ker_game_state_get_node_info (const _lw6ker_game_state_t *
 				  game_state, u_int16_t node_id,
 				  u_int32_t * last_command_round)
 {
   int ret = 0;
-  _lw6ker_node_t *node = NULL;
+  const _lw6ker_node_t *node = NULL;
 
-  node = _lw6ker_node_array_get (&(game_state->node_array), node_id);
+  node = _lw6ker_node_array_get_ro (&(game_state->node_array), node_id);
   if (node)
     {
       if (last_command_round)
@@ -708,7 +722,7 @@ _lw6ker_game_state_add_cursor (_lw6ker_game_state_t * game_state,
 			       u_int16_t cursor_id, int team_color)
 {
   int ret = 0;
-  lw6map_rules_t *rules = NULL;
+  const lw6map_rules_t *rules = NULL;
   int team_exists = 0;
   int real_team_color = LW6MAP_TEAM_COLOR_INVALID;
   int32_t x = 0;
@@ -804,7 +818,7 @@ _lw6ker_game_state_add_cursor (_lw6ker_game_state_t * game_state,
  * @team_color: the color we wish
  *
  * Adds a cursor in a game. Note that if there's already a cursor with
- * that id, it will fail, and the color is only the color we wish, 
+ * that id, it will fail, and the color is only the color we wish,
  * we might indeed be attributed another color on a successfull call.
  *
  * Return value: 1 on success, 0 on error.
@@ -874,14 +888,14 @@ lw6ker_game_state_remove_cursor (lw6ker_game_state_t * game_state,
 }
 
 int
-_lw6ker_game_state_cursor_exists (_lw6ker_game_state_t * game_state,
+_lw6ker_game_state_cursor_exists (const _lw6ker_game_state_t * game_state,
 				  u_int16_t cursor_id)
 {
   int ret = 0;
-  lw6ker_cursor_t *cursor = NULL;
+  const lw6ker_cursor_t *cursor = NULL;
   cursor =
-    _lw6ker_cursor_array_get (&(game_state->map_state.cursor_array),
-			      cursor_id);
+    _lw6ker_cursor_array_get_ro (&(game_state->map_state.cursor_array),
+				 cursor_id);
   if (cursor)
     {
       ret = 1;
@@ -901,24 +915,24 @@ _lw6ker_game_state_cursor_exists (_lw6ker_game_state_t * game_state,
  * Return value: 1 if cursor exists, 0 if not.
  */
 int
-lw6ker_game_state_cursor_exists (lw6ker_game_state_t * game_state,
+lw6ker_game_state_cursor_exists (const lw6ker_game_state_t * game_state,
 				 u_int16_t cursor_id)
 {
-  return _lw6ker_game_state_cursor_exists ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_cursor_exists ((const _lw6ker_game_state_t *)
 					   game_state, cursor_id);
 }
 
 int
-_lw6ker_game_state_get_cursor (_lw6ker_game_state_t *
+_lw6ker_game_state_get_cursor (const _lw6ker_game_state_t *
 			       game_state,
 			       lw6ker_cursor_t * cursor, u_int16_t cursor_id)
 {
   int ret = 0;
-  lw6ker_cursor_t *found_cursor = NULL;
+  const lw6ker_cursor_t *found_cursor = NULL;
 
   found_cursor =
-    _lw6ker_cursor_array_get (&(game_state->map_state.cursor_array),
-			      cursor_id);
+    _lw6ker_cursor_array_get_ro (&(game_state->map_state.cursor_array),
+				 cursor_id);
   if (cursor)
     {
       lw6ker_cursor_reset (cursor);
@@ -942,20 +956,23 @@ _lw6ker_game_state_get_cursor (_lw6ker_game_state_t *
  * @cursor: the cursor data (out param)
  * @cursor_id: the cursor to query
  *
+ * Get a pointer on a given cursor, pointer is read-only.
+ *
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6ker_game_state_get_cursor (lw6ker_game_state_t *
+lw6ker_game_state_get_cursor (const lw6ker_game_state_t *
 			      game_state,
 			      lw6ker_cursor_t * cursor, u_int16_t cursor_id)
 {
-  return _lw6ker_game_state_get_cursor ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_get_cursor ((const _lw6ker_game_state_t *)
 					game_state, cursor, cursor_id);
 }
 
 void
-_lw6ker_game_state_get_cursor_by_index (_lw6ker_game_state_t * game_state,
-					lw6ker_cursor_t * cursor, int i)
+_lw6ker_game_state_get_cursor_by_index (const _lw6ker_game_state_t *
+					game_state, lw6ker_cursor_t * cursor,
+					int i)
 {
   (*cursor) = game_state->map_state.cursor_array.cursors[i];
 }
@@ -968,17 +985,17 @@ _lw6ker_game_state_get_cursor_by_index (_lw6ker_game_state_t * game_state,
  * @i: the index
  *
  * Gets the cursor information, using its index. This is usefull to walk
- * the whole cursor without knowing their ids.
+ * the whole cursor without knowing their ids. Pointer is read-only.
  *
  * Return value: none.
  */
 void
-lw6ker_game_state_get_cursor_by_index (lw6ker_game_state_t *
+lw6ker_game_state_get_cursor_by_index (const lw6ker_game_state_t *
 				       game_state,
 				       lw6ker_cursor_t * cursor, int i)
 {
-  _lw6ker_game_state_get_cursor_by_index ((_lw6ker_game_state_t *) game_state,
-					  cursor, i);
+  _lw6ker_game_state_get_cursor_by_index ((const _lw6ker_game_state_t *)
+					  game_state, cursor, i);
 }
 
 int
@@ -1042,7 +1059,7 @@ _lw6ker_game_state_add_team_internal (_lw6ker_game_state_t * game_state,
    */
   int64_t total_fighters;
   int64_t total_fighters_to_remove;
-  lw6map_rules_t *rules = NULL;
+  const lw6map_rules_t *rules = NULL;
 
   rules = &(game_state->game_struct->rules);
   if (!_lw6ker_game_state_team_exists (game_state, team_color))
@@ -1289,7 +1306,7 @@ _lw6ker_game_state_remove_team (_lw6ker_game_state_t * game_state,
 }
 
 int
-_lw6ker_game_state_team_exists (_lw6ker_game_state_t * game_state,
+_lw6ker_game_state_team_exists (const _lw6ker_game_state_t * game_state,
 				int team_color)
 {
   int ret = 0;
@@ -1314,21 +1331,21 @@ _lw6ker_game_state_team_exists (_lw6ker_game_state_t * game_state,
  * Return value: 1 if team exists, 0 if not.
  */
 int
-lw6ker_game_state_team_exists (lw6ker_game_state_t * game_state,
+lw6ker_game_state_team_exists (const lw6ker_game_state_t * game_state,
 			       int team_color)
 {
-  return _lw6ker_game_state_team_exists ((_lw6ker_game_state_t *) game_state,
-					 team_color);
+  return _lw6ker_game_state_team_exists ((const _lw6ker_game_state_t *)
+					 game_state, team_color);
 }
 
 int
-_lw6ker_game_state_get_team_info (_lw6ker_game_state_t *
+_lw6ker_game_state_get_team_info (const _lw6ker_game_state_t *
 				  game_state, int team_color,
 				  int32_t * nb_cursors, int32_t * nb_fighters)
 {
   int ret = 0;
-  _lw6ker_team_t *team;
-  _lw6ker_cursor_array_t *cursor_array;
+  const _lw6ker_team_t *team;
+  const _lw6ker_cursor_array_t *cursor_array;
   int i = 0;
 
   if (team_color >= 0 && team_color < LW6MAP_MAX_NB_TEAMS)
@@ -1380,7 +1397,7 @@ _lw6ker_game_state_get_team_info (_lw6ker_game_state_t *
  * @team_color: the color to get informations about
  * @nb_cursors: number of cursors with this color (out param)
  * @nb_fighters: number of fighters with this color (out param)
- * 
+ *
  * Gets informations about a given color. Indeed, a color can have several
  * cursors, and knowing how many fighters there are with a given color
  * is probably the most important things about a color.
@@ -1388,17 +1405,17 @@ _lw6ker_game_state_get_team_info (_lw6ker_game_state_t *
  * Return value: 1 on success, 0 on failure.
  */
 int
-lw6ker_game_state_get_team_info (lw6ker_game_state_t *
+lw6ker_game_state_get_team_info (const lw6ker_game_state_t *
 				 game_state, int team_color,
 				 int32_t * nb_cursors, int32_t * nb_fighters)
 {
-  return _lw6ker_game_state_get_team_info ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_get_team_info ((const _lw6ker_game_state_t *)
 					   game_state, team_color, nb_cursors,
 					   nb_fighters);
 }
 
 int
-_lw6ker_game_state_get_nb_teams (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_nb_teams (const _lw6ker_game_state_t * game_state)
 {
   int ret = 0;
 
@@ -1409,7 +1426,7 @@ _lw6ker_game_state_get_nb_teams (_lw6ker_game_state_t * game_state)
 
 /**
  * lw6ker_game_state_get_nb_teams
- * 
+ *
  * @game_state: the game_state to query
  *
  * Tells how many teams there are in a game. This is different from the
@@ -1419,9 +1436,9 @@ _lw6ker_game_state_get_nb_teams (_lw6ker_game_state_t * game_state)
  * Return value: the number of teams.
  */
 int
-lw6ker_game_state_get_nb_teams (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_nb_teams (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_get_nb_teams ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_get_nb_teams ((const _lw6ker_game_state_t *)
 					  game_state);
 }
 
@@ -1657,6 +1674,16 @@ _lw6ker_game_state_finish_round (_lw6ker_game_state_t * game_state)
       game_state->moves += game_state->game_struct->rules.moves_per_round;
       game_state->spreads += game_state->game_struct->rules.spreads_per_round;
       game_state->rounds++;
+      /*
+       * If we're alone on the battlefield, there's no fight,
+       * no point in having the clock ticking, so we make the
+       * game longer until some other team comes. Technically,
+       * this cause the "time left" to remain constant.
+       */
+      if (nb_teams <= 1)
+	{
+	  game_state->total_rounds++;
+	}
 
       _lw6ker_game_state_checksum_log_if_needed (game_state);
     }
@@ -1715,7 +1742,7 @@ lw6ker_game_state_do_round (lw6ker_game_state_t * game_state)
 }
 
 u_int32_t
-_lw6ker_game_state_get_moves (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_moves (const _lw6ker_game_state_t * game_state)
 {
   return (game_state->moves);
 }
@@ -1730,13 +1757,14 @@ _lw6ker_game_state_get_moves (_lw6ker_game_state_t * game_state)
  * Return value: number of moves.
  */
 u_int32_t
-lw6ker_game_state_get_moves (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_moves (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_get_moves ((_lw6ker_game_state_t *) game_state);
+  return _lw6ker_game_state_get_moves ((const _lw6ker_game_state_t *)
+				       game_state);
 }
 
 u_int32_t
-_lw6ker_game_state_get_spreads (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_spreads (const _lw6ker_game_state_t * game_state)
 {
   return (game_state->spreads);
 }
@@ -1751,13 +1779,14 @@ _lw6ker_game_state_get_spreads (_lw6ker_game_state_t * game_state)
  * Return value: number of spreads.
  */
 u_int32_t
-lw6ker_game_state_get_spreads (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_spreads (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_get_spreads ((_lw6ker_game_state_t *) game_state);
+  return _lw6ker_game_state_get_spreads ((const _lw6ker_game_state_t *)
+					 game_state);
 }
 
 u_int32_t
-_lw6ker_game_state_get_rounds (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_rounds (const _lw6ker_game_state_t * game_state)
 {
   return (game_state->rounds);
 }
@@ -1772,16 +1801,16 @@ _lw6ker_game_state_get_rounds (_lw6ker_game_state_t * game_state)
  * Return value: number of rounds.
  */
 u_int32_t
-lw6ker_game_state_get_rounds (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_rounds (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_get_rounds ((_lw6ker_game_state_t *) game_state);
+  return _lw6ker_game_state_get_rounds ((const _lw6ker_game_state_t *)
+					game_state);
 }
 
 u_int32_t
-_lw6ker_game_state_get_total_rounds (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_total_rounds (const _lw6ker_game_state_t * game_state)
 {
-  return (game_state->game_struct->rules.rounds_per_sec *
-	  game_state->game_struct->rules.total_time);
+  return (game_state->total_rounds);
 }
 
 /**
@@ -1798,14 +1827,14 @@ _lw6ker_game_state_get_total_rounds (_lw6ker_game_state_t * game_state)
  * Return value: number of rounds in the game
  */
 u_int32_t
-lw6ker_game_state_get_total_rounds (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_total_rounds (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_get_total_rounds ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_get_total_rounds ((const _lw6ker_game_state_t *)
 					      game_state);
 }
 
 int
-_lw6ker_game_state_is_over (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_is_over (const _lw6ker_game_state_t * game_state)
 {
   return game_state->over ? 1 : 0;
 }
@@ -1821,13 +1850,14 @@ _lw6ker_game_state_is_over (_lw6ker_game_state_t * game_state)
  * Return value: 1 if over, 0 if not.
  */
 int
-lw6ker_game_state_is_over (lw6ker_game_state_t * game_state)
+lw6ker_game_state_is_over (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_is_over ((_lw6ker_game_state_t *) game_state);
+  return _lw6ker_game_state_is_over ((const _lw6ker_game_state_t *)
+				     game_state);
 }
 
 int
-_lw6ker_game_state_did_cursor_win (_lw6ker_game_state_t * game_state,
+_lw6ker_game_state_did_cursor_win (const _lw6ker_game_state_t * game_state,
 				   u_int16_t cursor_id)
 {
   int ret = 0;
@@ -1873,7 +1903,7 @@ _lw6ker_game_state_did_cursor_win (_lw6ker_game_state_t * game_state,
  * Return value: 1 if cursor is in winning team, 0 if not.
  */
 int
-lw6ker_game_state_did_cursor_win (lw6ker_game_state_t * game_state,
+lw6ker_game_state_did_cursor_win (const lw6ker_game_state_t * game_state,
 				  u_int16_t cursor_id)
 {
   return _lw6ker_game_state_did_cursor_win ((_lw6ker_game_state_t *)
@@ -1881,7 +1911,7 @@ lw6ker_game_state_did_cursor_win (lw6ker_game_state_t * game_state,
 }
 
 int
-_lw6ker_game_state_get_winner (_lw6ker_game_state_t * game_state,
+_lw6ker_game_state_get_winner (const _lw6ker_game_state_t * game_state,
 			       int excluded_team)
 {
   int nb_active_fighters_max;
@@ -1925,15 +1955,15 @@ _lw6ker_game_state_get_winner (_lw6ker_game_state_t * game_state,
  * teams on the map).
  */
 int
-lw6ker_game_state_get_winner (lw6ker_game_state_t * game_state,
+lw6ker_game_state_get_winner (const lw6ker_game_state_t * game_state,
 			      int excluded_team)
 {
-  return _lw6ker_game_state_get_winner ((_lw6ker_game_state_t *) game_state,
-					excluded_team);
+  return _lw6ker_game_state_get_winner ((const _lw6ker_game_state_t *)
+					game_state, excluded_team);
 }
 
 int
-_lw6ker_game_state_get_looser (_lw6ker_game_state_t * game_state,
+_lw6ker_game_state_get_looser (const _lw6ker_game_state_t * game_state,
 			       int excluded_team)
 {
   int nb_active_fighters_min;
@@ -1978,15 +2008,16 @@ _lw6ker_game_state_get_looser (_lw6ker_game_state_t * game_state,
  * teams on the map).
  */
 int
-lw6ker_game_state_get_looser (lw6ker_game_state_t * game_state,
+lw6ker_game_state_get_looser (const lw6ker_game_state_t * game_state,
 			      int excluded_team)
 {
-  return _lw6ker_game_state_get_looser ((_lw6ker_game_state_t *) game_state,
-					excluded_team);
+  return _lw6ker_game_state_get_looser ((const _lw6ker_game_state_t *)
+					game_state, excluded_team);
 }
 
 int32_t
-_lw6ker_game_state_get_nb_active_fighters (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_nb_active_fighters (const _lw6ker_game_state_t *
+					   game_state)
 {
   return (game_state->map_state.armies.active_fighters);
 }
@@ -2003,14 +2034,16 @@ _lw6ker_game_state_get_nb_active_fighters (_lw6ker_game_state_t * game_state)
  * Return value: number of fighters.
  */
 int32_t
-lw6ker_game_state_get_nb_active_fighters (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_nb_active_fighters (const lw6ker_game_state_t *
+					  game_state)
 {
-  return _lw6ker_game_state_get_nb_active_fighters ((_lw6ker_game_state_t *)
-						    game_state);
+  return
+    _lw6ker_game_state_get_nb_active_fighters ((const _lw6ker_game_state_t *)
+					       game_state);
 }
 
 int32_t
-_lw6ker_game_state_get_time_elapsed (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_time_elapsed (const _lw6ker_game_state_t * game_state)
 {
   int32_t ret = 0;
   u_int32_t rounds = 0;
@@ -2034,20 +2067,21 @@ _lw6ker_game_state_get_time_elapsed (_lw6ker_game_state_t * game_state)
  * Return value: time elapsed, in seconds.
  */
 int32_t
-lw6ker_game_state_get_time_elapsed (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_time_elapsed (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_get_time_elapsed ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_get_time_elapsed ((const _lw6ker_game_state_t *)
 					      game_state);
 }
 
 int32_t
-_lw6ker_game_state_get_time_left (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_time_left (const _lw6ker_game_state_t * game_state)
 {
   int32_t ret = 0;
 
   ret =
-    game_state->game_struct->rules.total_time -
-    _lw6ker_game_state_get_time_elapsed (game_state);
+    (_lw6ker_game_state_get_total_rounds (game_state) -
+     _lw6ker_game_state_get_rounds (game_state)) /
+    (u_int32_t) game_state->game_struct->rules.rounds_per_sec;
 
   return ret;
 }
@@ -2067,21 +2101,21 @@ _lw6ker_game_state_get_time_left (_lw6ker_game_state_t * game_state)
  * Return value: time left, in seconds.
  */
 int32_t
-lw6ker_game_state_get_time_left (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_time_left (const lw6ker_game_state_t * game_state)
 {
-  return _lw6ker_game_state_get_time_left ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_get_time_left ((const _lw6ker_game_state_t *)
 					   game_state);
 }
 
 int32_t
-_lw6ker_game_state_get_global_history (_lw6ker_game_state_t * game_state,
-				       int i, int team_id)
+_lw6ker_game_state_get_global_history (const _lw6ker_game_state_t *
+				       game_state, int i, int team_id)
 {
   return _lw6ker_history_get (&(game_state->global_history), i, team_id);
 }
 
 /**
- * lw6ker_game_state_get_global_history 
+ * lw6ker_game_state_get_global_history
  *
  * @game_state: the game_state to query
  * @i: the index of the history point
@@ -2096,22 +2130,22 @@ _lw6ker_game_state_get_global_history (_lw6ker_game_state_t * game_state,
  * Return value: number of fighters at that time.
  */
 int32_t
-lw6ker_game_state_get_global_history (lw6ker_game_state_t * game_state, int i,
-				      int team_id)
+lw6ker_game_state_get_global_history (const lw6ker_game_state_t * game_state,
+				      int i, int team_id)
 {
-  return _lw6ker_game_state_get_global_history ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_get_global_history ((const _lw6ker_game_state_t *)
 						game_state, i, team_id);
 }
 
 int32_t
-_lw6ker_game_state_get_latest_history (_lw6ker_game_state_t * game_state,
-				       int i, int team_id)
+_lw6ker_game_state_get_latest_history (const _lw6ker_game_state_t *
+				       game_state, int i, int team_id)
 {
   return _lw6ker_history_get (&(game_state->latest_history), i, team_id);
 }
 
 /**
- * lw6ker_game_state_get_latest_history 
+ * lw6ker_game_state_get_latest_history
  *
  * @game_state: the game_state to query
  * @i: the index of the history point
@@ -2126,15 +2160,16 @@ _lw6ker_game_state_get_latest_history (_lw6ker_game_state_t * game_state,
  * Return value: number of fighters at that time.
  */
 int32_t
-lw6ker_game_state_get_latest_history (lw6ker_game_state_t * game_state, int i,
-				      int team_id)
+lw6ker_game_state_get_latest_history (const lw6ker_game_state_t * game_state,
+				      int i, int team_id)
 {
-  return _lw6ker_game_state_get_latest_history ((_lw6ker_game_state_t *)
+  return _lw6ker_game_state_get_latest_history ((const _lw6ker_game_state_t *)
 						game_state, i, team_id);
 }
 
 int32_t
-_lw6ker_game_state_get_global_history_max (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_global_history_max (const _lw6ker_game_state_t *
+					   game_state)
 {
   return _lw6ker_history_get_max (&(game_state->global_history));
 }
@@ -2151,14 +2186,17 @@ _lw6ker_game_state_get_global_history_max (_lw6ker_game_state_t * game_state)
  * Return value: max number of fighters.
  */
 int32_t
-lw6ker_game_state_get_global_history_max (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_global_history_max (const lw6ker_game_state_t *
+					  game_state)
 {
-  return _lw6ker_game_state_get_global_history_max ((_lw6ker_game_state_t *)
-						    game_state);
+  return
+    _lw6ker_game_state_get_global_history_max ((const _lw6ker_game_state_t *)
+					       game_state);
 }
 
 int32_t
-_lw6ker_game_state_get_latest_history_max (_lw6ker_game_state_t * game_state)
+_lw6ker_game_state_get_latest_history_max (const _lw6ker_game_state_t *
+					   game_state)
 {
   return _lw6ker_history_get_max (&(game_state->latest_history));
 }
@@ -2175,10 +2213,12 @@ _lw6ker_game_state_get_latest_history_max (_lw6ker_game_state_t * game_state)
  * Return value: max number of fighters.
  */
 int32_t
-lw6ker_game_state_get_latest_history_max (lw6ker_game_state_t * game_state)
+lw6ker_game_state_get_latest_history_max (const lw6ker_game_state_t *
+					  game_state)
 {
-  return _lw6ker_game_state_get_latest_history_max ((_lw6ker_game_state_t *)
-						    game_state);
+  return
+    _lw6ker_game_state_get_latest_history_max ((const _lw6ker_game_state_t *)
+					       game_state);
 }
 
 /**
@@ -2196,21 +2236,21 @@ lw6ker_game_state_get_latest_history_max (lw6ker_game_state_t * game_state)
  * called often when one wants to know what's happening on the battlefield,
  * to draw it, for instance. If there's no fighter, the id is negative,
  * any id equal or greater than 0 (returned by this function) is valid.
- * 
+ *
  * Return value: the id of the fighter at that position.
  */
 int32_t
-lw6ker_game_state_get_fighter_id (lw6ker_game_state_t * game_state,
+lw6ker_game_state_get_fighter_id (const lw6ker_game_state_t * game_state,
 				  int32_t x, int32_t y, int32_t z)
 {
   return
     _lw6ker_map_state_get_fighter_id (&
-				      (((_lw6ker_game_state_t *)
+				      (((const _lw6ker_game_state_t *)
 					game_state)->map_state), x, y, z);
 }
 
 /**
- * lw6ker_game_state_get_fighter_by_id
+ * lw6ker_game_state_get_fighter_rw_by_id
  *
  * @game_state: game_state to query
  * @fighter_id: the id of the fighter
@@ -2218,13 +2258,14 @@ lw6ker_game_state_get_fighter_id (lw6ker_game_state_t * game_state,
  * Gets a fighter by its id. Internally, all fighters are stored in an array
  * so it could be "safe" to get fighter with id 0 then walk the array.
  * Previous versions of the game used to have this public (the array),
- * it has been hidden since.
- * 
+ * it has been hidden since. Pointer is read/write.
+ * Pointer is read/write.
+ *
  * Return value: pointer to the fighter with the given id.
  */
 lw6ker_fighter_t *
-lw6ker_game_state_get_fighter_by_id (lw6ker_game_state_t * game_state,
-				     int32_t fighter_id)
+lw6ker_game_state_get_fighter_rw_by_id (lw6ker_game_state_t * game_state,
+					int32_t fighter_id)
 {
   return (&
 	  (((_lw6ker_game_state_t *) game_state)->map_state.
@@ -2232,7 +2273,7 @@ lw6ker_game_state_get_fighter_by_id (lw6ker_game_state_t * game_state,
 }
 
 /**
- * lw6ker_game_state_get_fighter_safe
+ * lw6ker_game_state_get_fighter_rw_safe
  *
  * @game_state: game_state to query
  * @x: x position
@@ -2243,12 +2284,13 @@ lw6ker_game_state_get_fighter_by_id (lw6ker_game_state_t * game_state,
  * no fighter in this place, it will return NULL, but nothing worse can happen. More
  * precisely, if the place is in a wall, it won't bug, unlike the non-bullet-proof
  * equivalent of this function.
- * 
+ * Pointer is read/write.
+ *
  * Return value: pointer to the fighter at this position, or NULL if none.
  */
 lw6ker_fighter_t *
-lw6ker_game_state_get_fighter_safe (lw6ker_game_state_t * game_state,
-				    int32_t x, int32_t y, int32_t z)
+lw6ker_game_state_get_fighter_rw_safe (lw6ker_game_state_t * game_state,
+				       int32_t x, int32_t y, int32_t z)
 {
   lw6ker_fighter_t *ret = NULL;
   int fighter_id;
@@ -2263,7 +2305,8 @@ lw6ker_game_state_get_fighter_safe (lw6ker_game_state_t * game_state,
       fighter_id = lw6ker_game_state_get_fighter_id (game_state, x, y, z);
       if (fighter_id >= 0)
 	{
-	  ret = lw6ker_game_state_get_fighter_by_id (game_state, fighter_id);
+	  ret =
+	    lw6ker_game_state_get_fighter_rw_by_id (game_state, fighter_id);
 	}
     }
 
@@ -2271,7 +2314,7 @@ lw6ker_game_state_get_fighter_safe (lw6ker_game_state_t * game_state,
 };
 
 /**
- * lw6ker_game_state_get_fighter_unsafe
+ * lw6ker_game_state_get_fighter_rw_unsafe
  *
  * @game_state: game_state to query
  * @x: x position
@@ -2282,17 +2325,111 @@ lw6ker_game_state_get_fighter_safe (lw6ker_game_state_t * game_state,
  * no fighter in this place, not only will it probably not return a valid value, but it will also
  * even segfault before that, trying to access non-existing structures in menory. So only
  * call this if you're sure there's a fighter here.
- * 
+ * Pointer is read/write.
+ *
  * Return value: pointer to the fighter at this position, or NULL if none.
  */
 lw6ker_fighter_t *
-lw6ker_game_state_get_fighter_unsafe (lw6ker_game_state_t * game_state,
-				      int32_t x, int32_t y, int32_t z)
+lw6ker_game_state_get_fighter_rw_unsafe (lw6ker_game_state_t * game_state,
+					 int32_t x, int32_t y, int32_t z)
 {
   return
-    _lw6ker_map_state_get_fighter_unsafe (&
-					  (((_lw6ker_game_state_t *)
-					    game_state)->map_state), x, y, z);
+    _lw6ker_map_state_get_fighter_rw_unsafe (&
+					     (((_lw6ker_game_state_t *)
+					       game_state)->map_state), x, y,
+					     z);
+}
+
+/**
+ * lw6ker_game_state_get_fighter_ro_by_id
+ *
+ * @game_state: game_state to query
+ * @fighter_id: the id of the fighter
+ *
+ * Gets a fighter by its id. Internally, all fighters are stored in an array
+ * so it could be "safe" to get fighter with id 0 then walk the array.
+ * Previous versions of the game used to have this public (the array),
+ * it has been hidden since. Pointer is read-only.
+ * Pointer is read-only.
+ *
+ * Return value: pointer to the fighter with the given id.
+ */
+const lw6ker_fighter_t *
+lw6ker_game_state_get_fighter_ro_by_id (const lw6ker_game_state_t *
+					game_state, int32_t fighter_id)
+{
+  return (&
+	  (((const _lw6ker_game_state_t *) game_state)->map_state.
+	   armies.fighters[fighter_id]));
+}
+
+/**
+ * lw6ker_game_state_get_fighter_ro_safe
+ *
+ * @game_state: game_state to query
+ * @x: x position
+ * @y: y position
+ * @z: z position
+ *
+ * Gets a fighter by its position. This function will check for boundaries, if there's
+ * no fighter in this place, it will return NULL, but nothing worse can happen. More
+ * precisely, if the place is in a wall, it won't bug, unlike the non-bullet-proof
+ * equivalent of this function.
+ * Pointer is read-only.
+ *
+ * Return value: pointer to the fighter at this position, or NULL if none.
+ */
+const lw6ker_fighter_t *
+lw6ker_game_state_get_fighter_ro_safe (const lw6ker_game_state_t * game_state,
+				       int32_t x, int32_t y, int32_t z)
+{
+  const lw6ker_fighter_t *ret = NULL;
+  int fighter_id;
+
+  if (x >= 0
+      && x < ((_lw6ker_game_state_t *) game_state)->map_state.shape.w
+      && y >= 0 &&
+      y < ((_lw6ker_game_state_t *) game_state)->map_state.shape.h
+      && z >= 0
+      && z < ((_lw6ker_game_state_t *) game_state)->map_state.shape.d)
+    {
+      fighter_id = lw6ker_game_state_get_fighter_id (game_state, x, y, z);
+      if (fighter_id >= 0)
+	{
+	  ret =
+	    lw6ker_game_state_get_fighter_ro_by_id (game_state, fighter_id);
+	}
+    }
+
+  return ret;
+};
+
+/**
+ * lw6ker_game_state_get_fighter_ro_unsafe
+ *
+ * @game_state: game_state to query
+ * @x: x position
+ * @y: y position
+ * @z: z position
+ *
+ * Gets a fighter by its position. This function will not check for boundaries, if there's
+ * no fighter in this place, not only will it probably not return a valid value, but it will also
+ * even segfault before that, trying to access non-existing structures in menory. So only
+ * call this if you're sure there's a fighter here.
+ * Pointer is read-only.
+ *
+ * Return value: pointer to the fighter at this position, or NULL if none.
+ */
+const lw6ker_fighter_t *
+lw6ker_game_state_get_fighter_ro_unsafe (const lw6ker_game_state_t *
+					 game_state, int32_t x, int32_t y,
+					 int32_t z)
+{
+  return
+    _lw6ker_map_state_get_fighter_ro_unsafe (&
+					     (((const _lw6ker_game_state_t *)
+					       game_state)->map_state), x, y,
+					     z);
 }
 
 /**
@@ -2309,7 +2446,7 @@ lw6ker_game_state_get_fighter_unsafe (lw6ker_game_state_t * game_state,
  * Return value: the potential
  */
 int
-lw6ker_game_state_get_zone_potential (lw6ker_game_state_t * game_state,
+lw6ker_game_state_get_zone_potential (const lw6ker_game_state_t * game_state,
 				      int i, int team_id)
 {
   return ((_lw6ker_game_state_t *) game_state)->map_state.
@@ -2329,12 +2466,12 @@ lw6ker_game_state_get_zone_potential (lw6ker_game_state_t * game_state,
  * Return value: integer value.
  */
 int
-lw6ker_game_state_get_charge_per1000 (lw6ker_game_state_t * game_state,
+lw6ker_game_state_get_charge_per1000 (const lw6ker_game_state_t * game_state,
 				      int team_color)
 {
   return
     _lw6ker_team_get_charge_per1000 (&
-				     (((_lw6ker_game_state_t *)
+				     (((const _lw6ker_game_state_t *)
 				       game_state)->map_state.
 				      teams[team_color]));
 }
@@ -2352,13 +2489,13 @@ lw6ker_game_state_get_charge_per1000 (lw6ker_game_state_t * game_state,
  * Return value: integer value.
  */
 int
-lw6ker_game_state_get_weapon_per1000_left (lw6ker_game_state_t * game_state,
-					   int team_color)
+lw6ker_game_state_get_weapon_per1000_left (const lw6ker_game_state_t *
+					   game_state, int team_color)
 {
   return
     _lw6ker_map_state_get_weapon_per1000_left (&
-					       (((_lw6ker_game_state_t *)
-						 game_state)->map_state),
+					       (((const _lw6ker_game_state_t
+						  *) game_state)->map_state),
 					       lw6ker_game_state_get_rounds
 					       (game_state), team_color);
 }
@@ -2380,14 +2517,14 @@ lw6ker_game_state_get_weapon_per1000_left (lw6ker_game_state_t * game_state,
  * Return value: 1 if found, 0 if not.
  */
 int
-lw6ker_game_state_get_latest_weapon (lw6ker_game_state_t *
+lw6ker_game_state_get_latest_weapon (const lw6ker_game_state_t *
 				     game_state,
 				     int *team_color,
 				     int *weapon_id, int *per1000_left)
 {
   return
     _lw6ker_weapon_get_latest_weapon (&
-				      (((_lw6ker_game_state_t *)
+				      (((const _lw6ker_game_state_t *)
 					game_state)->map_state),
 				      lw6ker_game_state_get_rounds
 				      (game_state), team_color, weapon_id,
