@@ -32,8 +32,9 @@
 
 int
 _lw6ker_map_state_init (_lw6ker_map_state_t * map_state,
-			_lw6ker_map_struct_t * map_struct,
-			lw6map_rules_t * rules, lw6sys_progress_t * progress)
+			const _lw6ker_map_struct_t * map_struct,
+			const lw6map_rules_t * rules,
+			lw6sys_progress_t * progress)
 {
   int ret = 0;
   int32_t i;
@@ -104,7 +105,8 @@ _lw6ker_map_state_clear (_lw6ker_map_state_t * map_state)
 }
 
 int
-_lw6ker_map_state_sync (_lw6ker_map_state_t * dst, _lw6ker_map_state_t * src)
+_lw6ker_map_state_sync (_lw6ker_map_state_t * dst,
+			const _lw6ker_map_state_t * src)
 {
   int ret = 0;
 
@@ -138,13 +140,13 @@ _lw6ker_map_state_sync (_lw6ker_map_state_t * dst, _lw6ker_map_state_t * src)
 }
 
 void
-_lw6ker_map_state_update_checksum (_lw6ker_map_state_t * map_state,
+_lw6ker_map_state_update_checksum (const _lw6ker_map_state_t * map_state,
 				   u_int32_t * checksum)
 {
   int i;
   /*
    * No need to compute map_struct checksum again, it's done
-   * within game_state_update_checksum which itself calls 
+   * within game_state_update_checksum which itself calls
    * game_struct_update_checksum.
    */
   lw6sys_checksum_update_whd (checksum, &(map_state->shape));
@@ -164,7 +166,7 @@ _lw6ker_map_state_update_checksum (_lw6ker_map_state_t * map_state,
 }
 
 int
-_lw6ker_map_state_get_free_team_color (_lw6ker_map_state_t * map_state)
+_lw6ker_map_state_get_free_team_color (const _lw6ker_map_state_t * map_state)
 {
   int32_t i;
   int32_t ret = LW6MAP_TEAM_COLOR_INVALID;
@@ -185,7 +187,7 @@ _lw6ker_map_state_populate_team (_lw6ker_map_state_t * map_state,
 				 int32_t team_color,
 				 int32_t nb_fighters,
 				 lw6sys_xyz_t desired_center,
-				 lw6map_rules_t * rules)
+				 const lw6map_rules_t * rules)
 {
   lw6sys_xyz_t real_center;
   int32_t angle, radius;
@@ -259,7 +261,7 @@ _lw6ker_map_state_redistribute_team (_lw6ker_map_state_t * map_state,
 				     int32_t dst_team_color,
 				     int32_t src_team_color,
 				     int32_t nb_fighters,
-				     lw6map_rules_t * rules)
+				     const lw6map_rules_t * rules)
 {
   int ret = 0;
   int32_t i, j;
@@ -523,7 +525,7 @@ _lw6ker_map_state_remove_team_fighters (_lw6ker_map_state_t * map_state,
 }
 
 int
-_lw6ker_map_state_sanity_check (_lw6ker_map_state_t * map_state)
+_lw6ker_map_state_sanity_check (const _lw6ker_map_state_t * map_state)
 {
   int ret = 1;
   int32_t i;
@@ -612,8 +614,8 @@ _lw6ker_map_state_sanity_check (_lw6ker_map_state_t * map_state)
  */
 void
 _lw6ker_map_state_spread_gradient (_lw6ker_map_state_t * map_state,
-				   lw6map_rules_t * rules, int32_t nb_spreads,
-				   u_int32_t team_mask)
+				   const lw6map_rules_t * rules,
+				   int32_t nb_spreads, u_int32_t team_mask)
 {
   int i;
   int teams_concerned[LW6MAP_MAX_NB_TEAMS];
@@ -682,7 +684,7 @@ _lw6ker_map_state_get_nb_teams (const _lw6ker_map_state_t * map_state)
 
 void
 _lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state, int round,
-				 int parity, lw6map_rules_t * rules,
+				 int parity, const lw6map_rules_t * rules,
 				 int32_t nb_moves, u_int32_t team_mask)
 {
   _lw6ker_move_context_t context;
@@ -926,7 +928,8 @@ _lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state, int round,
 
 void
 _lw6ker_map_state_apply_cursors (_lw6ker_map_state_t * map_state,
-				 lw6map_rules_t * rules, u_int32_t team_mask)
+				 const lw6map_rules_t * rules,
+				 u_int32_t team_mask)
 {
   int32_t i, team_color;
   int32_t zone_id = -1;
@@ -1062,7 +1065,7 @@ _lw6ker_map_state_apply_cursors (_lw6ker_map_state_t * map_state,
 
 void
 _lw6ker_map_state_process_fire (_lw6ker_map_state_t * map_state,
-				lw6map_rules_t * rules, int round)
+				const lw6map_rules_t * rules, int round)
 {
   int32_t i, team_color;
   int charge_percent;
@@ -1318,7 +1321,7 @@ _lw6ker_map_state_frag (_lw6ker_map_state_t * map_state, int team_color,
 
 void
 _lw6ker_map_state_charge (_lw6ker_map_state_t * map_state,
-			  lw6map_rules_t * rules, int round)
+			  const lw6map_rules_t * rules, int round)
 {
   int32_t team_color;
   int charge_incr = 0;
@@ -1387,8 +1390,8 @@ _lw6ker_map_state_charge (_lw6ker_map_state_t * map_state,
 }
 
 int
-_lw6ker_map_state_is_this_weapon_active (_lw6ker_map_state_t * map_state,
-					 int round, int weapon_id,
+_lw6ker_map_state_is_this_weapon_active (const _lw6ker_map_state_t *
+					 map_state, int round, int weapon_id,
 					 int team_color)
 {
   return _lw6ker_team_is_this_weapon_active (&(map_state->teams[team_color]),
@@ -1396,8 +1399,9 @@ _lw6ker_map_state_is_this_weapon_active (_lw6ker_map_state_t * map_state,
 }
 
 int
-_lw6ker_map_state_get_weapon_per1000_left (_lw6ker_map_state_t * map_state,
-					   int round, int team_color)
+_lw6ker_map_state_get_weapon_per1000_left (const _lw6ker_map_state_t *
+					   map_state, int round,
+					   int team_color)
 {
   return
     _lw6ker_team_get_weapon_per1000_left (&(map_state->teams[team_color]),
