@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-  
+
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -61,7 +61,7 @@ typedef struct draft_zones_s
 draft_zones_t;
 
 void
-_lw6ker_map_struct_update_checksum (_lw6ker_map_struct_t *
+_lw6ker_map_struct_update_checksum (const _lw6ker_map_struct_t *
 				    map_struct, u_int32_t * checksum)
 {
   int i;
@@ -88,8 +88,8 @@ _lw6ker_map_struct_update_checksum (_lw6ker_map_struct_t *
 }
 
 int
-_lw6ker_map_struct_lazy_compare (_lw6ker_map_struct_t *
-				 map_struct_a, _lw6ker_map_struct_t *
+_lw6ker_map_struct_lazy_compare (const _lw6ker_map_struct_t *
+				 map_struct_a, const _lw6ker_map_struct_t *
 				 map_struct_b)
 {
   int ret = 0;
@@ -123,7 +123,7 @@ _lw6ker_map_struct_lazy_compare (_lw6ker_map_struct_t *
 }
 
 static int32_t
-relative_index_no_check (lw6map_level_t * level, int32_t x, int32_t y,
+relative_index_no_check (const lw6map_level_t * level, int32_t x, int32_t y,
 			 int32_t z)
 {
   return z * level->body.shape.w * level->body.shape.h +
@@ -131,7 +131,7 @@ relative_index_no_check (lw6map_level_t * level, int32_t x, int32_t y,
 }
 
 static int32_t
-relative_index (lw6map_level_t * level, int32_t x, int32_t y, int32_t z)
+relative_index (const lw6map_level_t * level, int32_t x, int32_t y, int32_t z)
 {
   lw6map_coords_fix_xy (&(level->param.rules), &(level->body.shape), &x, &y);
   lw6map_coords_fix_z (&(level->param.rules), &(level->body.shape), &z);
@@ -148,7 +148,7 @@ relative_index (lw6map_level_t * level, int32_t x, int32_t y, int32_t z)
  * optimized afterwards.
  */
 static draft_zones_t *
-draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
+draft_zones_new (const lw6map_level_t * level, lw6sys_progress_t * progress)
 {
   draft_zones_t *ret;
 
@@ -314,7 +314,7 @@ draft_zones_free (draft_zones_t * draft_zones)
  * we suppress.
  */
 static int32_t
-draft_zones_group (lw6map_level_t * level, draft_zones_t * draft_zones,
+draft_zones_group (const lw6map_level_t * level, draft_zones_t * draft_zones,
 		   int32_t step)
 {
   int32_t found = 0;
@@ -546,7 +546,7 @@ draft_zones_group (lw6map_level_t * level, draft_zones_t * draft_zones,
 }
 
 static int
-_fix_one_way (_lw6ker_map_struct_t * map_struct, lw6map_level_t * level)
+_fix_one_way (_lw6ker_map_struct_t * map_struct, const lw6map_level_t * level)
 {
   int ret = 0;
   int x, y;
@@ -826,7 +826,7 @@ draft_zones_to_map_struct (_lw6ker_map_struct_t * map_struct,
  * Init places, that is, mostly read and aggregate meta-layer info
  */
 static int
-init_places (_lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
+init_places (_lw6ker_map_struct_t * map_struct, const lw6map_level_t * level,
 	     lw6sys_progress_t * progress)
 {
   int ret = 0;
@@ -863,7 +863,7 @@ init_places (_lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
 				 (map_struct, x, y)].act_incr =
 		_LW6KER_ACT_LIMIT;
 	      /*
-	       * no need to set health_correction to 0, was done 
+	       * no need to set health_correction to 0, was done
 	       * by the CALLOC
 	       */
 	    }
@@ -992,7 +992,7 @@ init_places (_lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
  * have a quick way to get the right zone for a given (x,y).
  */
 static int
-init_slots (_lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
+init_slots (_lw6ker_map_struct_t * map_struct, const lw6map_level_t * level,
 	    lw6sys_progress_t * progress)
 {
   int ret = 0;
@@ -1066,7 +1066,7 @@ init_slots (_lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
  * of wether it's usefull to implement this. Debugging tool.
  */
 float
-_lw6ker_map_struct_get_compression (_lw6ker_map_struct_t * map_struct)
+_lw6ker_map_struct_get_compression (const _lw6ker_map_struct_t * map_struct)
 {
   float ret = 0.0f;
 
@@ -1085,7 +1085,8 @@ _lw6ker_map_struct_get_compression (_lw6ker_map_struct_t * map_struct)
  */
 int
 _lw6ker_map_struct_init (_lw6ker_map_struct_t * map_struct,
-			 lw6map_level_t * level, lw6sys_progress_t * progress)
+			 const lw6map_level_t * level,
+			 lw6sys_progress_t * progress)
 {
   int ret = 0;
   draft_zones_t *draft_zones;
@@ -1180,8 +1181,8 @@ _lw6ker_map_struct_clear (_lw6ker_map_struct_t * map_struct)
 }
 
 void
-_lw6ker_map_struct_find_free_slot_near (_lw6ker_map_struct_t * map_struct,
-					lw6sys_xyz_t * there,
+_lw6ker_map_struct_find_free_slot_near (const _lw6ker_map_struct_t *
+					map_struct, lw6sys_xyz_t * there,
 					lw6sys_xyz_t here)
 {
   int found = 0;
@@ -1244,7 +1245,7 @@ _lw6ker_map_struct_find_free_slot_near (_lw6ker_map_struct_t * map_struct,
 }
 
 int
-_lw6ker_map_struct_sanity_check (_lw6ker_map_struct_t * map_struct)
+_lw6ker_map_struct_sanity_check (const _lw6ker_map_struct_t * map_struct)
 {
   int ret = 1;
   int x, y, z, w, h, d;
