@@ -53,8 +53,8 @@
 #endif // LW6_GPROF || LW6_INSTRUMENT || LW6_PROFILER
 
 static inline int
-_is_slot_free (_lw6ker_map_struct_t * map_struct,
-	       _lw6ker_map_state_t * map_state, int32_t x, int32_t y,
+_is_slot_free (const _lw6ker_map_struct_t * map_struct,
+	       const _lw6ker_map_state_t * map_state, int32_t x, int32_t y,
 	       int32_t z)
 {
   /*
@@ -68,16 +68,16 @@ _is_slot_free (_lw6ker_map_struct_t * map_struct,
 }
 
 int
-_lw6ker_move_is_slot_free (_lw6ker_map_struct_t * map_struct,
-			   _lw6ker_map_state_t * map_state, int32_t x,
+_lw6ker_move_is_slot_free (const _lw6ker_map_struct_t * map_struct,
+			   const _lw6ker_map_state_t * map_state, int32_t x,
 			   int32_t y, int32_t z)
 {
   return _is_slot_free (map_struct, map_state, x, y, z);
 }
 
 static inline int
-_is_enemy_there (_lw6ker_map_struct_t * map_struct,
-		 _lw6ker_map_state_t * map_state, int32_t team_color,
+_is_enemy_there (const _lw6ker_map_struct_t * map_struct,
+		 const _lw6ker_map_state_t * map_state, int32_t team_color,
 		 int32_t x, int32_t y, int32_t z, int32_t * enemy_id,
 		 int32_t * enemy_color)
 {
@@ -101,8 +101,8 @@ _is_enemy_there (_lw6ker_map_struct_t * map_struct,
 }
 
 int
-_lw6ker_move_is_enemy_there (_lw6ker_map_struct_t * map_struct,
-			     _lw6ker_map_state_t * map_state,
+_lw6ker_move_is_enemy_there (const _lw6ker_map_struct_t * map_struct,
+			     const _lw6ker_map_state_t * map_state,
 			     int32_t team_color, int32_t x, int32_t y,
 			     int32_t z, int32_t * enemy_id,
 			     int32_t * enemy_color)
@@ -112,8 +112,8 @@ _lw6ker_move_is_enemy_there (_lw6ker_map_struct_t * map_struct,
 }
 
 static inline int
-_is_ally_there (_lw6ker_map_struct_t * map_struct,
-		_lw6ker_map_state_t * map_state, int32_t team_color,
+_is_ally_there (const _lw6ker_map_struct_t * map_struct,
+		const _lw6ker_map_state_t * map_state, int32_t team_color,
 		int32_t x, int32_t y, int32_t z)
 {
   int ret = 0;
@@ -139,8 +139,8 @@ _is_ally_there (_lw6ker_map_struct_t * map_struct,
 }
 
 int
-_lw6ker_move_is_ally_there (_lw6ker_map_struct_t * map_struct,
-			    _lw6ker_map_state_t * map_state,
+_lw6ker_move_is_ally_there (const _lw6ker_map_struct_t * map_struct,
+			    const _lw6ker_map_state_t * map_state,
 			    int32_t team_color, int32_t x, int32_t y,
 			    int32_t z)
 {
@@ -186,8 +186,8 @@ _lw6ker_move_find_straight_dir (int from_x, int from_y, lw6sys_xyz_t to,
  * Higher potential = closer to the cursor
  */
 static inline int32_t
-_find_best_dir (_lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
-		int parity)
+_find_best_dir (const _lw6ker_map_state_t * map_state,
+		const lw6ker_fighter_t * fighter, int parity)
 {
   int32_t ret = fighter->last_direction;
   int32_t zone_id =
@@ -309,14 +309,14 @@ _find_best_dir (_lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
 }
 
 int32_t
-_lw6ker_move_find_best_dir (_lw6ker_map_state_t * map_state,
-			    lw6ker_fighter_t * fighter, int parity)
+_lw6ker_move_find_best_dir (const _lw6ker_map_state_t * map_state,
+			    const lw6ker_fighter_t * fighter, int parity)
 {
   return _find_best_dir (map_state, fighter, parity);
 }
 
 static inline void
-_goto_with_dir_xy (lw6map_rules_t * rules, lw6sys_whd_t * shape,
+_goto_with_dir_xy (const lw6map_rules_t * rules, const lw6sys_whd_t * shape,
 		   int32_t * dst_x, int32_t * dst_y, int32_t src_x,
 		   int32_t src_y, int32_t move_dir)
 {
@@ -331,8 +331,8 @@ _goto_with_dir_xy (lw6map_rules_t * rules, lw6sys_whd_t * shape,
 }
 
 void
-_lw6ker_move_goto_with_dir_xy (lw6map_rules_t * rules,
-			       lw6sys_whd_t * shape, int32_t * dst_x,
+_lw6ker_move_goto_with_dir_xy (const lw6map_rules_t * rules,
+			       const lw6sys_whd_t * shape, int32_t * dst_x,
 			       int32_t * dst_y, int32_t src_x,
 			       int32_t src_y, int32_t move_dir)
 {
@@ -340,7 +340,7 @@ _lw6ker_move_goto_with_dir_xy (lw6map_rules_t * rules,
 }
 
 static inline void
-_goto_with_dir_z (lw6map_rules_t * rules, lw6sys_whd_t * shape,
+_goto_with_dir_z (const lw6map_rules_t * rules, const lw6sys_whd_t * shape,
 		  int32_t * dst_z, int32_t src_z, int32_t move_dir)
 {
   (*dst_z) = src_z + _LW6KER_TABLES_MOVE_Z_OFFSET[move_dir];
@@ -352,15 +352,15 @@ _goto_with_dir_z (lw6map_rules_t * rules, lw6sys_whd_t * shape,
 }
 
 void
-_lw6ker_move_goto_with_dir_z (lw6map_rules_t * rules, lw6sys_whd_t * shape,
-			      int32_t * dst_z, int32_t src_z,
-			      int32_t move_dir)
+_lw6ker_move_goto_with_dir_z (const lw6map_rules_t * rules,
+			      const lw6sys_whd_t * shape, int32_t * dst_z,
+			      int32_t src_z, int32_t move_dir)
 {
   _goto_with_dir_z (rules, shape, dst_z, src_z, move_dir);
 }
 
 static inline void
-_goto_with_dir (lw6map_rules_t * rules, lw6sys_whd_t * shape,
+_goto_with_dir (const lw6map_rules_t * rules, const lw6sys_whd_t * shape,
 		int32_t * dst_x, int32_t * dst_y, int32_t * dst_z,
 		int32_t src_x, int32_t src_y, int32_t src_z, int32_t move_dir)
 {
@@ -377,10 +377,10 @@ _goto_with_dir (lw6map_rules_t * rules, lw6sys_whd_t * shape,
 }
 
 void
-_lw6ker_move_goto_with_dir (lw6map_rules_t * rules, lw6sys_whd_t * shape,
-			    int32_t * dst_x, int32_t * dst_y,
-			    int32_t * dst_z, int32_t src_x, int32_t src_y,
-			    int32_t src_z, int32_t move_dir)
+_lw6ker_move_goto_with_dir (const lw6map_rules_t * rules,
+			    const lw6sys_whd_t * shape, int32_t * dst_x,
+			    int32_t * dst_y, int32_t * dst_z, int32_t src_x,
+			    int32_t src_y, int32_t src_z, int32_t move_dir)
 {
   _goto_with_dir (rules, shape,
 		  dst_x, dst_y, dst_z, src_x, src_y, src_z, move_dir);
@@ -639,16 +639,17 @@ _lw6ker_move_update_fighters_universal (_lw6ker_move_context_t * context)
  * slow function, only for external use
  */
 int
-_lw6ker_move_get_best_next_pos (_lw6ker_game_state_t * game_state,
+_lw6ker_move_get_best_next_pos (const _lw6ker_game_state_t * game_state,
 				lw6sys_xyz_t * next_pos,
 				lw6sys_xyz_t * current_pos, int team_color)
 {
-  _lw6ker_map_state_t *map_state = &(game_state->map_state);
-  _lw6ker_map_struct_t *map_struct = map_state->map_struct;
-  lw6map_rules_t *rules = &(game_state->game_struct->rules);
-  lw6sys_whd_t *shape = &(map_struct->shape);
+  const _lw6ker_map_state_t *map_state = &(game_state->map_state);
+  const _lw6ker_map_struct_t *map_struct = map_state->map_struct;
+  const lw6map_rules_t *rules = &(game_state->game_struct->rules);
+  const lw6sys_whd_t *shape = &(map_struct->shape);
   int32_t zone_id;
-  _lw6ker_zone_state_t *zone_states = map_state->teams[team_color].gradient;
+  const _lw6ker_zone_state_t *zone_states =
+    map_state->teams[team_color].gradient;
   int best_direction = -1;
   lw6sys_xyz_t start_pos;
   lw6sys_xyz_t target;
@@ -805,10 +806,11 @@ _lw6ker_move_get_best_next_pos (_lw6ker_game_state_t * game_state,
  * Return value: 1 if best place found, 0 if not.
  */
 int
-lw6ker_move_get_best_next_pos (lw6ker_game_state_t * game_state,
+lw6ker_move_get_best_next_pos (const lw6ker_game_state_t * game_state,
 			       lw6sys_xyz_t * next_pos,
 			       lw6sys_xyz_t * current_pos, int team_color)
 {
-  return _lw6ker_move_get_best_next_pos ((_lw6ker_game_state_t *) game_state,
-					 next_pos, current_pos, team_color);
+  return _lw6ker_move_get_best_next_pos ((const _lw6ker_game_state_t *)
+					 game_state, next_pos, current_pos,
+					 team_color);
 }
