@@ -28,8 +28,8 @@
 #include "ker-internal.h"
 
 void
-_lw6ker_place_struct_update_checksum (_lw6ker_place_struct_t * place_struct,
-				      u_int32_t * checksum)
+_lw6ker_place_struct_update_checksum (const _lw6ker_place_struct_t *
+				      place_struct, u_int32_t * checksum)
 {
   lw6sys_checksum_update_int32 (checksum, place_struct->act_incr);
   lw6sys_checksum_update_int32 (checksum, place_struct->health_correction);
