@@ -28,7 +28,7 @@
 #include "ker-internal.h"
 
 void
-_lw6ker_zone_state_update_checksum (_lw6ker_zone_state_t * zone_state,
+_lw6ker_zone_state_update_checksum (const _lw6ker_zone_state_t * zone_state,
 				    u_int32_t * checksum)
 {
   lw6sys_checksum_update_int32 (checksum, zone_state->potential);
