@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-  
+
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -175,7 +175,7 @@ typedef struct lw6ker_score_s
   int has_been_active;
   /// The color of the team this score is about.
   int team_color;
-  /** 
+  /**
    * Percentage of fighters for this team. The global score
    * array object will take care of making the sum of
    * fighters_percent be exactly 100, regardless of exactitude,
@@ -294,7 +294,7 @@ typedef struct lw6ker_game_state_s
 lw6ker_game_state_t;
 
 /* ker-capture.c */
-extern char *lw6ker_capture_str (lw6ker_game_state_t * game_state);
+extern char *lw6ker_capture_str (const lw6ker_game_state_t * game_state);
 
 /* ker-checksumlog.c */
 extern void lw6ker_game_state_checksum_log_set_interval (lw6ker_game_state_t *
@@ -306,31 +306,32 @@ extern void lw6ker_game_state_checksum_log_set_interval (lw6ker_game_state_t *
 extern void lw6ker_cursor_reset (lw6ker_cursor_t * cursor);
 
 /* ker-gamestate.c */
-extern lw6ker_game_state_t *lw6ker_game_state_new (lw6ker_game_struct_t *
-						   game_struct,
+extern lw6ker_game_state_t *lw6ker_game_state_new (const lw6ker_game_struct_t
+						   * game_struct,
 						   lw6sys_progress_t *
 						   progress);
 extern void lw6ker_game_state_free (lw6ker_game_state_t * game_state);
 extern void lw6ker_game_state_point_to (lw6ker_game_state_t * game_state,
-					lw6ker_game_struct_t * game_struct);
+					const lw6ker_game_struct_t *
+					game_struct);
 extern int lw6ker_game_state_memory_footprint (lw6ker_game_state_t *
 					       game_state);
-extern char *lw6ker_game_state_repr (lw6ker_game_state_t * game_state);
+extern char *lw6ker_game_state_repr (const lw6ker_game_state_t * game_state);
 extern int lw6ker_game_state_can_sync (lw6ker_game_state_t * dst,
-				       lw6ker_game_state_t * src);
+				       const lw6ker_game_state_t * src);
 extern int lw6ker_game_state_sync (lw6ker_game_state_t * dst,
-				   lw6ker_game_state_t * src);
-extern lw6ker_game_state_t *lw6ker_game_state_dup (lw6ker_game_state_t *
+				   const lw6ker_game_state_t * src);
+extern lw6ker_game_state_t *lw6ker_game_state_dup (const lw6ker_game_state_t *
 						   game_state,
 						   lw6sys_progress_t *
 						   progress);
-extern u_int32_t lw6ker_game_state_checksum (lw6ker_game_state_t *
+extern u_int32_t lw6ker_game_state_checksum (const lw6ker_game_state_t *
 					     game_state);
-extern void lw6ker_game_state_get_shape (lw6ker_game_state_t * game_state,
-					 lw6sys_whd_t * shape);
-extern int lw6ker_game_state_get_w (lw6ker_game_state_t * game_state);
-extern int lw6ker_game_state_get_h (lw6ker_game_state_t * game_state);
-extern int lw6ker_game_state_get_d (lw6ker_game_state_t * game_state);
+extern void lw6ker_game_state_get_shape (const lw6ker_game_state_t *
+					 game_state, lw6sys_whd_t * shape);
+extern int lw6ker_game_state_get_w (const lw6ker_game_state_t * game_state);
+extern int lw6ker_game_state_get_h (const lw6ker_game_state_t * game_state);
+extern int lw6ker_game_state_get_d (const lw6ker_game_state_t * game_state);
 extern int lw6ker_game_state_register_node (lw6ker_game_state_t *
 					    game_state, u_int64_t node_id);
 extern int lw6ker_game_state_unregister_node (lw6ker_game_state_t *
@@ -346,82 +347,113 @@ extern int lw6ker_game_state_add_cursor (lw6ker_game_state_t * game_state,
 extern int lw6ker_game_state_remove_cursor (lw6ker_game_state_t * game_state,
 					    u_int64_t node_id,
 					    u_int16_t cursor_id);
-extern int lw6ker_game_state_cursor_exists (lw6ker_game_state_t * game_state,
-					    u_int16_t cursor_id);
-extern int lw6ker_game_state_get_cursor (lw6ker_game_state_t *
+extern int lw6ker_game_state_cursor_exists (const lw6ker_game_state_t *
+					    game_state, u_int16_t cursor_id);
+extern int lw6ker_game_state_get_cursor (const lw6ker_game_state_t *
 					 game_state, lw6ker_cursor_t * cursor,
 					 u_int16_t cursor_id);
-extern void lw6ker_game_state_get_cursor_by_index (lw6ker_game_state_t *
+extern void lw6ker_game_state_get_cursor_by_index (const lw6ker_game_state_t *
 						   game_state,
 						   lw6ker_cursor_t * cursor,
 						   int i);
 extern int lw6ker_game_state_set_cursor (lw6ker_game_state_t * game_state,
 					 lw6ker_cursor_t * cursor);
-extern int lw6ker_game_state_team_exists (lw6ker_game_state_t * game_state,
-					  int team_color);
-extern int lw6ker_game_state_get_team_info (lw6ker_game_state_t * game_state,
-					    int team_color,
+extern int lw6ker_game_state_team_exists (const lw6ker_game_state_t *
+					  game_state, int team_color);
+extern int lw6ker_game_state_get_team_info (const lw6ker_game_state_t *
+					    game_state, int team_color,
 					    int32_t * nb_cursors,
 					    int32_t * nb_fighters);
-extern int lw6ker_game_state_get_nb_teams (lw6ker_game_state_t * game_state);
-extern void lw6ker_game_state_do_spread (lw6ker_game_state_t *
-					 game_state, u_int32_t team_mask);
-extern void lw6ker_game_state_do_move (lw6ker_game_state_t *
-				       game_state, u_int32_t team_mask);
+extern int lw6ker_game_state_get_nb_teams (const lw6ker_game_state_t *
+					   game_state);
+extern void lw6ker_game_state_do_spread (lw6ker_game_state_t * game_state,
+					 u_int32_t team_mask);
+extern void lw6ker_game_state_do_move (lw6ker_game_state_t * game_state,
+				       u_int32_t team_mask);
 extern void lw6ker_game_state_finish_round (lw6ker_game_state_t * game_state);
 extern void lw6ker_game_state_do_round (lw6ker_game_state_t * game_state);
-extern u_int32_t lw6ker_game_state_get_moves (lw6ker_game_state_t *
+extern u_int32_t lw6ker_game_state_get_moves (const lw6ker_game_state_t *
 					      game_state);
-extern u_int32_t lw6ker_game_state_get_spreads (lw6ker_game_state_t *
+extern u_int32_t lw6ker_game_state_get_spreads (const lw6ker_game_state_t *
 						game_state);
-extern u_int32_t lw6ker_game_state_get_rounds (lw6ker_game_state_t *
+extern u_int32_t lw6ker_game_state_get_rounds (const lw6ker_game_state_t *
 					       game_state);
-extern u_int32_t lw6ker_game_state_get_total_rounds (lw6ker_game_state_t *
-						     game_state);
-extern int lw6ker_game_state_is_over (lw6ker_game_state_t * game_state);
-extern int lw6ker_game_state_did_cursor_win (lw6ker_game_state_t * game_state,
-					     u_int16_t cursor_id);
-extern int lw6ker_game_state_get_winner (lw6ker_game_state_t * game_state,
-					 int excluded_team);
-extern int lw6ker_game_state_get_looser (lw6ker_game_state_t * game_state,
-					 int excluded_team);
-extern int32_t lw6ker_game_state_get_nb_active_fighters (lw6ker_game_state_t *
+extern u_int32_t lw6ker_game_state_get_total_rounds (const lw6ker_game_state_t
+						     * game_state);
+extern int lw6ker_game_state_is_over (const lw6ker_game_state_t * game_state);
+extern int lw6ker_game_state_did_cursor_win (const lw6ker_game_state_t *
+					     game_state, u_int16_t cursor_id);
+extern int lw6ker_game_state_get_winner (const lw6ker_game_state_t *
+					 game_state, int excluded_team);
+extern int lw6ker_game_state_get_looser (const lw6ker_game_state_t *
+					 game_state, int excluded_team);
+extern int32_t lw6ker_game_state_get_nb_active_fighters (const
+							 lw6ker_game_state_t *
 							 game_state);
-extern int32_t lw6ker_game_state_get_time_elapsed (lw6ker_game_state_t *
+extern int32_t lw6ker_game_state_get_time_elapsed (const lw6ker_game_state_t *
 						   game_state);
-extern int32_t lw6ker_game_state_get_time_left (lw6ker_game_state_t *
+extern int32_t lw6ker_game_state_get_time_left (const lw6ker_game_state_t *
 						game_state);
-extern int32_t lw6ker_game_state_get_global_history (lw6ker_game_state_t *
-						     game_state, int i,
+extern int32_t lw6ker_game_state_get_global_history (const lw6ker_game_state_t
+						     * game_state, int i,
 						     int team_id);
-extern int32_t lw6ker_game_state_get_latest_history (lw6ker_game_state_t *
-						     game_state, int i,
+extern int32_t lw6ker_game_state_get_latest_history (const lw6ker_game_state_t
+						     * game_state, int i,
 						     int team_id);
-extern int32_t lw6ker_game_state_get_global_history_max (lw6ker_game_state_t *
+extern int32_t lw6ker_game_state_get_global_history_max (const
+							 lw6ker_game_state_t *
 							 game_state);
-extern int32_t lw6ker_game_state_get_latest_history_max (lw6ker_game_state_t *
+extern int32_t lw6ker_game_state_get_latest_history_max (const
+							 lw6ker_game_state_t *
 							 game_state);
-extern int32_t lw6ker_game_state_get_fighter_id (lw6ker_game_state_t *
+extern int32_t lw6ker_game_state_get_fighter_id (const lw6ker_game_state_t *
 						 game_state, int32_t x,
 						 int32_t y, int32_t z);
 extern lw6ker_fighter_t
-  * lw6ker_game_state_get_fighter_by_id (lw6ker_game_state_t * game_state,
-					 int32_t fighter_id);
+  * lw6ker_game_state_get_fighter_rw_by_id (lw6ker_game_state_t * game_state,
+					    int32_t fighter_id);
 extern lw6ker_fighter_t
-  * lw6ker_game_state_get_fighter_safe (lw6ker_game_state_t * game_state,
-					int32_t x, int32_t y, int32_t z);
+  * lw6ker_game_state_get_fighter_rw_safe (lw6ker_game_state_t * game_state,
+					   int32_t x, int32_t y, int32_t z);
 extern lw6ker_fighter_t
-  * lw6ker_game_state_get_fighter_unsafe (lw6ker_game_state_t * game_state,
-					  int32_t x, int32_t y, int32_t z);
-extern int lw6ker_game_state_get_zone_potential (lw6ker_game_state_t *
+  * lw6ker_game_state_get_fighter_rw_unsafe (lw6ker_game_state_t * game_state,
+					     int32_t x, int32_t y, int32_t z);
+extern const lw6ker_fighter_t *lw6ker_game_state_get_fighter_ro_by_id (const
+								       lw6ker_game_state_t
+								       *
+								       game_state,
+								       int32_t
+								       fighter_id);
+extern const lw6ker_fighter_t *lw6ker_game_state_get_fighter_ro_safe (const
+								      lw6ker_game_state_t
+								      *
+								      game_state,
+								      int32_t
+								      x,
+								      int32_t
+								      y,
+								      int32_t
+								      z);
+extern const lw6ker_fighter_t *lw6ker_game_state_get_fighter_ro_unsafe (const
+									lw6ker_game_state_t
+									*
+									game_state,
+									int32_t
+									x,
+									int32_t
+									y,
+									int32_t
+									z);
+extern int lw6ker_game_state_get_zone_potential (const lw6ker_game_state_t *
 						 game_state, int zone_i,
 						 int team_id);
-extern int lw6ker_game_state_get_charge_per1000 (lw6ker_game_state_t *
+extern int lw6ker_game_state_get_charge_per1000 (const lw6ker_game_state_t *
 						 game_state, int team_color);
-extern int lw6ker_game_state_get_weapon_per1000_left (lw6ker_game_state_t *
+extern int lw6ker_game_state_get_weapon_per1000_left (const
+						      lw6ker_game_state_t *
 						      game_state,
 						      int team_color);
-extern int lw6ker_game_state_get_latest_weapon (lw6ker_game_state_t *
+extern int lw6ker_game_state_get_latest_weapon (const lw6ker_game_state_t *
 						game_state, int *team_color,
 						int *weapon_id,
 						int *per1000_left);
@@ -433,63 +465,73 @@ extern int lw6ker_game_state_get_nb_nodes (const lw6ker_game_state_t *
 					   game_state);
 
 /* ker-gamestruct.c */
-extern lw6ker_game_struct_t *lw6ker_game_struct_new (lw6map_level_t * level,
+extern lw6ker_game_struct_t *lw6ker_game_struct_new (const lw6map_level_t *
+						     level,
 						     lw6sys_progress_t *
 						     progress);
 extern void lw6ker_game_struct_free (lw6ker_game_struct_t * game_struct);
 extern void lw6ker_game_struct_point_to (lw6ker_game_struct_t * game_struct,
-					 lw6map_level_t * level);
-extern int lw6ker_game_struct_memory_footprint (lw6ker_game_struct_t *
+					 const lw6map_level_t * level);
+extern int lw6ker_game_struct_memory_footprint (const lw6ker_game_struct_t *
 						game_struct);
-extern char *lw6ker_game_struct_repr (lw6ker_game_struct_t * game_struct);
-extern lw6ker_game_struct_t *lw6ker_game_struct_dup (lw6ker_game_struct_t *
+extern char *lw6ker_game_struct_repr (const lw6ker_game_struct_t *
+				      game_struct);
+extern lw6ker_game_struct_t *lw6ker_game_struct_dup (const
+						     lw6ker_game_struct_t *
 						     game_struct,
 						     lw6sys_progress_t *
 						     progress);
-extern u_int32_t lw6ker_game_struct_checksum (lw6ker_game_struct_t *
+extern u_int32_t lw6ker_game_struct_checksum (const lw6ker_game_struct_t *
 					      game_struct);
-extern void lw6ker_game_struct_get_shape (lw6ker_game_struct_t * game_struct,
-					  lw6sys_whd_t * shape);
-extern int lw6ker_game_struct_get_w (lw6ker_game_struct_t * game_struct);
-extern int lw6ker_game_struct_get_h (lw6ker_game_struct_t * game_struct);
-extern int lw6ker_game_struct_get_d (lw6ker_game_struct_t * game_struct);
-extern int lw6ker_game_struct_is_fg (lw6ker_game_struct_t * game_struct,
+extern void lw6ker_game_struct_get_shape (const lw6ker_game_struct_t *
+					  game_struct, lw6sys_whd_t * shape);
+extern int lw6ker_game_struct_get_w (const lw6ker_game_struct_t *
+				     game_struct);
+extern int lw6ker_game_struct_get_h (const lw6ker_game_struct_t *
+				     game_struct);
+extern int lw6ker_game_struct_get_d (const lw6ker_game_struct_t *
+				     game_struct);
+extern int lw6ker_game_struct_is_fg (const lw6ker_game_struct_t * game_struct,
 				     int32_t x, int32_t y, int32_t z);
-extern int lw6ker_game_struct_is_bg (lw6ker_game_struct_t * game_struct,
+extern int lw6ker_game_struct_is_bg (const lw6ker_game_struct_t * game_struct,
 				     int32_t x, int32_t y, int32_t z);
-extern void lw6ker_game_struct_get_zones_info (lw6ker_game_struct_t *
+extern void lw6ker_game_struct_get_zones_info (const lw6ker_game_struct_t *
 					       game_struct, int *nb_zones,
 					       int *max_zone_size);
-extern void lw6ker_game_struct_get_zone_info (lw6ker_game_struct_t *
+extern void lw6ker_game_struct_get_zone_info (const lw6ker_game_struct_t *
 					      game_struct, int i,
 					      lw6sys_xyz_t * zone_pos,
 					      int *zone_size);
-extern int32_t lw6ker_game_struct_get_zone_id (lw6ker_game_struct_t *
+extern int32_t lw6ker_game_struct_get_zone_id (const lw6ker_game_struct_t *
 					       game_struct, int32_t x,
 					       int32_t y, int32_t z);
-extern void lw6ker_game_struct_find_free_slot_near (lw6ker_game_struct_t *
-						    game_struct,
+extern void lw6ker_game_struct_find_free_slot_near (const lw6ker_game_struct_t
+						    * game_struct,
 						    lw6sys_xyz_t * there,
 						    lw6sys_xyz_t here);
 
 /* ker-hexa.c */
-extern char *lw6ker_game_struct_to_hexa (lw6ker_game_struct_t * game_struct);
+extern char *lw6ker_game_struct_to_hexa (const lw6ker_game_struct_t *
+					 game_struct);
 extern lw6ker_game_struct_t *lw6ker_game_struct_from_hexa (const char *hexa,
+							   const
 							   lw6map_level_t *
 							   level);
-extern char *lw6ker_game_state_to_hexa (lw6ker_game_state_t * game_state);
+extern char *lw6ker_game_state_to_hexa (const lw6ker_game_state_t *
+					game_state);
 extern lw6ker_game_state_t *lw6ker_game_state_from_hexa (const char *hexa,
+							 const
 							 lw6ker_game_struct_t
 							 * game_struct);
 
 /* ker-move.c */
-extern int lw6ker_move_get_best_next_pos (lw6ker_game_state_t * game_state,
-					  lw6sys_xyz_t * next_pos,
+extern int lw6ker_move_get_best_next_pos (const lw6ker_game_state_t *
+					  game_state, lw6sys_xyz_t * next_pos,
 					  lw6sys_xyz_t * current_pos,
 					  int team_color);
 /* ker-scorearray.c */
 extern int lw6ker_score_array_update (lw6ker_score_array_t * score_array,
-				      lw6ker_game_state_t * game_state);
+				      const lw6ker_game_state_t * game_state);
 
 /* ker-teammask.c */
 extern void lw6ker_team_mask_get (u_int32_t * even, u_int32_t * odd,
