@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-  
+
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -45,7 +45,7 @@ _scm_lw6pil_bench ()
   lw6sys_progress_default (&progress, &(lw6_global.progress));
   lw6sys_progress_begin (&progress);
 
-  if (lw6pil_bench (&c_ret, &progress))
+  if (lw6pil_bench (lw6_global.argc, lw6_global.argv, &c_ret, &progress))
     {
       ret = scm_from_int (ceil (c_ret));
     }
