@@ -224,7 +224,7 @@ lw6map_style_clear (lw6map_style_t * style)
  * Return value: none.
  */
 void
-lw6map_style_copy (lw6map_style_t * dst, lw6map_style_t * src)
+lw6map_style_copy (lw6map_style_t * dst, const lw6map_style_t * src)
 {
   lw6map_style_clear (dst);
   memcpy (dst, src, sizeof (lw6map_style_t));
@@ -579,13 +579,13 @@ lw6map_style_set (lw6map_style_t * style, const char *key, const char *value)
  *
  * Get a style entry, takes a string key and will
  * identify the struct offset. The return value is
- * converted to string, typically the cannonical 
+ * converted to string, typically the cannonical
  * representation suitable to write in an XML config file.
  *
  * Return value: dynamically allocated string.
  */
 char *
-lw6map_style_get (lw6map_style_t * style, const char *key)
+lw6map_style_get (const lw6map_style_t * style, const char *key)
 {
   char *ret = NULL;
   char *formatted_key = NULL;
