@@ -35,13 +35,40 @@
 
 #define LW6MAT_F_0 0.0f
 #define LW6MAT_I_0 0
-#define LW6MAT_D_0 0.0d
+#define LW6MAT_D_0 0.0f
 #define LW6MAT_X_0 0
 #define LW6MAT_F_1 1.0f
 #define LW6MAT_I_1 1
-#define LW6MAT_D_1 1.0d
+#define LW6MAT_D_1 1.0f
 #define LW6MAT_X_1 65536
 
+#define LW6MAT_SIMILAR_F_DIFF 0.001f
+#define LW6MAT_SIMILAR_I_DIFF 0
+#define LW6MAT_SIMILAR_D_DIFF 0.00001f
+#define LW6MAT_SIMILAR_X_DIFF 4096
+#define LW6MAT_SIMILAR_F_SCALE 0.0001f
+#define LW6MAT_SIMILAR_I_SCALE 0
+#define LW6MAT_SIMILAR_D_SCALE 0.0000001f
+#define LW6MAT_SIMILAR_X_SCALE 256
+
+#define LW6MAT_VEC2_V_SIZE 2
+#define LW6MAT_VEC3_V_SIZE 3
+#define LW6MAT_VEC4_V_SIZE 4
+
+#define LW6MAT_MAT2_M_SIZE 2
+#define LW6MAT_MAT2_V_SIZE_X_SIZE 4
+#define LW6MAT_MAT3_M_SIZE 3
+#define LW6MAT_MAT3_V_SIZE_X_SIZE 9
+#define LW6MAT_MAT4_M_SIZE 4
+#define LW6MAT_MAT4_V_SIZE_X_SIZE 16
+
+#define LW6MAT_REPR_VEC "vector"
+#define LW6MAT_REPR_MAT "matrix"
+#define LW6MAT_REPR_F "float"
+#define LW6MAT_REPR_I "integer"
+#define LW6MAT_REPR_D "double"
+#define LW6MAT_REPR_X "fixed point"
+
 /*
  * Float API.
  */
@@ -64,7 +91,7 @@ typedef union
     float t;
   } t;
   /// Accessor with array index.
-  float v[2];
+  float v[LW6MAT_VEC2_V_SIZE];
 } lw6mat_fvec2_t;
 
 /**
@@ -94,7 +121,7 @@ typedef union
     float p;
   } t;
   /// Accessor with array index.
-  float v[3];
+  float v[LW6MAT_VEC3_V_SIZE];
   /// Accessor with smaller-sized vector, only 2 dimensions
   lw6mat_fvec2_t v2;
 } lw6mat_fvec3_t;
@@ -129,7 +156,7 @@ typedef union
     float q;
   } t;
   /// Accessor with array index.
-  float v[4];
+  float v[LW6MAT_VEC4_V_SIZE];
   /// Accessor with smaller-sized vector, only 2 dimensions
   lw6mat_fvec2_t v2;
   /// Accessor with smaller-sized vector, only 3 dimensions
@@ -141,8 +168,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  float m[2][2];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  float m[LW6MAT_MAT2_M_SIZE][LW6MAT_MAT2_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*4+j.
+   */
+  float v[LW6MAT_MAT2_V_SIZE_X_SIZE];
 } lw6mat_fmat2_t;
 
 /**
@@ -150,8 +188,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  float m[3][3];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  float m[LW6MAT_MAT3_M_SIZE][LW6MAT_MAT3_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*3+j.
+   */
+  float v[LW6MAT_MAT3_V_SIZE_X_SIZE];
 } lw6mat_fmat3_t;
 
 /**
@@ -159,8 +208,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  float m[4][4];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  float m[LW6MAT_MAT4_M_SIZE][LW6MAT_MAT4_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*4+j.
+   */
+  float v[LW6MAT_MAT4_V_SIZE_X_SIZE];
 } lw6mat_fmat4_t;
 
 /*
@@ -185,7 +245,7 @@ typedef union
     int32_t t;
   } t;
   /// Accessor with array index.
-  int32_t v[2];
+  int32_t v[LW6MAT_VEC2_V_SIZE];
 } lw6mat_ivec2_t;
 
 /**
@@ -215,7 +275,7 @@ typedef union
     int32_t p;
   } t;
   /// Accessor with array index.
-  int32_t v[3];
+  int32_t v[LW6MAT_VEC3_V_SIZE];
 } lw6mat_ivec3_t;
 
 /**
@@ -248,7 +308,7 @@ typedef union
     int32_t q;
   } t;
   /// Accessor with array index.
-  int32_t v[4];
+  int32_t v[LW6MAT_VEC4_V_SIZE];
 } lw6mat_ivec4_t;
 
 /**
@@ -256,8 +316,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  int32_t m[2][2];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  int32_t m[LW6MAT_MAT2_M_SIZE][LW6MAT_MAT2_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*2+j.
+   */
+  int32_t v[LW6MAT_MAT2_V_SIZE_X_SIZE];
 } lw6mat_imat2_t;
 
 /**
@@ -265,8 +336,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  int32_t m[3][3];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  int32_t m[LW6MAT_MAT3_M_SIZE][LW6MAT_MAT3_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*3+j.
+   */
+  int32_t v[LW6MAT_MAT3_V_SIZE_X_SIZE];
 } lw6mat_imat3_t;
 
 /**
@@ -274,8 +356,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  int32_t m[4][4];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  int32_t m[LW6MAT_MAT4_M_SIZE][LW6MAT_MAT4_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*4+j.
+   */
+  int32_t v[LW6MAT_MAT4_V_SIZE_X_SIZE];
 } lw6mat_imat4_t;
 
 /*
@@ -300,7 +393,7 @@ typedef union
     double t;
   } t;
   /// Accessor with array index.
-  double v[2];
+  double v[LW6MAT_VEC2_V_SIZE];
 } lw6mat_dvec2_t;
 
 /**
@@ -330,7 +423,7 @@ typedef union
     double p;
   } t;
   /// Accessor with array index.
-  double v[3];
+  double v[LW6MAT_VEC3_V_SIZE];
   /// Accessor with smaller-sized vector, only 2 dimensions
   lw6mat_dvec2_t v2;
 } lw6mat_dvec3_t;
@@ -365,7 +458,7 @@ typedef union
     double q;
   } t;
   /// Accessor with array index.
-  double v[4];
+  double v[LW6MAT_VEC4_V_SIZE];
   /// Accessor with smaller-sized vector, only 2 dimensions
   lw6mat_dvec2_t v2;
   /// Accessor with smaller-sized vector, only 3 dimensions
@@ -377,8 +470,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  double m[2][2];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  double m[LW6MAT_MAT2_M_SIZE][LW6MAT_MAT2_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*2+j.
+   */
+  double v[LW6MAT_MAT2_V_SIZE_X_SIZE];
 } lw6mat_dmat2_t;
 
 /**
@@ -386,8 +490,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  double m[3][3];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  double m[LW6MAT_MAT3_M_SIZE][LW6MAT_MAT3_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*3+j.
+   */
+  double v[LW6MAT_MAT3_V_SIZE_X_SIZE];
 } lw6mat_dmat3_t;
 
 /**
@@ -395,8 +510,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  double m[4][4];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  double m[LW6MAT_MAT4_M_SIZE][LW6MAT_MAT4_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*4+j.
+   */
+  double v[LW6MAT_MAT4_V_SIZE_X_SIZE];
 } lw6mat_dmat4_t;
 
 /*
@@ -421,7 +547,7 @@ typedef union
     int32_t t;
   } t;
   /// Accessor with array index.
-  int32_t v[2];
+  int32_t v[LW6MAT_VEC2_V_SIZE];
 } lw6mat_xvec2_t;
 
 /**
@@ -451,7 +577,7 @@ typedef union
     int32_t p;
   } t;
   /// Accessor with array index.
-  int32_t v[3];
+  int32_t v[LW6MAT_VEC3_V_SIZE];
 } lw6mat_xvec3_t;
 
 /**
@@ -484,7 +610,7 @@ typedef union
     int32_t q;
   } t;
   /// Accessor with array index.
-  int32_t v[4];
+  int32_t v[LW6MAT_VEC4_V_SIZE];
 } lw6mat_xvec4_t;
 
 /**
@@ -492,8 +618,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  int32_t m[2][2];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  int32_t m[LW6MAT_MAT2_M_SIZE][LW6MAT_MAT2_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*3+j.
+   */
+  int32_t v[LW6MAT_MAT2_V_SIZE_X_SIZE];
 } lw6mat_xmat2_t;
 
 /**
@@ -501,8 +638,19 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  int32_t m[3][3];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  int32_t m[LW6MAT_MAT3_M_SIZE][LW6MAT_MAT3_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*3+j.
+   */
+  int32_t v[LW6MAT_MAT3_V_SIZE_X_SIZE];
 } lw6mat_xmat3_t;
 
 /**
@@ -510,10 +658,44 @@ typedef union
  */
 typedef union
 {
-  /// Accessor with array index.
-  int32_t m[4][4];
+  /**
+   * Accessor with 2 dimensions array index.
+   * The convention is column-major mode as done in OpenGL
+   * so that m[i][j] is element at column i and row j.
+   * Beware, this is not the most natural order for a
+   * C programmer.
+   */
+  int32_t m[LW6MAT_MAT4_M_SIZE][LW6MAT_MAT4_M_SIZE];
+  /**
+   * Accessor with flat array index. To access element
+   * a column i and row j, use i*4+j.
+   */
+  int32_t v[LW6MAT_MAT4_V_SIZE_X_SIZE];
 } lw6mat_xmat4_t;
 
+/*
+ * Matrix index calculus. While you should probably
+ * not use this (use the built-in m[][] accessor instead
+ * they are provided to explicitly show memory layout.
+ */
+static inline int
+lw6mat_mat2_v_index (int i_column, int j_row)
+{
+  return i_column * LW6MAT_MAT2_M_SIZE + j_row;
+}
+
+static inline int
+lw6mat_mat3_v_index (int i_column, int j_row)
+{
+  return i_column * LW6MAT_MAT3_M_SIZE + j_row;
+}
+
+static inline int
+lw6mat_mat4_v_index (int i_column, int j_row)
+{
+  return i_column * LW6MAT_MAT4_M_SIZE + j_row;
+}
+
 /*
  * Conversions.
  */
@@ -708,6 +890,10 @@ extern void lw6mat_fvec2_cross (lw6mat_fvec3_t * fvec3,
 				const lw6mat_fvec2_t * fvec2_a,
 				const lw6mat_fvec2_t * fvec2_b);
 extern void lw6mat_fvec2_scale (lw6mat_fvec2_t * fvec2, float f);
+extern void lw6mat_fvec2_mul_fvec2 (lw6mat_fmat2_t * fmat2,
+				    const lw6mat_fvec2_t * fvec2_a,
+				    const lw6mat_fvec2_t * fvec2_b);
+extern char *lw6mat_fvec2_repr (const lw6mat_fvec2_t * fvec2);
 
 /* mat-fvec3.c */
 extern void lw6mat_fvec3_zero (lw6mat_fvec3_t * fvec3);
@@ -729,6 +915,10 @@ extern void lw6mat_fvec3_cross (lw6mat_fvec3_t * fvec3,
 				const lw6mat_fvec3_t * fvec3_a,
 				const lw6mat_fvec3_t * fvec3_b);
 extern void lw6mat_fvec3_scale (lw6mat_fvec3_t * fvec3, float f);
+extern void lw6mat_fvec3_mul_fvec3 (lw6mat_fmat3_t * fmat3,
+				    const lw6mat_fvec3_t * fvec3_a,
+				    const lw6mat_fvec3_t * fvec3_b);
+extern char *lw6mat_fvec3_repr (const lw6mat_fvec3_t * fvec3);
 
 /* mat-fvec4.c */
 extern void lw6mat_fvec4_zero (lw6mat_fvec4_t * fvec4);
@@ -750,6 +940,10 @@ extern void lw6mat_fvec4_cross (lw6mat_fvec3_t * fvec3,
 				const lw6mat_fvec4_t * fvec4_a,
 				const lw6mat_fvec4_t * fvec4_b);
 extern void lw6mat_fvec4_scale (lw6mat_fvec4_t * fvec4, float f);
+extern void lw6mat_fvec4_mul_fvec4 (lw6mat_fmat4_t * fmat4,
+				    const lw6mat_fvec4_t * fvec4_a,
+				    const lw6mat_fvec4_t * fvec4_b);
+extern char *lw6mat_fvec4_repr (const lw6mat_fvec4_t * fvec4);
 
 /* mat-ivec2.c */
 extern void lw6mat_ivec2_zero (lw6mat_ivec2_t * ivec2);
@@ -771,6 +965,7 @@ extern void lw6mat_ivec2_cross (lw6mat_ivec3_t * ivec3,
 				const lw6mat_ivec2_t * ivec2_a,
 				const lw6mat_ivec2_t * ivec2_b);
 extern void lw6mat_ivec2_scale (lw6mat_ivec2_t * ivec2, int32_t f);
+extern char *lw6mat_ivec2_repr (const lw6mat_ivec2_t * ivec2);
 
 /* mat-ivec3.c */
 extern void lw6mat_ivec3_zero (lw6mat_ivec3_t * ivec3);
@@ -792,6 +987,7 @@ extern void lw6mat_ivec3_cross (lw6mat_ivec3_t * ivec3,
 				const lw6mat_ivec3_t * ivec3_a,
 				const lw6mat_ivec3_t * ivec3_b);
 extern void lw6mat_ivec3_scale (lw6mat_ivec3_t * ivec3, int32_t f);
+extern char *lw6mat_ivec3_repr (const lw6mat_ivec3_t * ivec3);
 
 /* mat-ivec4.c */
 extern void lw6mat_ivec4_zero (lw6mat_ivec4_t * ivec4);
@@ -813,6 +1009,7 @@ extern void lw6mat_ivec4_cross (lw6mat_ivec3_t * ivec3,
 				const lw6mat_ivec4_t * ivec4_a,
 				const lw6mat_ivec4_t * ivec4_b);
 extern void lw6mat_ivec4_scale (lw6mat_ivec4_t * ivec4, int32_t f);
+extern char *lw6mat_ivec4_repr (const lw6mat_ivec3_t * ivec4);
 
 /* mat-dvec2.c */
 extern void lw6mat_dvec2_zero (lw6mat_dvec2_t * dvec2);
@@ -834,6 +1031,10 @@ extern void lw6mat_dvec2_cross (lw6mat_dvec3_t * dvec3,
 				const lw6mat_dvec2_t * dvec2_a,
 				const lw6mat_dvec2_t * dvec2_b);
 extern void lw6mat_dvec2_scale (lw6mat_dvec2_t * dvec2, double f);
+extern void lw6mat_dvec2_mul_dvec2 (lw6mat_dmat2_t * dmat2,
+				    const lw6mat_dvec2_t * dvec2_a,
+				    const lw6mat_dvec2_t * dvec2_b);
+extern char *lw6mat_dvec2_repr (const lw6mat_dvec2_t * dvec2);
 
 /* mat-dvec3.c */
 extern void lw6mat_dvec3_zero (lw6mat_dvec3_t * dvec3);
@@ -855,6 +1056,10 @@ extern void lw6mat_dvec3_cross (lw6mat_dvec3_t * dvec3,
 				const lw6mat_dvec3_t * dvec3_a,
 				const lw6mat_dvec3_t * dvec3_b);
 extern void lw6mat_dvec3_scale (lw6mat_dvec3_t * dvec3, double f);
+extern void lw6mat_dvec3_mul_dvec3 (lw6mat_dmat3_t * dmat3,
+				    const lw6mat_dvec3_t * dvec3_a,
+				    const lw6mat_dvec3_t * dvec3_b);
+extern char *lw6mat_dvec3_repr (const lw6mat_dvec3_t * dvec3);
 
 /* mat-dvec4.c */
 extern void lw6mat_dvec4_zero (lw6mat_dvec4_t * dvec4);
@@ -876,6 +1081,10 @@ extern void lw6mat_dvec4_cross (lw6mat_dvec3_t * dvec3,
 				const lw6mat_dvec4_t * dvec4_a,
 				const lw6mat_dvec4_t * dvec4_b);
 extern void lw6mat_dvec4_scale (lw6mat_dvec4_t * dvec4, double f);
+extern void lw6mat_dvec4_mul_dvec4 (lw6mat_dmat4_t * dmat4,
+				    const lw6mat_dvec4_t * dvec4_a,
+				    const lw6mat_dvec4_t * dvec4_b);
+extern char *lw6mat_dvec4_repr (const lw6mat_dvec4_t * dvec4);
 
 /* mat-xvec2.c */
 extern void lw6mat_xvec2_zero (lw6mat_xvec2_t * xvec2);
@@ -897,6 +1106,7 @@ extern void lw6mat_xvec2_cross (lw6mat_xvec3_t * xvec3,
 				const lw6mat_xvec2_t * xvec2_a,
 				const lw6mat_xvec2_t * xvec2_b);
 extern void lw6mat_xvec2_scale (lw6mat_xvec2_t * xvec2, int32_t f);
+extern char *lw6mat_xvec2_repr (const lw6mat_xvec2_t * xvec2);
 
 /* mat-xvec3.c */
 extern void lw6mat_xvec3_zero (lw6mat_xvec3_t * xvec3);
@@ -918,6 +1128,7 @@ extern void lw6mat_xvec3_cross (lw6mat_xvec3_t * xvec3,
 				const lw6mat_xvec3_t * xvec3_a,
 				const lw6mat_xvec3_t * xvec3_b);
 extern void lw6mat_xvec3_scale (lw6mat_xvec3_t * xvec3, int32_t f);
+extern char *lw6mat_xvec3_repr (const lw6mat_xvec3_t * xvec3);
 
 /* mat-xvec4.c */
 extern void lw6mat_xvec4_zero (lw6mat_xvec4_t * xvec4);
@@ -939,6 +1150,133 @@ extern void lw6mat_xvec4_cross (lw6mat_xvec3_t * xvec3,
 				const lw6mat_xvec4_t * xvec4_a,
 				const lw6mat_xvec4_t * xvec4_b);
 extern void lw6mat_xvec4_scale (lw6mat_xvec4_t * xvec4, int32_t f);
+extern char *lw6mat_xvec4_repr (const lw6mat_xvec4_t * xvec4);
+
+/* mat-fmat2.c */
+extern void lw6mat_fmat2_zero (lw6mat_fmat2_t * fmat2);
+extern void lw6mat_fmat2_id (lw6mat_fmat2_t * fmat2);
+extern int lw6mat_fmat2_is_same (const lw6mat_fmat2_t * fmat2_a,
+				 const lw6mat_fmat2_t * fmat2_b);
+extern void lw6mat_fmat2_trans (lw6mat_fmat2_t * fmat2);
+extern float lw6mat_fmat2_det (const lw6mat_fmat2_t * fmat2);
+extern void lw6mat_fmat2_scale (lw6mat_fmat2_t * fmat2, float f);
+extern int lw6mat_fmat2_inv (lw6mat_fmat2_t * fmat2_dst,
+			     const lw6mat_fmat2_t * fmat2_src);
+extern void lw6mat_fmat2_mul_fmat2 (lw6mat_fmat2_t * fmat2,
+				    const lw6mat_fmat2_t * fmat2_a,
+				    const lw6mat_fmat2_t * fmat2_b);
+extern void lw6mat_fmat2_mul_fvec2 (lw6mat_fvec2_t * fvec2_dst,
+				    const lw6mat_fmat2_t * fmat2,
+				    const lw6mat_fvec2_t * fvec2_src);
+extern char *lw6mat_fmat2_repr (const lw6mat_fmat2_t * fmat2);
+
+/* mat-fmat3.c */
+extern void lw6mat_fmat3_zero (lw6mat_fmat3_t * fmat3);
+extern void lw6mat_fmat3_id (lw6mat_fmat3_t * fmat3);
+extern int lw6mat_fmat3_is_same (const lw6mat_fmat3_t * fmat3_a,
+				 const lw6mat_fmat3_t * fmat3_b);
+extern void lw6mat_fmat3_trans (lw6mat_fmat3_t * fmat3);
+extern float lw6mat_fmat3_det (const lw6mat_fmat3_t * fmat3);
+extern void lw6mat_fmat3_scale (lw6mat_fmat3_t * fmat3, float f);
+extern int lw6mat_fmat3_inv (lw6mat_fmat3_t * fmat3_dst,
+			     const lw6mat_fmat3_t * fmat3_src);
+extern void lw6mat_fmat3_mul_fmat3 (lw6mat_fmat3_t * fmat3,
+				    const lw6mat_fmat3_t * fmat3_a,
+				    const lw6mat_fmat3_t * fmat3_b);
+extern void lw6mat_fmat3_mul_fvec3 (lw6mat_fvec3_t * fvec3_dst,
+				    const lw6mat_fmat3_t * fmat3,
+				    const lw6mat_fvec3_t * fvec3_src);
+extern void lw6mat_fmat3_mul_fvec2 (lw6mat_fvec2_t * fvec2_dst,
+				    const lw6mat_fmat3_t * fmat3,
+				    const lw6mat_fvec2_t * fvec2_src);
+extern char *lw6mat_fmat3_repr (const lw6mat_fmat3_t * fmat3);
+
+/* mat-fmat4.c */
+extern void lw6mat_fmat4_zero (lw6mat_fmat4_t * fmat4);
+extern void lw6mat_fmat4_id (lw6mat_fmat4_t * fmat4);
+extern int lw6mat_fmat4_is_same (const lw6mat_fmat4_t * fmat4_a,
+				 const lw6mat_fmat4_t * fmat4_b);
+extern void lw6mat_fmat4_trans (lw6mat_fmat4_t * fmat4);
+extern float lw6mat_fmat4_det (const lw6mat_fmat4_t * fmat4);
+extern void lw6mat_fmat4_scale (lw6mat_fmat4_t * fmat4, float f);
+extern int lw6mat_fmat4_inv (lw6mat_fmat4_t * fmat4_dst,
+			     const lw6mat_fmat4_t * fmat4_src);
+extern void lw6mat_fmat4_mul_fmat4 (lw6mat_fmat4_t * fmat4,
+				    const lw6mat_fmat4_t * fmat4_a,
+				    const lw6mat_fmat4_t * fmat4_b);
+extern void lw6mat_fmat4_mul_fvec4 (lw6mat_fvec4_t * fvec4_dst,
+				    const lw6mat_fmat4_t * fmat4,
+				    const lw6mat_fvec4_t * fvec4_src);
+extern void lw6mat_fmat4_mul_fvec3 (lw6mat_fvec3_t * fvec3_dst,
+				    const lw6mat_fmat4_t * fmat4,
+				    const lw6mat_fvec3_t * fvec3_src);
+extern char *lw6mat_fmat4_repr (const lw6mat_fmat4_t * fmat4);
+
+/* mat-dmat2.c */
+extern void lw6mat_dmat2_zero (lw6mat_dmat2_t * dmat2);
+extern void lw6mat_dmat2_id (lw6mat_dmat2_t * dmat2);
+extern int lw6mat_dmat2_is_same (const lw6mat_dmat2_t * dmat2_a,
+				 const lw6mat_dmat2_t * dmat2_b);
+extern void lw6mat_dmat2_trans (lw6mat_dmat2_t * dmat2);
+extern double lw6mat_dmat2_det (const lw6mat_dmat2_t * dmat2);
+extern void lw6mat_dmat2_scale (lw6mat_dmat2_t * dmat2, double f);
+extern int lw6mat_dmat2_inv (lw6mat_dmat2_t * dmat2_dst,
+			     const lw6mat_dmat2_t * dmat2_src);
+extern void lw6mat_dmat2_mul_dmat2 (lw6mat_dmat2_t * dmat2,
+				    const lw6mat_dmat2_t * dmat2_a,
+				    const lw6mat_dmat2_t * dmat2_b);
+extern void lw6mat_dmat2_mul_dvec2 (lw6mat_dvec2_t * dvec2_dst,
+				    const lw6mat_dmat2_t * dmat2,
+				    const lw6mat_dvec2_t * dvec2_src);
+extern char *lw6mat_dmat2_repr (const lw6mat_dmat2_t * dmat2);
+
+/* mat-dmat3.c */
+extern void lw6mat_dmat3_zero (lw6mat_dmat3_t * dmat3);
+extern void lw6mat_dmat3_id (lw6mat_dmat3_t * dmat3);
+extern int lw6mat_dmat3_is_same (const lw6mat_dmat3_t * dmat3_a,
+				 const lw6mat_dmat3_t * dmat3_b);
+extern void lw6mat_dmat3_trans (lw6mat_dmat3_t * dmat3);
+extern double lw6mat_dmat3_det (const lw6mat_dmat3_t * dmat3);
+extern void lw6mat_dmat3_scale (lw6mat_dmat3_t * dmat3, double f);
+extern int lw6mat_dmat3_inv (lw6mat_dmat3_t * dmat3_dst,
+			     const lw6mat_dmat3_t * dmat3_src);
+extern void lw6mat_dmat3_mul_dmat3 (lw6mat_dmat3_t * dmat3,
+				    const lw6mat_dmat3_t * dmat3_a,
+				    const lw6mat_dmat3_t * dmat3_b);
+extern void lw6mat_dmat3_mul_dvec3 (lw6mat_dvec3_t * dvec3_dst,
+				    const lw6mat_dmat3_t * dmat3,
+				    const lw6mat_dvec3_t * dvec3_src);
+extern void lw6mat_dmat3_mul_dvec2 (lw6mat_dvec2_t * dvec2_dst,
+				    const lw6mat_dmat3_t * fmat3,
+				    const lw6mat_dvec2_t * dvec2_src);
+extern char *lw6mat_dmat3_repr (const lw6mat_dmat3_t * dmat3);
+
+/* mat-dmat4.c */
+extern void lw6mat_dmat4_zero (lw6mat_dmat4_t * dmat4);
+extern void lw6mat_dmat4_id (lw6mat_dmat4_t * dmat4);
+extern int lw6mat_dmat4_is_same (const lw6mat_dmat4_t * dmat4_a,
+				 const lw6mat_dmat4_t * dmat4_b);
+extern void lw6mat_dmat4_trans (lw6mat_dmat4_t * dmat4);
+extern double lw6mat_dmat4_det (const lw6mat_dmat4_t * dmat4);
+extern void lw6mat_dmat4_scale (lw6mat_dmat4_t * dmat4, double f);
+extern int lw6mat_dmat4_inv (lw6mat_dmat4_t * dmat4_dst,
+			     const lw6mat_dmat4_t * dmat4_src);
+extern void lw6mat_dmat4_mul_dmat4 (lw6mat_dmat4_t * dmat4,
+				    const lw6mat_dmat4_t * dmat4_a,
+				    const lw6mat_dmat4_t * dmat4_b);
+extern void lw6mat_dmat4_mul_dvec4 (lw6mat_dvec4_t * dvec4_dst,
+				    const lw6mat_dmat4_t * dmat4,
+				    const lw6mat_dvec4_t * dvec4_src);
+extern void lw6mat_dmat4_mul_dvec3 (lw6mat_dvec3_t * dvec3_dst,
+				    const lw6mat_dmat4_t * dmat4,
+				    const lw6mat_dvec3_t * dvec3_src);
+extern char *lw6mat_dmat4_repr (const lw6mat_dmat4_t * dmat4);
+
+/* mat-similar.c */
+extern int lw6mat_is_similar_f (float f_a, float f_b);
+extern int lw6mat_is_similar_i (int32_t i_a, int32_t i_b);
+extern int lw6mat_is_similar_d (double d_a, double d_b);
+extern int lw6mat_is_similar_x (int32_t x_a, int32_t x_b);
 
 /* mat-test.c */
 extern int lw6mat_test_register (int mode);
