@@ -47,7 +47,8 @@
 #define _LW6P2P_SELECT_OTHER_NODE_SQL "select-other-node.sql"
 #define _LW6P2P_SELECT_AVAILABLE_NODE_SQL "select-available-node.sql"
 #define _LW6P2P_SELECT_UNAVAILABLE_NODE_SQL "select-unavailable-node.sql"
-#define _LW6P2P_UPDATE_NODE_SQL "update-node.sql"
+#define _LW6P2P_UPDATE_NODE_INFO_SQL "update-node-info.sql"
+#define _LW6P2P_UPDATE_NODE_NET_SQL "update-node-net.sql"
 
 #define _LW6P2P_DB_NODE_NB_FIELDS 26
 #define _LW6P2P_DB_NODE_ORDER_CREATION_TIMESTAMP 0
@@ -97,11 +98,12 @@ typedef struct _lw6p2p_consts_s
   int node_verify_max_at_once;
   int foo_delay;
   int join_delay;
-  int miss_delay;
+  int miss_get_delay;
+  int miss_duplicate_delay;
   int miss_wake_up_interval;
   int miss_max_range;
   int ticket_table_hash_size;
-  int send_best_reliable_limit_n;
+  int send_per_poll_limit_n;
   int received_atom_parts_per_poll_to_disable_miss;
   int meta_nb_duplicates;
 }
@@ -168,6 +170,15 @@ typedef struct _lw6p2p_backends_s
   lw6srv_backend_t **srv_backends;
 } _lw6p2p_backends_t;
 
+typedef struct _lw6p2p_packet_s
+{
+  u_int32_t logical_ticket_sig;
+  u_int32_t physical_ticket_sig;
+  u_int64_t logical_from_id;
+  u_int64_t logical_to_id;
+  char *msg;
+} _lw6p2p_packet_t;
+
 typedef struct _lw6p2p_tentacle_s
 {
   _lw6p2p_backends_t *backends;
@@ -188,8 +199,11 @@ typedef struct _lw6p2p_tentacle_s
   lw6cnx_connection_t **cli_connections;
   int nb_srv_connections;
   lw6cnx_connection_t **srv_connections;
-  lw6sys_list_t *unsent_queue;
+  lw6sys_list_t *unsent_reliable_queue;
+  lw6sys_list_t *unsent_unreliable_queue;
   int last_poll_received_messages;
+  lw6dat_miss_t last_miss;
+  int64_t last_miss_timestamp;
 } _lw6p2p_tentacle_t;
 
 typedef struct _lw6p2p_node_s
@@ -249,15 +263,6 @@ typedef struct _lw6p2p_cli_oob_callback_data_s
   lw6cli_oob_t *cli_oob;
 } _lw6p2p_cli_oob_callback_data_t;
 
-typedef struct _lw6p2p_queue_item_s
-{
-  u_int32_t logical_ticket_sig;
-  u_int64_t logical_from_id;
-  u_int64_t logical_to_id;
-  char *msg;
-}
-_lw6p2p_queue_item_t;
-
 /* p2p-backends.c */
 extern int _lw6p2p_backends_init_cli (int argc, const char *argv[],
 				      _lw6p2p_backends_t * backends,
@@ -295,9 +300,9 @@ extern int _lw6p2p_data_unload (_lw6p2p_data_t * data);
 
 /* p2p-db.c */
 extern _lw6p2p_db_t *_lw6p2p_db_open (int argc, const char *argv[],
-				      char *name);
+				      const char *name);
 extern void _lw6p2p_db_close (_lw6p2p_db_t * db);
-extern char *_lw6p2p_db_repr (_lw6p2p_db_t * db);
+extern char *_lw6p2p_db_repr (const _lw6p2p_db_t * db);
 extern char *_lw6p2p_db_get_query (_lw6p2p_db_t * db, char *key);
 extern void _lw6p2p_db_log (_lw6p2p_db_t * db, char *message);
 extern int _lw6p2p_db_lock (_lw6p2p_db_t * db);
@@ -314,6 +319,8 @@ extern int _lw6p2p_db_now (_lw6p2p_db_t * db);
 /* p2p-explore.c */
 extern int _lw6p2p_explore_discover_nodes_if_needed (_lw6p2p_node_t * node);
 extern int _lw6p2p_explore_discover_nodes (_lw6p2p_node_t * node);
+extern void _lw6p2p_explore_start_verify_node (_lw6p2p_node_t * node,
+					       const char *public_url);
 extern int _lw6p2p_explore_verify_nodes_if_needed (_lw6p2p_node_t * node);
 extern int _lw6p2p_explore_verify_nodes (_lw6p2p_node_t * node);
 
@@ -338,7 +345,7 @@ extern _lw6p2p_node_t *_lw6p2p_node_new (int argc, const char *argv[],
 					 char *known_nodes,
 					 int network_reliability, int trojan);
 extern void _lw6p2p_node_free (_lw6p2p_node_t * node);
-extern char *_lw6p2p_node_repr (_lw6p2p_node_t * node);
+extern char *_lw6p2p_node_repr (const _lw6p2p_node_t * node);
 extern int _lw6p2p_node_lock (_lw6p2p_node_t * node);
 extern int _lw6p2p_node_unlock (_lw6p2p_node_t * node);
 extern int _lw6p2p_node_trylock (_lw6p2p_node_t * node);
@@ -348,24 +355,30 @@ extern void _lw6p2p_node_close (_lw6p2p_node_t * node);
 extern u_int64_t _lw6p2p_node_get_id (_lw6p2p_node_t * node);
 extern int _lw6p2p_node_insert_discovered (_lw6p2p_node_t * node,
 					   char *public_url);
-extern int _lw6p2p_node_update_peer (_lw6p2p_node_t * node,
-				     const char *version,
-				     const char *codename,
-				     int stamp,
-				     const char *id,
-				     const char *url,
-				     const char *title,
-				     const char *description, int password,
-				     int bench, int open_relay,
-				     int creation_timestamp,
-				     const char *community_id, int round,
-				     const char *level, int required_bench,
-				     int nb_colors, int max_nb_colors,
-				     int nb_cursors, int max_nb_cursors,
-				     int nb_nodes, int max_nb_nodes,
-				     const char *ip, int port,
-				     int last_ping_timestamp,
-				     int ping_delay_msec);
+extern int _lw6p2p_node_update_peer_info_x (_lw6p2p_node_t * node,
+					    const char *version,
+					    const char *codename,
+					    int stamp,
+					    const char *id,
+					    const char *url,
+					    const char *title,
+					    const char *description,
+					    int password, int bench,
+					    int open_relay,
+					    int creation_timestamp,
+					    const char *community_id,
+					    int round, const char *level,
+					    int required_bench, int nb_colors,
+					    int max_nb_colors, int nb_cursors,
+					    int max_nb_cursors, int nb_nodes,
+					    int max_nb_nodes);
+extern int _lw6p2p_node_update_peer_info (_lw6p2p_node_t * node,
+					  lw6nod_info_t * peer_info);
+extern int _lw6p2p_node_update_peer_net (_lw6p2p_node_t * node,
+					 const char *id, const char *url,
+					 const char *ip, int port,
+					 int last_ping_timestamp,
+					 int ping_delay_msec);
 extern int _lw6p2p_node_update_local (_lw6p2p_node_t * node,
 				      lw6nod_info_t * node_info);
 extern int _lw6p2p_node_find_free_tentacle (_lw6p2p_node_t * node);
@@ -384,6 +397,9 @@ extern int _lw6p2p_node_client_join (_lw6p2p_node_t * node,
 				     u_int64_t remote_id,
 				     const char *remote_url,
 				     lw6sys_progress_t * progress);
+extern int _lw6p2p_node_refresh_peer (_lw6p2p_node_t * node,
+				      u_int64_t remote_id,
+				      const char *remote_url);
 extern void _lw6p2p_node_disconnect (_lw6p2p_node_t * node);
 extern int _lw6p2p_node_update_info (_lw6p2p_node_t * node,
 				     int round, const char *level,
@@ -415,20 +431,24 @@ extern char *_lw6p2p_node_get_next_reference_msg (_lw6p2p_node_t * node,
 extern char *_lw6p2p_node_get_next_draft_msg (_lw6p2p_node_t * node,
 					      lw6sys_progress_t * progress);
 
+/* p2p-packet.c */
+extern _lw6p2p_packet_t *_lw6p2p_packet_new (u_int32_t logical_ticket_sig,
+					     u_int32_t physical_ticket_sig,
+					     u_int64_t logical_from_id,
+					     u_int64_t logical_to_id,
+					     const char *msg);
+extern void _lw6p2p_packet_free (_lw6p2p_packet_t * packet);
+extern u_int32_t _lw6p2p_packet_checksum (const _lw6p2p_packet_t * packet);
+extern int _lw6p2p_packet_compare (const _lw6p2p_packet_t * a,
+				   const _lw6p2p_packet_t * b);
+extern int _lw6p2p_packet_sort_callback (const lw6sys_list_t ** list_a,
+					 const lw6sys_list_t ** list_b);
+
 /* p2p-peeridlist.c */
 extern void _lw6p2p_peer_id_list_process_join (_lw6p2p_node_t * node,
 					       lw6nod_info_t *
 					       remote_node_info);
 
-/* p2p-queueitem.c */
-extern _lw6p2p_queue_item_t *_lw6p2p_queue_item_new (u_int32_t
-						     logical_ticket_sig,
-						     u_int64_t
-						     logical_from_id,
-						     u_int64_t logical_to_id,
-						     const char *msg);
-extern void _lw6p2p_queue_item_free (_lw6p2p_queue_item_t * queue_item);
-
 /* p2p-recv.c */
 extern void _lw6p2p_recv_process (_lw6p2p_node_t * node,
 				  lw6cnx_connection_t * cnx,
