@@ -27,7 +27,7 @@
 #include "p2p.h"
 #include "p2p-internal.h"
 
-static u_int32_t seq_id = 0;
+static volatile u_int32_t seq_id = 0;
 
 /**
  * lw6p2p_node_new
@@ -49,7 +49,7 @@ static u_int32_t seq_id = 0;
  * @open_relay: act as an open relay or not
  * @known_nodes: list of already known nodes
  * @network_reliability: drop 1 packet out of X
- * @trojan: act as a stupid trojan to test out automatic kick-off 
+ * @trojan: act as a stupid trojan to test out automatic kick-off
  *
  * Creates a new "pear to pear" node. This will fire the server
  * and allow client access, on demand. A lot of stuff can be done
@@ -364,13 +364,13 @@ _lw6p2p_node_free (_lw6p2p_node_t * node)
  * Return value: a dynamically allocated string
  */
 char *
-lw6p2p_node_repr (lw6p2p_node_t * node)
+lw6p2p_node_repr (const lw6p2p_node_t * node)
 {
   return _lw6p2p_node_repr ((_lw6p2p_node_t *) node);
 }
 
 char *
-_lw6p2p_node_repr (_lw6p2p_node_t * node)
+_lw6p2p_node_repr (const _lw6p2p_node_t * node)
 {
   char *repr = NULL;
   int nb_nodes = 0;
@@ -489,7 +489,7 @@ lw6p2p_node_poll (lw6p2p_node_t * node, lw6sys_progress_t * progress)
   int ret = 0;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -747,7 +747,7 @@ _tcp_accepter_reply (void *func_data, void *data)
 		       * to save time, since protocol analysis must
 		       * really remain simple. Besides this "double"
 		       * anlysis is rare since it only concerns one
-		       * message at the beginning of each incoming 
+		       * message at the beginning of each incoming
 		       * connection.
 		       */
 		      analyse_tcp_ret =
@@ -865,7 +865,7 @@ _udp_buffer_reply (void *func_data, void *data)
 		       * to save time, since protocol analysis must
 		       * really remain simple. Besides this "double"
 		       * anlysis is rare since it only concerns one
-		       * message at the beginning of each incoming 
+		       * message at the beginning of each incoming
 		       * connection.
 		       */
 		      analyse_udp_ret =
@@ -1059,9 +1059,7 @@ _poll_step10_send_atoms (_lw6p2p_node_t * node, int64_t now)
 						   logical_ticket_sig,
 						   node->node_id_int,
 						   remote_id_int, atom_str,
-						   send_i >
-						   node->db->data.
-						   consts.send_best_reliable_limit_n))
+						   1))
 		    {
 		      ret = 0;
 		    }
@@ -1129,8 +1127,9 @@ _poll_step12_miss_list (_lw6p2p_node_t * node, int64_t now,
   const char *msg = NULL;
   int nb_atom_parts_since_last_poll = 0;
   int disable_miss = 0;
+  int tentacle_i;
 
-  if (now - node->db->data.consts.miss_delay >=
+  if (now - node->db->data.consts.miss_get_delay >=
       node->last_poll_miss_timestamp)
     {
       node->last_poll_miss_timestamp = now;
@@ -1150,6 +1149,70 @@ _poll_step12_miss_list (_lw6p2p_node_t * node, int64_t now,
 		(nb_atom_parts_since_last_poll >
 		 node->db->data.
 		 consts.received_atom_parts_per_poll_to_disable_miss) ? 1 : 0;
+	      tentacle_i = _lw6p2p_node_find_tentacle (node, miss->from_id);
+	      if (tentacle_i >= 0)
+		{
+		  /*
+		   * If the new miss is included in previous MISS message,
+		   * and "not enough time" has elapsed then do not send it
+		   * again as we suspect it's better to wait for a while before
+		   * firing it again, this avoids spamming too many MISS messages.
+		   */
+		  disable_miss = 0;
+		  if (lw6dat_miss_overlaps
+		      (miss, &(node->tentacles[tentacle_i].last_miss)))
+		    {
+		      if (now - node->db->data.consts.miss_duplicate_delay <
+			  node->tentacles[tentacle_i].last_miss_timestamp)
+			{
+			  lw6sys_log (LW6SYS_LOG_DEBUG,
+				      _x_ ("not sending MISS from_id=%"
+					   LW6SYS_PRINTF_LL
+					   "x serial_min=%d serial_max=%d as it overlaps with previous serial_min=%d serial_max=%d"),
+				      (long long) miss->from_id,
+				      miss->serial_min, miss->serial_max,
+				      node->tentacles[tentacle_i].
+				      last_miss.serial_min,
+				      node->tentacles[tentacle_i].
+				      last_miss.serial_max);
+			  disable_miss = 1;
+			}
+		      else
+			{
+			  lw6sys_log (LW6SYS_LOG_DEBUG,
+				      _x_ ("sending MISS from_id=%"
+					   LW6SYS_PRINTF_LL
+					   "x serial_min=%d serial_max=%d, it overlaps with previous serial_min=%d serial_max=%d but we've waited for too long"),
+				      (long long) miss->from_id,
+				      miss->serial_min, miss->serial_max,
+				      node->tentacles[tentacle_i].
+				      last_miss.serial_min,
+				      node->tentacles[tentacle_i].
+				      last_miss.serial_max);
+			}
+		    }
+		  else
+		    {
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _x_ ("sending MISS from_id=%"
+				       LW6SYS_PRINTF_LL
+				       "x serial_min=%d serial_max=%d, it does not overlap with previous serial_min=%d serial_max=%d"),
+				  (long long) miss->from_id, miss->serial_min,
+				  miss->serial_max,
+				  node->tentacles[tentacle_i].
+				  last_miss.serial_min,
+				  node->tentacles[tentacle_i].
+				  last_miss.serial_max);
+		    }
+		  if (!disable_miss)
+		    {
+		      lw6dat_miss_sync (&
+					(node->
+					 tentacles[tentacle_i].last_miss),
+					miss);
+		      node->tentacles[tentacle_i].last_miss_timestamp = now;
+		    }
+		}
 	      if (!disable_miss)
 		{
 		  msg =
@@ -1266,7 +1329,7 @@ void
 lw6p2p_node_close (lw6p2p_node_t * node)
 {
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -1497,17 +1560,17 @@ _lw6p2p_node_insert_discovered (_lw6p2p_node_t * node, char *public_url)
 }
 
 int
-_lw6p2p_node_update_peer (_lw6p2p_node_t * node, const char *version,
-			  const char *codename, int stamp, const char *id,
-			  const char *url, const char *title,
-			  const char *description, int has_password,
-			  int bench, int open_relay, int creation_timestamp,
-			  const char *community_id, int round,
-			  const char *level, int required_bench,
-			  int nb_colors, int max_nb_colors, int nb_cursors,
-			  int max_nb_cursors, int nb_nodes, int max_nb_nodes,
-			  const char *ip, int port, int last_ping_timestamp,
-			  int ping_delay_msec)
+_lw6p2p_node_update_peer_info_x (_lw6p2p_node_t * node, const char *version,
+				 const char *codename, int stamp,
+				 const char *id, const char *url,
+				 const char *title, const char *description,
+				 int has_password, int bench, int open_relay,
+				 int creation_timestamp,
+				 const char *community_id, int round,
+				 const char *level, int required_bench,
+				 int nb_colors, int max_nb_colors,
+				 int nb_cursors, int max_nb_cursors,
+				 int nb_nodes, int max_nb_nodes)
 {
   int ret = 1;
   char *query = NULL;
@@ -1542,7 +1605,7 @@ _lw6p2p_node_update_peer (_lw6p2p_node_t * node, const char *version,
 
   query = lw6sys_new_sprintf (_lw6p2p_db_get_query
 			      (node->db,
-			       _LW6P2P_UPDATE_NODE_SQL),
+			       _LW6P2P_UPDATE_NODE_INFO_SQL),
 			      creation_timestamp, escaped_version,
 			      escaped_codename, stamp,
 			      escaped_id, escaped_title,
@@ -1550,9 +1613,7 @@ _lw6p2p_node_update_peer (_lw6p2p_node_t * node, const char *version,
 			      bench, open_relay, escaped_community_id, round,
 			      escaped_level, required_bench, nb_colors,
 			      max_nb_colors, nb_cursors, max_nb_cursors,
-			      nb_nodes, max_nb_nodes, ip, port,
-			      last_ping_timestamp, ping_delay_msec, available,
-			      escaped_url);
+			      nb_nodes, max_nb_nodes, available, escaped_url);
   if (query)
     {
       if (_lw6p2p_db_lock (node->db))
@@ -1599,6 +1660,87 @@ _lw6p2p_node_update_peer (_lw6p2p_node_t * node, const char *version,
   return ret;
 }
 
+int
+_lw6p2p_node_update_peer_info (_lw6p2p_node_t * node,
+			       lw6nod_info_t * peer_info)
+{
+  int ret = 1;
+
+  ret =
+    _lw6p2p_node_update_peer_info_x (node, peer_info->const_info.version,
+				     peer_info->const_info.codename,
+				     peer_info->const_info.stamp,
+				     peer_info->const_info.ref_info.id_str,
+				     peer_info->const_info.ref_info.url,
+				     peer_info->const_info.title,
+				     peer_info->const_info.description,
+				     peer_info->const_info.has_password,
+				     peer_info->const_info.bench,
+				     peer_info->const_info.open_relay,
+				     _lw6p2p_db_timestamp (node->db,
+							   peer_info->
+							   const_info.creation_timestamp),
+				     lw6sys_str_empty_if_null (peer_info->
+							       dyn_info.
+							       community_id_str),
+				     peer_info->dyn_info.round,
+				     lw6sys_str_empty_if_null (peer_info->
+							       dyn_info.
+							       level),
+				     peer_info->dyn_info.required_bench,
+				     peer_info->dyn_info.nb_colors,
+				     peer_info->dyn_info.max_nb_colors,
+				     peer_info->dyn_info.nb_cursors,
+				     peer_info->dyn_info.max_nb_cursors,
+				     peer_info->dyn_info.nb_nodes,
+				     peer_info->dyn_info.max_nb_nodes);
+
+  return ret;
+}
+
+int
+_lw6p2p_node_update_peer_net (_lw6p2p_node_t * node,
+			      const char *id,
+			      const char *url,
+			      const char *ip, int port,
+			      int last_ping_timestamp, int ping_delay_msec)
+{
+  int ret = 1;
+  char *query = NULL;
+  char *escaped_id = NULL;
+  char *escaped_url = NULL;
+
+  escaped_id = lw6sys_escape_sql_value (id);
+  escaped_url = lw6sys_escape_sql_value (url);
+
+  query = lw6sys_new_sprintf (_lw6p2p_db_get_query
+			      (node->db,
+			       _LW6P2P_UPDATE_NODE_NET_SQL),
+			      ip, port,
+			      last_ping_timestamp, ping_delay_msec,
+			      escaped_url);
+  if (query)
+    {
+      if (_lw6p2p_db_lock (node->db))
+	{
+	  ret = _lw6p2p_db_exec_ignore_data (node->db, query);
+	  _lw6p2p_db_unlock (node->db);
+	}
+      LW6SYS_FREE (query);
+    }
+
+  if (escaped_id)
+    {
+      LW6SYS_FREE (escaped_id);
+    }
+  if (escaped_url)
+    {
+      LW6SYS_FREE (escaped_url);
+    }
+
+  return ret;
+}
+
 int
 _lw6p2p_node_update_local (_lw6p2p_node_t * node, lw6nod_info_t * node_info)
 {
@@ -1608,33 +1750,13 @@ _lw6p2p_node_update_local (_lw6p2p_node_t * node, lw6nod_info_t * node_info)
    * Call the generic update_peer function for that matter, in fact
    * the update is pretty much the same except for the IP/port & timeout
    */
+  ret = _lw6p2p_node_update_peer_info (node, node_info) && ret;
+
   ret =
-    _lw6p2p_node_update_peer (node, node_info->const_info.version,
-			      node_info->const_info.codename,
-			      node_info->const_info.stamp,
-			      node_info->const_info.ref_info.id_str,
-			      node_info->const_info.ref_info.url,
-			      node_info->const_info.title,
-			      node_info->const_info.description,
-			      node_info->const_info.has_password,
-			      node_info->const_info.bench,
-			      node_info->const_info.open_relay,
-			      _lw6p2p_db_timestamp (node->db,
-						    node_info->
-						    const_info.creation_timestamp),
-			      lw6sys_str_empty_if_null (node_info->
-							dyn_info.community_id_str),
-			      node_info->dyn_info.round,
-			      lw6sys_str_empty_if_null (node_info->
-							dyn_info.level),
-			      node_info->dyn_info.required_bench,
-			      node_info->dyn_info.nb_colors,
-			      node_info->dyn_info.max_nb_colors,
-			      node_info->dyn_info.nb_cursors,
-			      node_info->dyn_info.max_nb_cursors,
-			      node_info->dyn_info.nb_nodes,
-			      node_info->dyn_info.max_nb_nodes, node->bind_ip,
-			      node->bind_port, 0, 0);
+    _lw6p2p_node_update_peer_net (node, node_info->const_info.ref_info.id_str,
+				  node_info->const_info.ref_info.url,
+				  node->bind_ip, node->bind_port, 0, 0)
+    && ret;
 
   return ret;
 }
@@ -1870,7 +1992,7 @@ lw6p2p_node_get_entries (lw6p2p_node_t * node, int skip_local)
   lw6sys_list_t *ret = NULL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -1917,7 +2039,7 @@ _lw6p2p_node_server_start (_lw6p2p_node_t * node, int64_t seq_0)
  *
  * @node: node to start
  * @seq_0: seq when starting the server
- * 
+ *
  * Starts a node in server mode, if node was previously connected to other
  * nodes, disconnect it from any peer.
  *
@@ -1929,7 +2051,7 @@ lw6p2p_node_server_start (lw6p2p_node_t * node, int64_t seq_0)
   int ret = 0;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2132,8 +2254,8 @@ _lw6p2p_node_client_join (_lw6p2p_node_t * node, u_int64_t remote_id,
  * @remote_id: id of remote node to join
  * @remote_url: url of remote node to join
  * @progress: progress indicator to show end-user the advancement of process
- * 
- * Starts a node in client mode, joins the given node, 
+ *
+ * Starts a node in client mode, joins the given node,
  * if node was previously connected to other
  * nodes, disconnect it from any peer.
  *
@@ -2146,7 +2268,7 @@ lw6p2p_node_client_join (lw6p2p_node_t * node, u_int64_t remote_id,
   int ret = 0;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2160,6 +2282,64 @@ lw6p2p_node_client_join (lw6p2p_node_t * node, u_int64_t remote_id,
   return ret;
 }
 
+/*
+ * This function *must* be called in locked mode
+ */
+int
+_lw6p2p_node_refresh_peer (_lw6p2p_node_t * node, u_int64_t remote_id,
+			   const char *remote_url)
+{
+  int ret = 1;
+  char *url_from_id = NULL;
+
+  url_from_id =
+    lw6nod_info_community_get_url_from_id (node->node_info, remote_id);
+  if (url_from_id)
+    {
+      if (!lw6sys_str_is_same (remote_url, url_from_id))
+	{
+	  _lw6p2p_explore_start_verify_node (node, url_from_id);
+	}
+      LW6SYS_FREE (url_from_id);
+    }
+  _lw6p2p_explore_start_verify_node (node, remote_url);
+
+  return ret;
+}
+
+/**
+ * lw6p2p_node_refresh_peer
+ *
+ * @node: node to use
+ * @remote_id: id of remote node to refresh
+ * @remote_url: url of remote node to refresh
+ *
+ * Forces a refresh of a remote node, that is, try and get more up-to-date
+ * informations from it, not waiting for the standard update schedule.
+ *
+ * Return value: 1 on success, 0 on failure.
+ */
+int
+lw6p2p_node_refresh_peer (lw6p2p_node_t * node, u_int64_t remote_id,
+			  const char *remote_url)
+{
+  int ret = 0;
+
+  /*
+   * We lock in public function, the private one does not use
+   * the lock, because it could be used in other functions
+   * that are themselves locked...
+   */
+  if (_node_lock (node))
+    {
+      ret = _lw6p2p_node_refresh_peer ((_lw6p2p_node_t *) node, remote_id,
+				       remote_url);
+      _node_unlock (node);
+    }
+
+  return ret;
+}
+
 void
 _lw6p2p_node_disconnect (_lw6p2p_node_t * node)
 {
@@ -2200,7 +2380,7 @@ _lw6p2p_node_disconnect (_lw6p2p_node_t * node)
  * lw6p2p_node_disconnect
  *
  * @node: node to disconnect
- * 
+ *
  * Disconnects a node, if node was previously connected to other
  * nodes, disconnect it from any peer. Note that this does not
  * affect out-of-band connections, only real game-related links.
@@ -2211,7 +2391,7 @@ void
 lw6p2p_node_disconnect (lw6p2p_node_t * node)
 {
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2275,7 +2455,7 @@ lw6p2p_node_update_info (lw6p2p_node_t * node,
 {
   int ret = 0;
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2317,7 +2497,7 @@ void
 lw6p2p_node_calibrate (lw6p2p_node_t * node, int64_t timestamp, int64_t seq)
 {
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2355,7 +2535,7 @@ lw6p2p_node_get_local_seq_0 (lw6p2p_node_t * node)
   int64_t ret = 0LL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2397,7 +2577,7 @@ lw6p2p_node_get_local_seq_last (lw6p2p_node_t * node)
   int64_t ret = 0LL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2438,7 +2618,7 @@ lw6p2p_node_get_seq_min (lw6p2p_node_t * node)
   int64_t ret = 0LL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2479,7 +2659,7 @@ lw6p2p_node_get_seq_max (lw6p2p_node_t * node)
   int64_t ret = 0LL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2521,7 +2701,7 @@ lw6p2p_node_get_seq_draft (lw6p2p_node_t * node)
   int64_t ret = 0LL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2564,7 +2744,7 @@ lw6p2p_node_get_seq_reference (lw6p2p_node_t * node)
   int64_t ret = 0LL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2607,7 +2787,7 @@ lw6p2p_node_is_peer_connected (lw6p2p_node_t * node, u_int64_t peer_id)
   int64_t ret = 0LL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2652,7 +2832,7 @@ lw6p2p_node_is_peer_registered (lw6p2p_node_t * node, u_int64_t peer_id)
   int64_t ret = 0LL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2700,7 +2880,7 @@ lw6p2p_node_is_seed_needed (lw6p2p_node_t * node)
   int ret = 0;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2747,7 +2927,7 @@ lw6p2p_node_is_dump_needed (lw6p2p_node_t * node)
   int ret = 0;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2790,7 +2970,7 @@ lw6p2p_node_put_local_msg (lw6p2p_node_t * node, const char *msg)
   int ret = 0;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2853,7 +3033,7 @@ lw6p2p_node_get_next_reference_msg (lw6p2p_node_t * node,
   char *ret = NULL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
@@ -2896,7 +3076,7 @@ _lw6p2p_node_get_next_draft_msg (_lw6p2p_node_t * node,
 	  /*
 	   * Special case, we do not even have *one* full message in stock
 	   * so we just get any seq available (the last one for that matter) and
-	   * call blindly the get_msg function, not to really get the message 
+	   * call blindly the get_msg function, not to really get the message
 	   * (there is none) but to trigger the code that will update MISS ranges
 	   */
 	  seq_min = lw6dat_warehouse_get_seq_min (node->warehouse);
@@ -2949,7 +3129,7 @@ lw6p2p_node_get_next_draft_msg (lw6p2p_node_t * node,
   char *ret = NULL;
 
   /*
-   * We lock in public function, the private one does not use 
+   * We lock in public function, the private one does not use
    * the lock, because it could be used in other functions
    * that are themselves locked...
    */
