@@ -63,6 +63,32 @@
 #define _TEST_ENTRY_PING_DELAY_MSEC 500
 #define _TEST_ENTRY_AVAILABLE 1
 
+#define _TEST_TENTACLE_DURATION_THREAD 10000
+#define _TEST_TENTACLE_BIND_IP1 "127.0.0.1"
+#define _TEST_TENTACLE_BIND_PORT1 8058
+#define _TEST_TENTACLE_URL1 "127.0.0.1:8058"
+#define _TEST_TENTACLE_ID1 0x1234123412341234LL
+#define _TEST_TENTACLE_BIND_IP2 "127.0.0.1"
+#define _TEST_TENTACLE_BIND_PORT2 8059
+#define _TEST_TENTACLE_URL2 "127.0.0.1:8059"
+#define _TEST_TENTACLE_ID2 0x2345234523452345LL
+#define _TEST_TENTACLE_PASSWORD "toto"
+#define _TEST_TENTACLE_NETWORK_RELIABILITY 10
+
+#define _TEST_PACKET_LOGICAL_TICKET_SIG_1 0x12341234
+#define _TEST_PACKET_PHYSICAL_TICKET_SIG_1 0x23452345
+#define _TEST_PACKET_LOGICAL_FROM_ID_1 0x2345234523452345LL
+#define _TEST_PACKET_LOGICAL_TO_ID_1 0x3456345634563456LL
+#define _TEST_PACKET_MSG_1 "toto"
+#define _TEST_PACKET_CHECKSUM_1 0xbfad51f5
+#define _TEST_PACKET_LOGICAL_TICKET_SIG_2 0x12341234
+#define _TEST_PACKET_PHYSICAL_TICKET_SIG_2 0x23452345
+#define _TEST_PACKET_LOGICAL_FROM_ID_2 0x2345234523452345LL
+#define _TEST_PACKET_LOGICAL_TO_ID_2 0x3456345634563456LL
+#define _TEST_PACKET_MSG_2 "titi"
+#define _TEST_PACKET_CHECKSUM_2 0xa1f8f755
+#define _TEST_PACKET_COMPARE +1
+
 #define _TEST_NODE_BIND_IP LW6NET_ADDRESS_LOOPBACK
 #define _TEST_NODE_BIND_PORT1 (LW6NET_DEFAULT_PORT + 11)
 #define _TEST_NODE_BIND_PORT2 (LW6NET_DEFAULT_PORT + 12)
@@ -145,6 +171,7 @@
 #define _TEST_NODE_PUBLIC_URL4 "http://localhost:8070/"
 #define _TEST_NODE_PUBLIC_URL5 "http://localhost:8071/"
 #define _TEST_NODE_PUBLIC_URL6 "http://localhost:8072/"
+#define _TEST_NODE_UNREACHABLE_URL "http://ufoot.org:9000/"
 #define _TEST_NODE_IP1 NULL
 #define _TEST_NODE_IP2 NULL
 #define _TEST_NODE_IP3 LW6NET_ADDRESS_LOOPBACK
@@ -169,6 +196,7 @@
 #define _TEST_BOGUS_BACKEND "bogus"
 
 #define _TEST_NODE_ACK_DELAY_MSEC 7500
+#define _TEST_NODE_REFRESH_DURATION 3000
 #define _TEST_NODE_OOB_DURATION 9000
 #define _TEST_NODE_CMD_DURATION (9000+_TEST_NODE_ACK_DELAY_MSEC)
 #define _TEST_NODE_API_DURATION_JOIN 500
@@ -205,7 +233,7 @@ typedef struct _lw6p2p_test_data_s
 
 static _lw6p2p_test_data_t _test_data = { 0 };
 
-/* 
+/*
  * Testing db
  */
 static void
@@ -226,10 +254,10 @@ _test_db ()
 		lw6p2p_db_default_name (), _TEST_DB_NAME12);
 
     db = lw6p2p_db_open (argc, argv, _TEST_DB_NAME12);
-    if (db)
+    if (LW6SYS_TEST_ACK (db))
       {
 	repr = lw6p2p_db_repr (db);
-	if (repr)
+	if (LW6SYS_TEST_ACK (repr))
 	  {
 	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created db \"%s\""), repr);
 	    LW6SYS_FREE (repr);
@@ -242,7 +270,7 @@ _test_db ()
 	ret = 0;
       }
 
-    if (lw6p2p_db_reset (argc, argv, _TEST_DB_NAME12))
+    if (LW6SYS_TEST_ACK (lw6p2p_db_reset (argc, argv, _TEST_DB_NAME12)))
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("deleted db"));
       }
@@ -256,7 +284,7 @@ _test_db ()
   LW6SYS_TEST_FUNCTION_END;
 }
 
-/* 
+/*
  * Testing entry
  */
 static void
@@ -295,10 +323,10 @@ _test_entry ()
 			      _TEST_ENTRY_LAST_PING_TIMESTAMP,
 			      _TEST_ENTRY_PING_DELAY_MSEC,
 			      _TEST_ENTRY_AVAILABLE);
-    if (entry)
+    if (LW6SYS_TEST_ACK (entry))
       {
 	repr = lw6p2p_entry_repr (entry);
-	if (repr)
+	if (LW6SYS_TEST_ACK (repr))
 	  {
 	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("entry created: \"%s\""),
 			repr);
@@ -317,7 +345,383 @@ _test_entry ()
   LW6SYS_TEST_FUNCTION_END;
 }
 
-/* 
+typedef struct _test_tentacle_data_s
+{
+  _lw6p2p_tentacle_t tentacle;
+  _lw6p2p_backends_t backends;
+  lw6srv_listener_t *listener;
+  float progress_value;
+  lw6sys_progress_t progress;
+  int *done;
+  int ret;
+} _test_tentacle_data_t;
+
+static void
+_test_tentacle1_recv_callback (void *recv_callback_data,
+			       lw6cnx_connection_p connection,
+			       u_int32_t physical_ticket_sig,
+			       u_int32_t logical_ticket_sig,
+			       u_int64_t logical_from_id,
+			       u_int64_t logical_to_id, const char *message)
+{
+  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("tentacle1 received \"%s\""), message);
+}
+
+static void
+_test_tentacle2_recv_callback (void *recv_callback_data,
+			       lw6cnx_connection_p connection,
+			       u_int32_t physical_ticket_sig,
+			       u_int32_t logical_ticket_sig,
+			       u_int64_t logical_from_id,
+			       u_int64_t logical_to_id, const char *message)
+{
+  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("tentacle2 received \"%s\""), message);
+}
+
+static void
+_test_tentacle1_thread_callback (void *tentacle_data)
+{
+  _test_tentacle_data_t *data = (_test_tentacle_data_t *) tentacle_data;
+  int64_t end_timestamp = 0LL;
+
+  end_timestamp = lw6sys_get_timestamp () + _TEST_TENTACLE_DURATION_THREAD;
+
+  data->ret = 1;
+
+  if (_lw6p2p_tentacle_init
+      (&(data->tentacle), &(data->backends), data->listener,
+       _TEST_TENTACLE_URL1, _TEST_TENTACLE_URL2, _TEST_TENTACLE_BIND_IP2,
+       _TEST_TENTACLE_PASSWORD, _TEST_TENTACLE_ID1, _TEST_TENTACLE_ID2,
+       _TEST_TENTACLE_NETWORK_RELIABILITY, _test_tentacle1_recv_callback,
+       tentacle_data))
+    {
+      while (lw6sys_get_timestamp () < end_timestamp && !(*(data->done)))
+	{
+	  lw6sys_idle ();
+	  // todo...
+	}
+
+      _lw6p2p_tentacle_clear (&(data->tentacle));
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to init tentacle1"));
+      data->ret = 0;
+    }
+}
+
+static void
+_test_tentacle2_thread_callback (void *tentacle_data)
+{
+  _test_tentacle_data_t *data = (_test_tentacle_data_t *) tentacle_data;
+  int64_t end_timestamp = 0LL;
+
+  end_timestamp = lw6sys_get_timestamp () + _TEST_TENTACLE_DURATION_THREAD;
+
+  data->ret = 2;
+
+  if (_lw6p2p_tentacle_init
+      (&(data->tentacle), &(data->backends), data->listener,
+       _TEST_TENTACLE_URL2, _TEST_TENTACLE_URL1, _TEST_TENTACLE_BIND_IP1,
+       _TEST_TENTACLE_PASSWORD, _TEST_TENTACLE_ID2, _TEST_TENTACLE_ID1,
+       _TEST_TENTACLE_NETWORK_RELIABILITY, _test_tentacle2_recv_callback,
+       tentacle_data))
+    {
+      while (lw6sys_get_timestamp () < end_timestamp && !(*(data->done)))
+	{
+	  lw6sys_idle ();
+	  // todo...
+	}
+
+      _lw6p2p_tentacle_clear (&(data->tentacle));
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to init tentacle2"));
+      data->ret = 0;
+    }
+}
+
+static int
+_tentacle_with_backends (char *cli_backends, char *srv_backends)
+{
+  int ret = 1;
+  lw6sys_thread_handler_t *thread1 = NULL;
+  lw6sys_thread_handler_t *thread2 = NULL;
+  _test_tentacle_data_t tentacle_data1;
+  _test_tentacle_data_t tentacle_data2;
+  int done = 0;
+  const int argc = _TEST_ARGC;
+  const char *argv[] = { _TEST_ARGV0 };
+
+  lw6sys_log (LW6SYS_LOG_NOTICE,
+	      _x_ ("testing tentacle with backends \"%s\" and \"%s\""),
+	      cli_backends, srv_backends);
+
+  memset (&tentacle_data1, 0, sizeof (_test_tentacle_data_t));
+  memset (&tentacle_data2, 0, sizeof (_test_tentacle_data_t));
+
+  if (ret)
+    {
+      tentacle_data1.listener =
+	lw6srv_start (_TEST_TENTACLE_BIND_IP1, _TEST_TENTACLE_BIND_PORT1);
+      if (LW6SYS_TEST_ACK (tentacle_data1.listener))
+	{
+	  lw6sys_log (LW6SYS_LOG_NOTICE,
+		      _x_ ("listener1 listening on ip=%s port=%d"),
+		      _TEST_TENTACLE_BIND_IP1, _TEST_TENTACLE_BIND_PORT1);
+	  if (LW6SYS_TEST_ACK
+	      (_lw6p2p_backends_init_cli
+	       (argc, argv, &(tentacle_data1.backends), cli_backends)))
+	    {
+	      if (LW6SYS_TEST_ACK
+		  (_lw6p2p_backends_init_srv
+		   (argc, argv, &(tentacle_data1.backends), srv_backends,
+		    tentacle_data1.listener)))
+		{
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_WARNING,
+			      _x_ ("unable to open srv backends1 \"%s\""),
+			      srv_backends);
+		  ret = 0;
+		}
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _x_ ("unable to open cli backends1 \"%s\""),
+			  cli_backends);
+	      ret = 0;
+	    }
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _x_ ("unable to start listener1 on ip=%s port=%d"),
+		      _TEST_TENTACLE_BIND_IP1, _TEST_TENTACLE_BIND_PORT1);
+	  ret = 0;
+	}
+    }
+
+  if (ret)
+    {
+      tentacle_data2.listener =
+	lw6srv_start (_TEST_TENTACLE_BIND_IP2, _TEST_TENTACLE_BIND_PORT2);
+      if (LW6SYS_TEST_ACK (tentacle_data2.listener))
+	{
+	  lw6sys_log (LW6SYS_LOG_NOTICE,
+		      _x_ ("listener2 listening on ip=%s port=%d"),
+		      _TEST_TENTACLE_BIND_IP2, _TEST_TENTACLE_BIND_PORT2);
+	  if (LW6SYS_TEST_ACK
+	      (_lw6p2p_backends_init_cli
+	       (argc, argv, &(tentacle_data2.backends), cli_backends)))
+	    {
+	      if (LW6SYS_TEST_ACK
+		  (_lw6p2p_backends_init_srv
+		   (argc, argv, &(tentacle_data2.backends), srv_backends,
+		    tentacle_data2.listener)))
+		{
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_WARNING,
+			      _x_ ("unable to open srv backends2 \"%s\""),
+			      srv_backends);
+		  ret = 0;
+		}
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _x_ ("unable to open cli backends2 \"%s\""),
+			  cli_backends);
+	      ret = 0;
+	    }
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _x_ ("unable to start listener2 on ip=%s port=%d"),
+		      _TEST_TENTACLE_BIND_IP2, _TEST_TENTACLE_BIND_PORT2);
+	  ret = 0;
+	}
+    }
+
+  if (ret)
+    {
+      thread1 =
+	lw6sys_thread_create (_test_tentacle1_thread_callback, NULL,
+			      (void *) &tentacle_data1);
+      thread2 =
+	lw6sys_thread_create (_test_tentacle2_thread_callback, NULL,
+			      (void *) &tentacle_data2);
+
+      tentacle_data1.done = &done;
+      tentacle_data2.done = &done;
+
+      lw6sys_progress_default (&(tentacle_data1.progress),
+			       &(tentacle_data1.progress_value));
+      lw6sys_progress_default (&(tentacle_data2.progress),
+			       &(tentacle_data2.progress_value));
+      lw6sys_progress_begin (&(tentacle_data1.progress));
+      lw6sys_progress_begin (&(tentacle_data2.progress));
+
+      if (LW6SYS_TEST_ACK (thread1 && thread2))
+	{
+	  lw6sys_log (LW6SYS_LOG_NOTICE,
+		      _x_ ("each tentacle running in its own thread"));
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _x_ ("unable to start all threads"));
+	  ret = 0;
+	}
+
+      if (thread1)
+	{
+	  lw6sys_thread_join (thread1);
+	}
+      if (thread2)
+	{
+	  lw6sys_thread_join (thread2);
+	}
+    }
+
+  _lw6p2p_backends_clear_srv (&(tentacle_data1.backends));
+  _lw6p2p_backends_clear_cli (&(tentacle_data1.backends));
+  _lw6p2p_backends_clear_srv (&(tentacle_data2.backends));
+  _lw6p2p_backends_clear_cli (&(tentacle_data2.backends));
+  if (tentacle_data1.listener)
+    {
+      lw6srv_stop (tentacle_data1.listener);
+      tentacle_data1.listener = NULL;
+    }
+  if (tentacle_data2.listener)
+    {
+      lw6srv_stop (tentacle_data2.listener);
+      tentacle_data2.listener = NULL;
+    }
+  ret = ret && tentacle_data1.ret && tentacle_data2.ret;
+  if (LW6SYS_TEST_ACK (ret))
+    {
+      lw6sys_log (LW6SYS_LOG_NOTICE,
+		  _x_ ("all tentacles completed their tests successfully"));
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_
+		  ("at least one tentacle failed to complete its test, results are tentacle_data1.ret=%d, tentacle_data2.ret=%d"),
+		  tentacle_data1.ret, tentacle_data2.ret);
+    }
+
+  return ret;
+}
+
+/*
+ * Testing tentacle
+ */
+static void
+_test_tentacle ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    ret = ret && _tentacle_with_backends ("tcp", "tcpd");
+    ret = ret && _tentacle_with_backends ("udp", "udpd");
+    _tentacle_with_backends ("http", "httpd");	// even if fails, keep going since http is optional
+    ret = ret
+      && _tentacle_with_backends (lw6cli_default_backends (),
+				  lw6srv_default_backends ());
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+}
+
+/*
+ * Testing packet
+ */
+static void
+_test_packet ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    _lw6p2p_packet_t *packet_1 = NULL;
+    _lw6p2p_packet_t *packet_2 = NULL;
+    u_int32_t checksum_1 = 0;
+    u_int32_t checksum_2 = 0;
+
+    packet_1 =
+      _lw6p2p_packet_new (_TEST_PACKET_LOGICAL_TICKET_SIG_1,
+			  _TEST_PACKET_PHYSICAL_TICKET_SIG_1,
+			  _TEST_PACKET_LOGICAL_FROM_ID_1,
+			  _TEST_PACKET_LOGICAL_TO_ID_1, _TEST_PACKET_MSG_1);
+    if (LW6SYS_TEST_ACK (packet_1))
+      {
+	packet_2 =
+	  _lw6p2p_packet_new (_TEST_PACKET_LOGICAL_TICKET_SIG_2,
+			      _TEST_PACKET_PHYSICAL_TICKET_SIG_2,
+			      _TEST_PACKET_LOGICAL_FROM_ID_2,
+			      _TEST_PACKET_LOGICAL_TO_ID_2,
+			      _TEST_PACKET_MSG_2);
+	if (LW6SYS_TEST_ACK (packet_2))
+	  {
+	    checksum_1 = _lw6p2p_packet_checksum (packet_1);
+	    checksum_2 = _lw6p2p_packet_checksum (packet_2);
+	    if (LW6SYS_TEST_ACK
+		(checksum_1 == _TEST_PACKET_CHECKSUM_1
+		 && checksum_2 == _TEST_PACKET_CHECKSUM_2))
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _x_ ("packet checksums OK (%08x,%08x)"),
+			    checksum_1, checksum_2);
+	      }
+	    else
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING,
+			    _x_
+			    ("packet checksums mismatch (%08x,%08x) vs (%08x,%08x)"),
+			    checksum_1, checksum_2, _TEST_PACKET_CHECKSUM_1,
+			    _TEST_PACKET_CHECKSUM_2);
+		ret = 0;
+	      }
+	    if (LW6SYS_TEST_ACK
+		(_lw6p2p_packet_compare (packet_1, packet_2) ==
+		 _TEST_PACKET_COMPARE))
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _x_ ("packet compare works as expected"));
+	      }
+	    else
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING,
+			    _x_ ("packet compare does not work as expected"));
+		ret = 0;
+	      }
+	    _lw6p2p_packet_free (packet_2);
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+	_lw6p2p_packet_free (packet_1);
+      }
+    else
+      {
+	ret = 0;
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+}
+
+/*
  * Testing node initialisation
  */
 static void
@@ -341,7 +745,7 @@ _test_node_init ()
     int64_t seq_reference = 0LL;
 
     db = lw6p2p_db_open (argc, argv, _TEST_DB_NAME12);
-    if (db)
+    if (LW6SYS_TEST_ACK (db))
       {
 	/*
 	 * Passing 0LL as a node id will cause automatic generation of an id
@@ -356,17 +760,17 @@ _test_node_init ()
 			   _TEST_NODE_BENCH, _TEST_NODE_OPEN_RELAY,
 			   _TEST_NODE_KNOWN_NODES1,
 			   _TEST_NODE_NETWORK_RELIABILITY, _TEST_NODE_TROJAN);
-	if (node)
+	if (LW6SYS_TEST_ACK (node))
 	  {
 	    repr = lw6p2p_node_repr (node);
-	    if (repr)
+	    if (LW6SYS_TEST_ACK (repr))
 	      {
 		lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created node \"%s\""),
 			    repr);
 		LW6SYS_FREE (repr);
 	      }
 	    id_str = lw6sys_id_ltoa (lw6p2p_node_get_id (node));
-	    if (id_str)
+	    if (LW6SYS_TEST_ACK (id_str))
 	      {
 		lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("get_id returns %s"),
 			    id_str);
@@ -417,7 +821,7 @@ _test_node_init ()
   LW6SYS_TEST_FUNCTION_END;
 }
 
-/* 
+/*
  * Initializes up to 6 nodes
  */
 static int
@@ -447,7 +851,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
       if (*db12)
 	{
 	  repr = lw6p2p_db_repr (*db12);
-	  if (repr)
+	  if (LW6SYS_TEST_ACK (repr))
 	    {
 	      lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created db \"%s\""), repr);
 	      LW6SYS_FREE (repr);
@@ -469,7 +873,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
       if (*db34)
 	{
 	  repr = lw6p2p_db_repr (*db34);
-	  if (repr)
+	  if (LW6SYS_TEST_ACK (repr))
 	    {
 	      lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created db \"%s\""), repr);
 	      LW6SYS_FREE (repr);
@@ -491,7 +895,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
       if (*db56)
 	{
 	  repr = lw6p2p_db_repr (*db56);
-	  if (repr)
+	  if (LW6SYS_TEST_ACK (repr))
 	    {
 	      lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created db \"%s\""), repr);
 	      LW6SYS_FREE (repr);
@@ -517,7 +921,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
 	  if (*node1)
 	    {
 	      repr = lw6p2p_node_repr (*node1);
-	      if (repr)
+	      if (LW6SYS_TEST_ACK (repr))
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created node1 \"%s\""),
 			      repr);
@@ -542,7 +946,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
 	  if (*node2)
 	    {
 	      repr = lw6p2p_node_repr (*node2);
-	      if (repr)
+	      if (LW6SYS_TEST_ACK (repr))
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created node2 \"%s\""),
 			      repr);
@@ -570,7 +974,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
 	  if (*node3)
 	    {
 	      repr = lw6p2p_node_repr (*node3);
-	      if (repr)
+	      if (LW6SYS_TEST_ACK (repr))
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created node3 \"%s\""),
 			      repr);
@@ -595,7 +999,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
 	  if (*node4)
 	    {
 	      repr = lw6p2p_node_repr (*node4);
-	      if (repr)
+	      if (LW6SYS_TEST_ACK (repr))
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created node4 \"%s\""),
 			      repr);
@@ -624,7 +1028,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
 	  if (*node5)
 	    {
 	      repr = lw6p2p_node_repr (*node5);
-	      if (repr)
+	      if (LW6SYS_TEST_ACK (repr))
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created node5 \"%s\""),
 			      repr);
@@ -649,7 +1053,7 @@ _init_nodes (char *cli_backends, char *srv_backends, lw6p2p_db_t ** db12,
 	  if (*node6)
 	    {
 	      repr = lw6p2p_node_repr (*node6);
-	      if (repr)
+	      if (LW6SYS_TEST_ACK (repr))
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("created node6 \"%s\""),
 			      repr);
@@ -822,7 +1226,7 @@ _print_entry_callback (void *func_data, void *data)
     }
 }
 
-/* 
+/*
  * Testing node connection
  */
 static int
@@ -851,41 +1255,65 @@ _cmd_with_backends (char *cli_backends, char *srv_backends)
       (cli_backends, srv_backends, &db12, &db34, &db56, &node1, &node2,
        &node3, &node4, &node5, &node6))
     {
-      if (_lw6p2p_node_register_tentacle
-	  ((_lw6p2p_node_t *) node1, _TEST_NODE_PUBLIC_URL2, _TEST_NODE_IP2,
-	   lw6p2p_node_get_id (node2))
-	  && _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *) node2,
-					     _TEST_NODE_PUBLIC_URL1,
-					     _TEST_NODE_IP1,
-					     lw6p2p_node_get_id (node1))
-	  && _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *) node1,
-					     _TEST_NODE_PUBLIC_URL3,
-					     _TEST_NODE_IP3,
-					     lw6p2p_node_get_id (node3))
-	  && _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *) node3,
-					     _TEST_NODE_PUBLIC_URL1,
-					     _TEST_NODE_IP1,
-					     lw6p2p_node_get_id (node1))
-	  && _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *) node1,
-					     _TEST_NODE_PUBLIC_URL4,
-					     _TEST_NODE_IP4,
-					     lw6p2p_node_get_id (node4))
-	  && _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *) node4,
-					     _TEST_NODE_PUBLIC_URL1,
-					     _TEST_NODE_IP1,
-					     lw6p2p_node_get_id (node1))
-	  && _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *) node4,
-					     _TEST_NODE_PUBLIC_URL2,
-					     _TEST_NODE_IP2,
-					     lw6p2p_node_get_id (node2))
-	  && _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *) node6,
-					     _TEST_NODE_PUBLIC_URL2,
-					     _TEST_NODE_IP2,
-					     lw6p2p_node_get_id (node2))
-	  && _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *) node5,
-					     _TEST_NODE_PUBLIC_URL1,
-					     _TEST_NODE_IP1,
-					     lw6p2p_node_get_id (node1)))
+      if (LW6SYS_TEST_ACK (_lw6p2p_node_register_tentacle
+			   ((_lw6p2p_node_t *) node1, _TEST_NODE_PUBLIC_URL2,
+			    _TEST_NODE_IP2, lw6p2p_node_get_id (node2))
+			   &&
+			   _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *)
+							   node2,
+							   _TEST_NODE_PUBLIC_URL1,
+							   _TEST_NODE_IP1,
+							   lw6p2p_node_get_id
+							   (node1))
+			   &&
+			   _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *)
+							   node1,
+							   _TEST_NODE_PUBLIC_URL3,
+							   _TEST_NODE_IP3,
+							   lw6p2p_node_get_id
+							   (node3))
+			   &&
+			   _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *)
+							   node3,
+							   _TEST_NODE_PUBLIC_URL1,
+							   _TEST_NODE_IP1,
+							   lw6p2p_node_get_id
+							   (node1))
+			   &&
+			   _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *)
+							   node1,
+							   _TEST_NODE_PUBLIC_URL4,
+							   _TEST_NODE_IP4,
+							   lw6p2p_node_get_id
+							   (node4))
+			   &&
+			   _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *)
+							   node4,
+							   _TEST_NODE_PUBLIC_URL1,
+							   _TEST_NODE_IP1,
+							   lw6p2p_node_get_id
+							   (node1))
+			   &&
+			   _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *)
+							   node4,
+							   _TEST_NODE_PUBLIC_URL2,
+							   _TEST_NODE_IP2,
+							   lw6p2p_node_get_id
+							   (node2))
+			   &&
+			   _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *)
+							   node6,
+							   _TEST_NODE_PUBLIC_URL2,
+							   _TEST_NODE_IP2,
+							   lw6p2p_node_get_id
+							   (node2))
+			   &&
+			   _lw6p2p_node_register_tentacle ((_lw6p2p_node_t *)
+							   node5,
+							   _TEST_NODE_PUBLIC_URL1,
+							   _TEST_NODE_IP1,
+							   lw6p2p_node_get_id
+							   (node1))))
 	{
 	  while (lw6sys_get_timestamp () < end_timestamp)
 	    {
@@ -909,7 +1337,7 @@ _cmd_with_backends (char *cli_backends, char *srv_backends)
   return ret;
 }
 
-/* 
+/*
  * Testing node connection
  */
 static void
@@ -946,24 +1374,48 @@ _oob_with_backends (char *cli_backends, char *srv_backends)
   lw6p2p_node_t *node5 = NULL;
   lw6p2p_node_t *node6 = NULL;
   int64_t end_timestamp = 0LL;
+  int64_t refresh_timestamp = 0LL;
 
   lw6sys_log (LW6SYS_LOG_NOTICE,
 	      _x_ ("testing oob with backends \"%s\" and \"%s\""),
 	      cli_backends, srv_backends);
 
   ret = 0;
+  refresh_timestamp = lw6sys_get_timestamp () + _TEST_NODE_REFRESH_DURATION;
   end_timestamp = lw6sys_get_timestamp () + _TEST_NODE_OOB_DURATION;
   if (_init_nodes
       (cli_backends, srv_backends, &db12, &db34, &db56, &node1, &node2,
        &node3, &node4, &node5, &node6))
     {
+      ret = 1;
+
+      while (lw6sys_get_timestamp () < refresh_timestamp)
+	{
+	  _poll_nodes (node1, node2, node3, node4, node5, node6);
+	}
+      ret =
+	lw6p2p_node_refresh_peer (node1, lw6p2p_node_get_id (node2),
+				  _TEST_NODE_UNREACHABLE_URL) && ret;
+      ret =
+	lw6p2p_node_refresh_peer (node2, lw6p2p_node_get_id (node3),
+				  _TEST_NODE_UNREACHABLE_URL) && ret;
+      ret =
+	lw6p2p_node_refresh_peer (node3, lw6p2p_node_get_id (node4),
+				  _TEST_NODE_UNREACHABLE_URL) && ret;
+      ret =
+	lw6p2p_node_refresh_peer (node4, lw6p2p_node_get_id (node5),
+				  _TEST_NODE_UNREACHABLE_URL) && ret;
+      ret =
+	lw6p2p_node_refresh_peer (node5, lw6p2p_node_get_id (node6),
+				  _TEST_NODE_UNREACHABLE_URL) && ret;
+      ret =
+	lw6p2p_node_refresh_peer (node6, lw6p2p_node_get_id (node1),
+				  _TEST_NODE_UNREACHABLE_URL) && ret;
       while (lw6sys_get_timestamp () < end_timestamp)
 	{
 	  _poll_nodes (node1, node2, node3, node4, node5, node6);
 	}
 
-      ret = 1;
-
       _quit_nodes (db12, db34, db56, node1, node2, node3, node4, node5,
 		   node6);
     }
@@ -971,7 +1423,7 @@ _oob_with_backends (char *cli_backends, char *srv_backends)
   return ret;
 }
 
-/* 
+/*
  * Testing node connection
  */
 static void
@@ -993,7 +1445,7 @@ _test_node_oob ()
   LW6SYS_TEST_FUNCTION_END;
 }
 
-/* 
+/*
  * Testing node msg
  */
 static void
@@ -1025,7 +1477,7 @@ _test_node_msg ()
     lw6sys_progress_default (&progress, &progress_value);
 
     db = lw6p2p_db_open (argc, argv, _TEST_DB_NAME12);
-    if (db)
+    if (LW6SYS_TEST_ACK (db))
       {
 	/*
 	 * Passing 0LL as a node id will cause automatic generation of an id
@@ -1040,7 +1492,7 @@ _test_node_msg ()
 			   _TEST_NODE_BENCH, _TEST_NODE_OPEN_RELAY,
 			   _TEST_NODE_KNOWN_NODES1,
 			   _TEST_NODE_NETWORK_RELIABILITY, _TEST_NODE_TROJAN);
-	if (node)
+	if (LW6SYS_TEST_ACK (node))
 	  {
 	    node_id = lw6p2p_node_get_id (node);
 	    seq = _TEST_NODE_MSG_SEQ_0;
@@ -1056,7 +1508,7 @@ _test_node_msg ()
 		      lw6sys_str_random_words (lw6sys_random
 					       (_TEST_NODE_MSG_RANDOM_STR_SIZE)
 					       + 1);
-		    if (random_str)
+		    if (LW6SYS_TEST_ACK (random_str))
 		      {
 			msg =
 			  lw6sys_new_sprintf ("%" LW6SYS_PRINTF_LL "d %"
@@ -1064,7 +1516,7 @@ _test_node_msg ()
 					      (long long) seq,
 					      (long long) node_id,
 					      k, random_str);
-			if (msg)
+			if (LW6SYS_TEST_ACK (msg))
 			  {
 			    checksums[k] = lw6sys_checksum_str (msg);
 			    msgs[k] = msg;
@@ -1099,7 +1551,7 @@ _test_node_msg ()
 			found = 1;
 		      }
 		  }
-		if (!found)
+		if (!LW6SYS_TEST_ACK (found))
 		  {
 		    lw6sys_log (LW6SYS_LOG_WARNING,
 				_x_
@@ -1110,7 +1562,8 @@ _test_node_msg ()
 		LW6SYS_FREE (msg);
 		++k;
 	      }
-	    if (k == _TEST_NODE_MSG_NB_SEQS * _TEST_NODE_MSG_NB_PER_SEQ)
+	    if (LW6SYS_TEST_ACK
+		(k == _TEST_NODE_MSG_NB_SEQS * _TEST_NODE_MSG_NB_PER_SEQ))
 	      {
 		lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("got %d draft messages"),
 			    k);
@@ -1564,7 +2017,171 @@ _test_node_api_node6_callback (void *api_data)
     }
 }
 
-/* 
+static int
+_api_with_backends (char *cli_backends, char *srv_backends)
+{
+  int ret = 1;
+  lw6p2p_db_t *db12 = NULL;
+  lw6p2p_db_t *db34 = NULL;
+  lw6p2p_db_t *db56 = NULL;
+  lw6p2p_node_t *node1 = NULL;
+  lw6p2p_node_t *node2 = NULL;
+  lw6p2p_node_t *node3 = NULL;
+  lw6p2p_node_t *node4 = NULL;
+  lw6p2p_node_t *node5 = NULL;
+  lw6p2p_node_t *node6 = NULL;
+  int64_t end_timestamp = 0LL;
+  lw6sys_thread_handler_t *thread1 = NULL;
+  lw6sys_thread_handler_t *thread2 = NULL;
+  lw6sys_thread_handler_t *thread3 = NULL;
+  lw6sys_thread_handler_t *thread4 = NULL;
+  lw6sys_thread_handler_t *thread5 = NULL;
+  lw6sys_thread_handler_t *thread6 = NULL;
+  _test_node_api_data_t api_data1;
+  _test_node_api_data_t api_data2;
+  _test_node_api_data_t api_data3;
+  _test_node_api_data_t api_data4;
+  _test_node_api_data_t api_data5;
+  _test_node_api_data_t api_data6;
+  int done = 0;
+
+  lw6sys_log (LW6SYS_LOG_NOTICE,
+	      _x_ ("testing api with backends \"%s\" and \"%s\""),
+	      cli_backends, srv_backends);
+
+  memset (&api_data1, 0, sizeof (_test_node_api_data_t));
+  memset (&api_data2, 0, sizeof (_test_node_api_data_t));
+  memset (&api_data3, 0, sizeof (_test_node_api_data_t));
+  memset (&api_data4, 0, sizeof (_test_node_api_data_t));
+  memset (&api_data5, 0, sizeof (_test_node_api_data_t));
+  memset (&api_data6, 0, sizeof (_test_node_api_data_t));
+
+  if (LW6SYS_TEST_ACK (_init_nodes
+		       (cli_backends,
+			srv_backends, &db12, &db34, &db56,
+			&node1, &node2, &node3, &node4, &node5, &node6)))
+    {
+      api_data1.node = node1;
+      api_data2.node = node2;
+      api_data3.node = node3;
+      api_data4.node = node4;
+      api_data5.node = node5;
+      api_data6.node = node6;
+      api_data1.done = &done;
+      api_data2.done = &done;
+      api_data3.done = &done;
+      api_data4.done = &done;
+      api_data5.done = &done;
+      api_data6.done = &done;
+      lw6sys_progress_default (&(api_data1.progress),
+			       &(api_data1.progress_value));
+      lw6sys_progress_default (&(api_data2.progress),
+			       &(api_data2.progress_value));
+      lw6sys_progress_default (&(api_data3.progress),
+			       &(api_data3.progress_value));
+      lw6sys_progress_default (&(api_data4.progress),
+			       &(api_data4.progress_value));
+      lw6sys_progress_default (&(api_data5.progress),
+			       &(api_data5.progress_value));
+      lw6sys_progress_default (&(api_data6.progress),
+			       &(api_data6.progress_value));
+      lw6sys_progress_begin (&(api_data1.progress));
+      lw6sys_progress_begin (&(api_data2.progress));
+      lw6sys_progress_begin (&(api_data3.progress));
+      lw6sys_progress_begin (&(api_data4.progress));
+      lw6sys_progress_begin (&(api_data5.progress));
+      lw6sys_progress_begin (&(api_data6.progress));
+
+      api_data4.peer_id = lw6p2p_node_get_id (node2);
+
+      thread1 =
+	lw6sys_thread_create (_test_node_api_node1_callback, NULL,
+			      (void *) &api_data1);
+      thread2 =
+	lw6sys_thread_create (_test_node_api_node2_callback, NULL,
+			      (void *) &api_data2);
+      thread3 =
+	lw6sys_thread_create (_test_node_api_node3_callback, NULL,
+			      (void *) &api_data3);
+      thread4 =
+	lw6sys_thread_create (_test_node_api_node4_callback, NULL,
+			      (void *) &api_data4);
+      thread5 =
+	lw6sys_thread_create (_test_node_api_node5_callback, NULL,
+			      (void *) &api_data5);
+      thread6 =
+	lw6sys_thread_create (_test_node_api_node6_callback, NULL,
+			      (void *) &api_data6);
+
+      if (LW6SYS_TEST_ACK
+	  (thread1 && thread2 && thread3 && thread4 && thread5 && thread6))
+	{
+	  lw6sys_log (LW6SYS_LOG_NOTICE,
+		      _x_ ("each node running in its own thread"));
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _x_ ("unable to start all threads"));
+	  ret = 0;
+	}
+      if (thread1)
+	{
+	  lw6sys_thread_join (thread1);
+	}
+      if (thread2)
+	{
+	  lw6sys_thread_join (thread2);
+	}
+      if (thread3)
+	{
+	  lw6sys_thread_join (thread3);
+	}
+      if (thread4)
+	{
+	  lw6sys_thread_join (thread4);
+	}
+      if (thread5)
+	{
+	  lw6sys_thread_join (thread5);
+	}
+      if (thread6)
+	{
+	  lw6sys_thread_join (thread6);
+	}
+      lw6sys_log (LW6SYS_LOG_NOTICE,
+		  _x_
+		  ("waiting for some time to let nodes handle disconnection"));
+      end_timestamp = lw6sys_get_timestamp () + _TEST_NODE_API_DURATION_END;
+      while (lw6sys_get_timestamp () < end_timestamp)
+	{
+	  _poll_nodes (node1, node2, node3, node4, node5, node6);
+	}
+
+      _quit_nodes (db12, db34, db56, node1, node2, node3, node4, node5,
+		   node6);
+
+      ret = ret && api_data1.ret && api_data2.ret && api_data3.ret
+	&& api_data4.ret && api_data5.ret && api_data6.ret;
+      if (LW6SYS_TEST_ACK (ret))
+	{
+	  lw6sys_log (LW6SYS_LOG_NOTICE,
+		      _x_ ("all nodes completed their tests successfully"));
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _x_
+		      ("at least one node failed to complete its test, results are api_data1.ret=%d, api_data2.ret=%d, api_data3.ret=%d, api_data4.ret=%d, api_data5.ret=%d, api_data6.ret=%d"),
+		      api_data1.ret, api_data2.ret, api_data3.ret,
+		      api_data4.ret, api_data5.ret, api_data6.ret);
+	}
+    }
+
+  return ret;
+}
+
+/*
  * Testing node api
  */
 static void
@@ -1574,157 +2191,12 @@ _test_node_api ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    lw6p2p_db_t *db12 = NULL;
-    lw6p2p_db_t *db34 = NULL;
-    lw6p2p_db_t *db56 = NULL;
-    lw6p2p_node_t *node1 = NULL;
-    lw6p2p_node_t *node2 = NULL;
-    lw6p2p_node_t *node3 = NULL;
-    lw6p2p_node_t *node4 = NULL;
-    lw6p2p_node_t *node5 = NULL;
-    lw6p2p_node_t *node6 = NULL;
-    int64_t end_timestamp = 0LL;
-    lw6sys_thread_handler_t *thread1 = NULL;
-    lw6sys_thread_handler_t *thread2 = NULL;
-    lw6sys_thread_handler_t *thread3 = NULL;
-    lw6sys_thread_handler_t *thread4 = NULL;
-    lw6sys_thread_handler_t *thread5 = NULL;
-    lw6sys_thread_handler_t *thread6 = NULL;
-    _test_node_api_data_t api_data1;
-    _test_node_api_data_t api_data2;
-    _test_node_api_data_t api_data3;
-    _test_node_api_data_t api_data4;
-    _test_node_api_data_t api_data5;
-    _test_node_api_data_t api_data6;
-    int done = 0;
-
-    memset (&api_data1, 0, sizeof (_test_node_api_data_t));
-    memset (&api_data2, 0, sizeof (_test_node_api_data_t));
-    memset (&api_data3, 0, sizeof (_test_node_api_data_t));
-    memset (&api_data4, 0, sizeof (_test_node_api_data_t));
-    memset (&api_data5, 0, sizeof (_test_node_api_data_t));
-    memset (&api_data6, 0, sizeof (_test_node_api_data_t));
-
-    if (_init_nodes
-	(lw6cli_default_backends (),
-	 lw6srv_default_backends (), &db12, &db34, &db56, &node1, &node2,
-	 &node3, &node4, &node5, &node6))
-      {
-	api_data1.node = node1;
-	api_data2.node = node2;
-	api_data3.node = node3;
-	api_data4.node = node4;
-	api_data5.node = node5;
-	api_data6.node = node6;
-	api_data1.done = &done;
-	api_data2.done = &done;
-	api_data3.done = &done;
-	api_data4.done = &done;
-	api_data5.done = &done;
-	api_data6.done = &done;
-	lw6sys_progress_default (&(api_data1.progress),
-				 &(api_data1.progress_value));
-	lw6sys_progress_default (&(api_data2.progress),
-				 &(api_data2.progress_value));
-	lw6sys_progress_default (&(api_data3.progress),
-				 &(api_data3.progress_value));
-	lw6sys_progress_default (&(api_data4.progress),
-				 &(api_data4.progress_value));
-	lw6sys_progress_default (&(api_data5.progress),
-				 &(api_data5.progress_value));
-	lw6sys_progress_default (&(api_data6.progress),
-				 &(api_data6.progress_value));
-	lw6sys_progress_begin (&(api_data1.progress));
-	lw6sys_progress_begin (&(api_data2.progress));
-	lw6sys_progress_begin (&(api_data3.progress));
-	lw6sys_progress_begin (&(api_data4.progress));
-	lw6sys_progress_begin (&(api_data5.progress));
-	lw6sys_progress_begin (&(api_data6.progress));
-
-	api_data4.peer_id = lw6p2p_node_get_id (node2);
-
-	thread1 =
-	  lw6sys_thread_create (_test_node_api_node1_callback, NULL,
-				(void *) &api_data1);
-	thread2 =
-	  lw6sys_thread_create (_test_node_api_node2_callback, NULL,
-				(void *) &api_data2);
-	thread3 =
-	  lw6sys_thread_create (_test_node_api_node3_callback, NULL,
-				(void *) &api_data3);
-	thread4 =
-	  lw6sys_thread_create (_test_node_api_node4_callback, NULL,
-				(void *) &api_data4);
-	thread5 =
-	  lw6sys_thread_create (_test_node_api_node5_callback, NULL,
-				(void *) &api_data5);
-	thread6 =
-	  lw6sys_thread_create (_test_node_api_node6_callback, NULL,
-				(void *) &api_data6);
-
-	if (thread1 && thread2 && thread3 && thread4 && thread5 && thread6)
-	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE,
-			_x_ ("each node running in its own thread"));
-	  }
-	else
-	  {
-	    lw6sys_log (LW6SYS_LOG_WARNING,
-			_x_ ("unable to start all threads"));
-	    ret = 0;
-	  }
-	if (thread1)
-	  {
-	    lw6sys_thread_join (thread1);
-	  }
-	if (thread2)
-	  {
-	    lw6sys_thread_join (thread2);
-	  }
-	if (thread3)
-	  {
-	    lw6sys_thread_join (thread3);
-	  }
-	if (thread4)
-	  {
-	    lw6sys_thread_join (thread4);
-	  }
-	if (thread5)
-	  {
-	    lw6sys_thread_join (thread5);
-	  }
-	if (thread6)
-	  {
-	    lw6sys_thread_join (thread6);
-	  }
-	lw6sys_log (LW6SYS_LOG_NOTICE,
-		    _x_
-		    ("waiting for some time to let nodes handle disconnection"));
-	end_timestamp = lw6sys_get_timestamp () + _TEST_NODE_API_DURATION_END;
-	while (lw6sys_get_timestamp () < end_timestamp)
-	  {
-	    _poll_nodes (node1, node2, node3, node4, node5, node6);
-	  }
-
-	_quit_nodes (db12, db34, db56, node1, node2, node3, node4, node5,
-		     node6);
-
-	ret = ret && api_data1.ret && api_data2.ret && api_data3.ret
-	  && api_data4.ret && api_data5.ret && api_data6.ret;
-	if (ret)
-	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE,
-			_x_ ("all nodes completed their tests successfully"));
-	  }
-	else
-	  {
-	    lw6sys_log (LW6SYS_LOG_WARNING,
-			_x_
-			("at least one node failed to complete its test, results are api_data1.ret=%d, api_data2.ret=%d, api_data3.ret=%d, api_data4.ret=%d, api_data5.ret=%d, api_data6.ret=%d"),
-			api_data1.ret, api_data2.ret, api_data3.ret,
-			api_data4.ret, api_data5.ret, api_data6.ret);
-	  }
-      }
+    ret = ret && _api_with_backends ("tcp", "tcpd");
+    ret = ret && _api_with_backends ("udp", "udpd");
+    _api_with_backends ("http", "httpd");	// even if fails, keep going since http is optional
+    ret = ret
+      && _api_with_backends (lw6cli_default_backends (),
+			     lw6srv_default_backends ());
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -1797,6 +2269,8 @@ lw6p2p_test_register (int mode)
     {
       LW6SYS_CUNIT_ADD_TEST (suite, _test_db);
       LW6SYS_CUNIT_ADD_TEST (suite, _test_entry);
+      LW6SYS_CUNIT_ADD_TEST (suite, _test_packet);
+      LW6SYS_CUNIT_ADD_TEST (suite, _test_tentacle);
       LW6SYS_CUNIT_ADD_TEST (suite, _test_node_init);
       LW6SYS_CUNIT_ADD_TEST (suite, _test_node_oob);
       LW6SYS_CUNIT_ADD_TEST (suite, _test_node_cmd);
