@@ -35,7 +35,7 @@
  * try and identify the objects in their on per-process lists,
  * structures, Guile object, whatever they use.
  */
-static u_int32_t seq_id = 0;
+static volatile u_int32_t seq_id = 0;
 
 _lw6pil_pilot_t *
 _lw6pil_pilot_new (lw6ker_game_state_t * game_state, int64_t seq_0,
@@ -498,6 +498,7 @@ _commit_draft (_lw6pil_pilot_t * pilot)
 	  sync_draft_from_reference (pilot);
 
 	  lw6sys_spinlock_lock (pilot->draft.commands_spinlock);
+
 	  replay = lw6sys_list_new ((lw6sys_free_func_t) lw6pil_command_free);
 	  if (replay)
 	    {
@@ -790,8 +791,8 @@ _lw6pil_pilot_sync_from_draft (lw6ker_game_state_t * target,
  * It might even be in an inconsistent state, the position could reflect
  * a position which will never exist. Still, the data returned will not
  * correspond to a half-spread or half-moved game_state if dirty_read
- * is set to 0. In this case the data has at least some basic consistency 
- * and getting this does require some mutex lock, however wait time should 
+ * is set to 0. In this case the data has at least some basic consistency
+ * and getting this does require some mutex lock, however wait time should
  * be fairly small (max. a round). But, in a general manner, this function
  * is only used for display, and we do not care much if there's a small
  * glitch, we prefer fast & smooth display.
@@ -852,7 +853,7 @@ lw6pil_pilot_dirty_read (lw6pil_pilot_t * pilot)
 }
 
 char *
-_lw6pil_pilot_repr (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_repr (const _lw6pil_pilot_t * pilot)
 {
   char *ret = NULL;
 
@@ -889,7 +890,7 @@ _lw6pil_pilot_repr (_lw6pil_pilot_t * pilot)
  * Return value: a dynamically allocated string.
  */
 char *
-lw6pil_pilot_repr (lw6pil_pilot_t * pilot)
+lw6pil_pilot_repr (const lw6pil_pilot_t * pilot)
 {
   return _lw6pil_pilot_repr ((_lw6pil_pilot_t *) pilot);
 }
@@ -968,7 +969,7 @@ lw6pil_pilot_slow_down (lw6pil_pilot_t * pilot, int seq_dec)
 }
 
 int
-_lw6pil_pilot_get_round_0 (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_get_round_0 (const _lw6pil_pilot_t * pilot)
 {
   return pilot->round_0;
 }
@@ -977,20 +978,20 @@ _lw6pil_pilot_get_round_0 (_lw6pil_pilot_t * pilot)
  * lw6pil_pilot_get_round_0
  *
  * @pilot: pilot object to query
- * 
+ *
  * Get the initial round (the one passed at object construction) which
  * says what the round was at object creation, it's just an offset.
  *
  * Return value: 64-bit integer
  */
 int
-lw6pil_pilot_get_round_0 (lw6pil_pilot_t * pilot)
+lw6pil_pilot_get_round_0 (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_get_round_0 ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_get_round_0 ((const _lw6pil_pilot_t *) pilot);
 }
 
 int64_t
-_lw6pil_pilot_get_seq_0 (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_get_seq_0 (const _lw6pil_pilot_t * pilot)
 {
   return pilot->seq_0;
 }
@@ -999,20 +1000,20 @@ _lw6pil_pilot_get_seq_0 (_lw6pil_pilot_t * pilot)
  * lw6pil_pilot_get_seq_0
  *
  * @pilot: pilot object to query
- * 
+ *
  * Get the initial seq (the one passed at object construction) which
  * says what the seq was at round=0, it's just an offset.
  *
  * Return value: 64-bit integer
  */
 int64_t
-lw6pil_pilot_get_seq_0 (lw6pil_pilot_t * pilot)
+lw6pil_pilot_get_seq_0 (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_get_seq_0 ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_get_seq_0 ((const _lw6pil_pilot_t *) pilot);
 }
 
 int
-_lw6pil_pilot_seq2round (_lw6pil_pilot_t * pilot, int64_t seq)
+_lw6pil_pilot_seq2round (const _lw6pil_pilot_t * pilot, int64_t seq)
 {
   return (seq >=
 	  _LW6PIL_MIN_SEQ_0 ? ((seq - _lw6pil_pilot_get_seq_0 (pilot)) +
@@ -1024,7 +1025,7 @@ _lw6pil_pilot_seq2round (_lw6pil_pilot_t * pilot, int64_t seq)
  *
  * @pilot: pilot object to work on
  * @seq: the seq to convert
- * 
+ *
  * Converts a seq (64-bit) to a round (32-bit). 64-bit seqs are used
  * to avoid out-of-range errors on very long games, OTOH a round is 32-bit
  * to garantee the atomicity of its affection, even on platforms which
@@ -1033,13 +1034,13 @@ _lw6pil_pilot_seq2round (_lw6pil_pilot_t * pilot, int64_t seq)
  * Return value: the round (32-bit integer)
  */
 int
-lw6pil_pilot_seq2round (lw6pil_pilot_t * pilot, int64_t seq)
+lw6pil_pilot_seq2round (const lw6pil_pilot_t * pilot, int64_t seq)
 {
-  return _lw6pil_pilot_seq2round ((_lw6pil_pilot_t *) pilot, seq);
+  return _lw6pil_pilot_seq2round ((const _lw6pil_pilot_t *) pilot, seq);
 }
 
 int64_t
-_lw6pil_pilot_round2seq (_lw6pil_pilot_t * pilot, int round)
+_lw6pil_pilot_round2seq (const _lw6pil_pilot_t * pilot, int round)
 {
   return round + _lw6pil_pilot_get_seq_0 (pilot) -
     _lw6pil_pilot_get_round_0 (pilot);
@@ -1050,7 +1051,7 @@ _lw6pil_pilot_round2seq (_lw6pil_pilot_t * pilot, int round)
  *
  * @pilot: pilot object to work on
  * @round: the round to convert
- * 
+ *
  * Converts a round (32-bit) to a seq (64-bit). 64-bit seqs are used
  * to avoid out-of-range errors on very long games, OTOH a round is 32-bit
  * to garantee the atomicity of its affection, even on platforms which
@@ -1059,13 +1060,13 @@ _lw6pil_pilot_round2seq (_lw6pil_pilot_t * pilot, int round)
  * Return value: the seq (64-bit integer)
  */
 int64_t
-lw6pil_pilot_round2seq (lw6pil_pilot_t * pilot, int round)
+lw6pil_pilot_round2seq (const lw6pil_pilot_t * pilot, int round)
 {
   return _lw6pil_pilot_round2seq ((_lw6pil_pilot_t *) pilot, round);
 }
 
 int64_t
-_lw6pil_pilot_get_next_seq (_lw6pil_pilot_t * pilot, int64_t timestamp)
+_lw6pil_pilot_get_next_seq (const _lw6pil_pilot_t * pilot, int64_t timestamp)
 {
   int64_t next_seq = 0LL;
   int64_t last_commit_seq = 0LL;
@@ -1108,13 +1109,14 @@ _lw6pil_pilot_get_next_seq (_lw6pil_pilot_t * pilot, int64_t timestamp)
  * Return value: none.
  */
 int64_t
-lw6pil_pilot_get_next_seq (lw6pil_pilot_t * pilot, int64_t timestamp)
+lw6pil_pilot_get_next_seq (const lw6pil_pilot_t * pilot, int64_t timestamp)
 {
-  return _lw6pil_pilot_get_next_seq ((_lw6pil_pilot_t *) pilot, timestamp);
+  return _lw6pil_pilot_get_next_seq ((const _lw6pil_pilot_t *) pilot,
+				     timestamp);
 }
 
 int64_t
-_lw6pil_pilot_get_last_commit_seq (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_get_last_commit_seq (const _lw6pil_pilot_t * pilot)
 {
   int64_t ret = 0;
 
@@ -1134,13 +1136,13 @@ _lw6pil_pilot_get_last_commit_seq (_lw6pil_pilot_t * pilot)
  * Return value: the commit seq (reference object)
  */
 int64_t
-lw6pil_pilot_get_last_commit_seq (lw6pil_pilot_t * pilot)
+lw6pil_pilot_get_last_commit_seq (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_get_last_commit_seq ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_get_last_commit_seq ((const _lw6pil_pilot_t *) pilot);
 }
 
 int64_t
-_lw6pil_pilot_get_reference_target_seq (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_get_reference_target_seq (const _lw6pil_pilot_t * pilot)
 {
   int64_t ret = 0;
 
@@ -1164,13 +1166,14 @@ _lw6pil_pilot_get_reference_target_seq (_lw6pil_pilot_t * pilot)
  * Return value: the target seq (reference object)
  */
 int64_t
-lw6pil_pilot_get_reference_target_seq (lw6pil_pilot_t * pilot)
+lw6pil_pilot_get_reference_target_seq (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_get_reference_target_seq ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_get_reference_target_seq ((const _lw6pil_pilot_t *)
+						 pilot);
 }
 
 int64_t
-_lw6pil_pilot_get_reference_current_seq (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_get_reference_current_seq (const _lw6pil_pilot_t * pilot)
 {
   int64_t ret = 0;
 
@@ -1192,13 +1195,14 @@ _lw6pil_pilot_get_reference_current_seq (_lw6pil_pilot_t * pilot)
  * Return value: the current seq (reference object)
  */
 int64_t
-lw6pil_pilot_get_reference_current_seq (lw6pil_pilot_t * pilot)
+lw6pil_pilot_get_reference_current_seq (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_get_reference_current_seq ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_get_reference_current_seq ((const _lw6pil_pilot_t *)
+						  pilot);
 }
 
 int64_t
-_lw6pil_pilot_get_max_seq (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_get_max_seq (const _lw6pil_pilot_t * pilot)
 {
   int64_t ret = 0;
 
@@ -1222,13 +1226,13 @@ _lw6pil_pilot_get_max_seq (_lw6pil_pilot_t * pilot)
  * Return value: the current seq (reference object)
  */
 int64_t
-lw6pil_pilot_get_max_seq (lw6pil_pilot_t * pilot)
+lw6pil_pilot_get_max_seq (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_get_max_seq ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_get_max_seq ((const _lw6pil_pilot_t *) pilot);
 }
 
 int
-_lw6pil_pilot_is_over (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_is_over (const _lw6pil_pilot_t * pilot)
 {
   int ret = 0;
 
@@ -1247,13 +1251,14 @@ _lw6pil_pilot_is_over (_lw6pil_pilot_t * pilot)
  * Return value: 1 if over, 0 if not
  */
 int
-lw6pil_pilot_is_over (lw6pil_pilot_t * pilot)
+lw6pil_pilot_is_over (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_is_over ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_is_over ((const _lw6pil_pilot_t *) pilot);
 }
 
 int
-_lw6pil_pilot_did_cursor_win (_lw6pil_pilot_t * pilot, u_int16_t cursor_id)
+_lw6pil_pilot_did_cursor_win (const _lw6pil_pilot_t * pilot,
+			      u_int16_t cursor_id)
 {
   int ret = 0;
 
@@ -1278,13 +1283,15 @@ _lw6pil_pilot_did_cursor_win (_lw6pil_pilot_t * pilot, u_int16_t cursor_id)
  * Return value: 1 if over, 0 if not
  */
 int
-lw6pil_pilot_did_cursor_win (lw6pil_pilot_t * pilot, u_int16_t cursor_id)
+lw6pil_pilot_did_cursor_win (const lw6pil_pilot_t * pilot,
+			     u_int16_t cursor_id)
 {
-  return _lw6pil_pilot_did_cursor_win ((_lw6pil_pilot_t *) pilot, cursor_id);
+  return _lw6pil_pilot_did_cursor_win ((const _lw6pil_pilot_t *) pilot,
+				       cursor_id);
 }
 
 int
-_lw6pil_pilot_get_winner (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_get_winner (const _lw6pil_pilot_t * pilot)
 {
   int ret = 0;
 
@@ -1308,13 +1315,13 @@ _lw6pil_pilot_get_winner (_lw6pil_pilot_t * pilot)
  * Return value: a team color, -1 if no winner and/or error.
  */
 int
-lw6pil_pilot_get_winner (lw6pil_pilot_t * pilot)
+lw6pil_pilot_get_winner (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_get_winner ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_get_winner ((const _lw6pil_pilot_t *) pilot);
 }
 
 int
-_lw6pil_pilot_get_looser (_lw6pil_pilot_t * pilot)
+_lw6pil_pilot_get_looser (const _lw6pil_pilot_t * pilot)
 {
   int ret = 0;
 
@@ -1338,9 +1345,9 @@ _lw6pil_pilot_get_looser (_lw6pil_pilot_t * pilot)
  * Return value: a team color, -1 if no looser and/or error.
  */
 int
-lw6pil_pilot_get_looser (lw6pil_pilot_t * pilot)
+lw6pil_pilot_get_looser (const lw6pil_pilot_t * pilot)
 {
-  return _lw6pil_pilot_get_looser ((_lw6pil_pilot_t *) pilot);
+  return _lw6pil_pilot_get_looser ((const _lw6pil_pilot_t *) pilot);
 }
 
 lw6pil_local_cursors_t *
