@@ -41,8 +41,9 @@
 
 #define _HISTORY_LENGTH 256
 #define _LEVEL_LENGTH 80
-#define _MSGBOX_LENGTH 4096
-#define _BT_FACTOR 2
+#define _MSGBOX_BUF_LENGTH 8192
+#define _MSGBOX_BT_LENGTH 640
+#define _MSGBOX_BT_MIDDLE " ... "
 /*
  * For some reason seams on GNU/Linux (gtk2/xorg) systems
  * the message box is trimmed at 64 chars width. 128 makes
@@ -655,10 +656,26 @@ _log_to_console (FILE * f, const char *level_str, const char *fmt, va_list ap)
 {
   if (_console_enable_state)
     {
-      fprintf (f, "%s: %s", lw6sys_build_get_package_tarname (), level_str);
-      vfprintf (f, fmt, ap);
-      fprintf (f, "\n");
-      fflush (f);
+      time_t t_now;
+      struct tm tm_now;
+      struct tm *tm_ret = NULL;
+      struct timeval timeval_now;
+
+      memset (&t_now, 0, sizeof (time_t));
+      memset (&tm_now, 0, sizeof (struct tm));
+      memset (&timeval_now, 0, sizeof (struct timeval));
+      gettimeofday (&timeval_now, NULL);
+      t_now = timeval_now.tv_sec;
+      tm_ret = localtime_r (&t_now, &tm_now);
+      if (tm_ret == &tm_now)
+	{
+	  fprintf (f, "%s: (%02d:%02d:%02d) %s",
+		   lw6sys_build_get_package_tarname (), (int) tm_now.tm_hour,
+		   (int) tm_now.tm_min, (int) tm_now.tm_sec, level_str);
+	  vfprintf (f, fmt, ap);
+	  fprintf (f, "\n");
+	  fflush (f);
+	}
     }
 }
 
@@ -702,26 +719,25 @@ void
 _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
 		      const char *fmt, va_list ap)
 {
-  char message_raw[_MSGBOX_LENGTH + 1];
-  char message_full[_MSGBOX_LENGTH + 1];
+  char message_raw[_MSGBOX_BUF_LENGTH + 1];
+  char message_full[_MSGBOX_BUF_LENGTH + 1];
   char *bt = NULL;
-  int bt_width = 0;
   int free_bt = 0;
 
-  _lw6sys_buf_vsnprintf (message_raw, _MSGBOX_LENGTH, fmt, ap);
+  _lw6sys_buf_vsnprintf (message_raw, _MSGBOX_BUF_LENGTH, fmt, ap);
   lw6sys_str_reformat_this (message_raw, _MSGBOX_WIDTH);
-  bt = lw6sys_backtrace (2, 1);	// skip this function & caller  
+  bt = lw6sys_backtrace (2, 1);	// skip this function & caller
   if (bt)
     {
-      bt_width = lw6sys_imax (_MSGBOX_WIDTH, sqrt (strlen (bt)) * _BT_FACTOR);
-      lw6sys_str_reformat_this (bt, bt_width);
+      lw6sys_str_truncate_middle (bt, _MSGBOX_BT_LENGTH, _MSGBOX_BT_MIDDLE);
+      lw6sys_str_reformat_this (bt, _MSGBOX_WIDTH);
       free_bt = 1;
     }
   else
     {
       bt = "";
     }
-  lw6sys_buf_sprintf (message_full, _MSGBOX_LENGTH,
+  lw6sys_buf_sprintf (message_full, _MSGBOX_BUF_LENGTH,
 		      "%s (%s:%d)\n\n%s\n\n%s: %s\n\n%s: %s", level_str, file,
 		      line, message_raw, _("Backtrace"), bt, _("Report bugs"),
 		      lw6sys_build_get_bugs_url ());
@@ -807,7 +823,7 @@ _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
 	   */
 	  gtk_dialog_run (GTK_DIALOG (dlg));
 	  /*
-	   * It's important to set dlg_timeout to NULL so that 
+	   * It's important to set dlg_timeout to NULL so that
 	   * timeout thread does finish when we click on OK.
 	   */
 	  dlg_timeout = NULL;
@@ -835,10 +851,10 @@ _lw6sys_msgbox_alert (const char *level_str, const char *file, int line,
 /**
  * lw6sys_log:
  *
- * @level_id: the log level to use. Possible values are, by order, 
- *   LW6SYS_LOG_ERROR_ID (0), 
- *   LW6SYS_LOG_WARNING_ID (1), 
- *   LW6SYS_LOG_NOTICE_ID (2), 
+ * @level_id: the log level to use. Possible values are, by order,
+ *   LW6SYS_LOG_ERROR_ID (0),
+ *   LW6SYS_LOG_WARNING_ID (1),
+ *   LW6SYS_LOG_NOTICE_ID (2),
  *   LW6SYS_LOG_INFO_ID (3),
  *   LW6SYS_LOG_DEBUG_ID (4) and
  *   LW6SYS_LOG_TMP_ID (5).
