@@ -54,6 +54,8 @@
 #define README_FILE "README"
 #endif // LW6_MS_WINDOWS
 #define CWD_SIZE 2048
+#define _DIR_IF_NOT_FOUND_NB_PARENTS 5
+#define _FILE_IF_NOT_FOUND_NB_PARENTS 5
 
 /**
  * lw6sys_get_default_user_dir
@@ -275,10 +277,9 @@ static void
 dir_if_not_found (char **dir, const char *sub, int check_readme)
 {
   char *tmp = NULL;
-  char *parent1 = NULL;
-  char *parent2 = NULL;
-  char *parent3 = NULL;
+  char *parent = NULL;
   int dir_exists = 0;
+  int i = 0;
 
   if (dir && *dir)
     {
@@ -289,69 +290,39 @@ dir_if_not_found (char **dir, const char *sub, int check_readme)
 	lw6sys_dir_exists (*dir);
       if (!dir_exists)
 	{
-	  parent1 = lw6sys_path_parent (".");
-	  if (parent1)
+	  parent = lw6sys_path_parent (".");
+	  for (i = _DIR_IF_NOT_FOUND_NB_PARENTS; i > 0; --i)
 	    {
-	      tmp = lw6sys_path_concat (parent1, sub);
-	      dir_exists =
-		check_readme ?
-		lw6sys_dir_exists_with_readme_containing_text (tmp,
-							       lw6sys_build_get_home_url
-							       ()) :
-		lw6sys_dir_exists (tmp);
-	      if (dir_exists)
+	      if (parent)
 		{
-		  LW6SYS_FREE (*dir);
-		  (*dir) = tmp;
-		}
-	      else
-		{
-		  LW6SYS_FREE (tmp);
-		  parent2 = lw6sys_path_parent (parent1);
-		  if (parent2)
+		  tmp = lw6sys_path_concat (parent, sub);
+		  dir_exists =
+		    check_readme ?
+		    lw6sys_dir_exists_with_readme_containing_text (tmp,
+								   lw6sys_build_get_home_url
+								   ()) :
+		    lw6sys_dir_exists (tmp);
+		  if (dir_exists)
 		    {
-		      tmp = lw6sys_path_concat (parent2, sub);
-		      dir_exists =
-			check_readme ?
-			lw6sys_dir_exists_with_readme_containing_text (tmp,
-								       lw6sys_build_get_home_url
-								       ()) :
-			lw6sys_dir_exists (tmp);
-		      if (dir_exists)
-			{
-			  LW6SYS_FREE (*dir);
-			  (*dir) = tmp;
-			}
-		      else
-			{
-			  LW6SYS_FREE (tmp);
-			  parent3 = lw6sys_path_parent (parent2);
-			  if (parent3)
-			    {
-			      tmp = lw6sys_path_concat (parent3, sub);
-			      dir_exists =
-				check_readme ?
-				lw6sys_dir_exists_with_readme_containing_text
-				(tmp,
-				 lw6sys_build_get_home_url ()) :
-				lw6sys_dir_exists (tmp);
-			      if (dir_exists)
-				{
-				  LW6SYS_FREE (*dir);
-				  (*dir) = tmp;
-				}
-			      else
-				{
-				  LW6SYS_FREE (tmp);
-				}
-			      LW6SYS_FREE (parent3);
-			    }
-			}
-		      LW6SYS_FREE (parent2);
+		      LW6SYS_FREE (*dir);
+		      (*dir) = tmp;
+		      i = 0;
 		    }
+		  else
+		    {
+		      LW6SYS_FREE (tmp);
+		    }
+		  tmp = lw6sys_path_parent (parent);
+		  LW6SYS_FREE (parent);
+		  parent = tmp;
 		}
-	      LW6SYS_FREE (parent1);
 	    }
+	  if (parent)
+	    {
+	      LW6SYS_FREE (parent);
+	      parent = NULL;
+	    }
+
 	  if (!lw6sys_dir_exists (*dir))
 	    {
 	      tmp = lw6sys_path_concat (lw6sys_build_get_package_id (), sub);
@@ -606,56 +577,36 @@ static void
 file_if_not_found (char **file, const char *sub)
 {
   char *tmp = NULL;
-  char *parent1 = NULL;
-  char *parent2 = NULL;
-  char *parent3 = NULL;
+  char *parent = NULL;
+  int i = 0;
 
   if (file && *file && !lw6sys_file_exists (*file))
     {
-      parent1 = lw6sys_path_parent (".");
-      if (parent1)
+      parent = lw6sys_path_parent (".");
+      for (i = _FILE_IF_NOT_FOUND_NB_PARENTS; i > 0; --i)
 	{
-	  tmp = lw6sys_path_concat (parent1, sub);
-	  if (lw6sys_file_exists (tmp))
+	  if (parent)
 	    {
-	      LW6SYS_FREE (*file);
-	      (*file) = tmp;
-	    }
-	  else
-	    {
-	      LW6SYS_FREE (tmp);
-	      parent2 = lw6sys_path_parent (parent1);
-	      if (parent2)
+	      tmp = lw6sys_path_concat (parent, sub);
+	      if (lw6sys_file_exists (tmp))
 		{
-		  tmp = lw6sys_path_concat (parent2, sub);
-		  if (lw6sys_file_exists (tmp))
-		    {
-		      LW6SYS_FREE (*file);
-		      (*file) = tmp;
-		    }
-		  else
-		    {
-		      LW6SYS_FREE (tmp);
-		      parent3 = lw6sys_path_parent (parent2);
-		      if (parent3)
-			{
-			  tmp = lw6sys_path_concat (parent3, sub);
-			  if (lw6sys_file_exists (tmp))
-			    {
-			      LW6SYS_FREE (*file);
-			      (*file) = tmp;
-			    }
-			  else
-			    {
-			      LW6SYS_FREE (tmp);
-			    }
-			  LW6SYS_FREE (parent3);
-			}
-		    }
-		  LW6SYS_FREE (parent2);
+		  LW6SYS_FREE (*file);
+		  (*file) = tmp;
+		  i = 0;
 		}
+	      else
+		{
+		  LW6SYS_FREE (tmp);
+		}
+	      tmp = lw6sys_path_parent (parent);
+	      LW6SYS_FREE (parent);
+	      parent = tmp;
 	    }
-	  LW6SYS_FREE (parent1);
+	}
+      if (parent)
+	{
+	  LW6SYS_FREE (parent);
+	  parent = NULL;
 	}
       if (!lw6sys_file_exists (*file))
 	{
@@ -1404,7 +1355,7 @@ lw6sys_get_prefix (int argc, const char *argv[])
  * @argc: argc, number of arguments, as given to @main
  * @argv: argv, pointer to arguments, as given to @main
  *
- * Returns the mod dir (modules, shared .so), 
+ * Returns the mod dir (modules, shared .so),
  * taking in account command-line and
  * environment variables. However config file content has no impact
  * on the result.
