@@ -111,6 +111,12 @@ typedef char *char_ptr_t;
 #define LW6SYS_EXIT_ERROR 1
 #define LW6SYS_EXIT_CRITICAL 2
 
+#ifdef LW6_UNIX
+#define LW6SYS_TRAP_ERRORS_DEFAULT 0
+#else // LW6_UNIX
+#define LW6SYS_TRAP_ERRORS_DEFAULT 1
+#endif // LW6_UNIX
+
 /*
  * Yet another MS-windows hack, printf %ll doesn't work
  * one needs to use a special "%I64" instead...
@@ -135,6 +141,7 @@ typedef char *char_ptr_t;
 #define LW6SYS_TEST_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_NOTICE,_("running tests in function \"%s\""),__FUNCTION__); }
 #define LW6SYS_TEST_FUNCTION_END_NO_CUNIT { if (ret) { lw6sys_log(LW6SYS_LOG_NOTICE,_("tests OK in function \"%s\""),__FUNCTION__); } else { lw6sys_log(LW6SYS_LOG_WARNING,_("tests FAILED in function \"%s\""),__FUNCTION__); } }
 #define LW6SYS_TEST_FUNCTION_END { if (ret) { lw6sys_log(LW6SYS_LOG_NOTICE,_("tests OK in function \"%s\""),__FUNCTION__); } else { lw6sys_log(LW6SYS_LOG_WARNING,_("tests FAILED in function \"%s\""),__FUNCTION__); } _test_data.ret=_test_data.ret && ret; CU_ASSERT_EQUAL(ret, 1); }
+#define LW6SYS_TEST_ACK(value) ( CU_assertImplementation(!!(value), __LINE__, #value, __FILE__, "", CU_FALSE) )
 #define LW6SYS_BACKEND_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("begin backend function \"%s\""),__FUNCTION__); }
 #define LW6SYS_BACKEND_FUNCTION_END { lw6sys_log(LW6SYS_LOG_DEBUG,_("end backend function \"%s\""),__FUNCTION__); }
 
@@ -201,13 +208,13 @@ typedef struct lw6sys_xyz_s
 lw6sys_xyz_t;
 
 /**
- * Contains the shape of a 3D box. There are 3 differences with its 
+ * Contains the shape of a 3D box. There are 3 differences with its
  * "XYZ" equivalent. First, sometimes w*h*d reads better than x,y,z.
  * Then, xyz is signed, whd is unsigned. Finally, these are real
- * int32 values, they are not 14-bit limited. 
- * It does not really cost any memory for it's usually used as 
- * a single "shape" attribute for a whole map. At the same time, 
- * it's very often used as a test value in loops, so it's interesting 
+ * int32 values, they are not 14-bit limited.
+ * It does not really cost any memory for it's usually used as
+ * a single "shape" attribute for a whole map. At the same time,
+ * it's very often used as a test value in loops, so it's interesting
  * to have it in a value that's easy to optimize for the compiler
  * (exactly one register...)
  */
@@ -366,7 +373,7 @@ typedef struct lw6sys_assoc_s
    * will be called on deletion.
    */
   lw6sys_free_func_t free_func;
-  /** 
+  /**
    * Pointer on the next item, will be NULL on last element,
    * there's a difference between a NULL pointer and a valid
    * assoc with only one item being EOL.
@@ -466,7 +473,7 @@ typedef struct lw6sys_list_s
    * will be called on deletion.
    */
   lw6sys_free_func_t free_func;
-  /** 
+  /**
    * Pointer on the next item, will be NULL on last element,
    * there's a difference between a NULL pointer and a valid
    * list with only one item being EOL. Other way to state it:
@@ -476,8 +483,8 @@ typedef struct lw6sys_list_s
 }
 lw6sys_list_t;
 
-typedef int (*lw6sys_sort_callback_func_t) (lw6sys_list_t ** list_a,
-					    lw6sys_list_t ** list_b);
+typedef int (*lw6sys_sort_callback_func_t) (const lw6sys_list_t ** list_a,
+					    const lw6sys_list_t ** list_b);
 
 /**
  * The hexa (for hexadecimal) serializer is a tool used
@@ -801,9 +808,9 @@ extern void lw6sys_checksum_update_int32 (u_int32_t * checksum,
 extern void lw6sys_checksum_update_int64 (u_int32_t * checksum,
 					  int64_t value);
 extern void lw6sys_checksum_update_whd (u_int32_t * checksum,
-					lw6sys_whd_t * whd);
+					const lw6sys_whd_t * whd);
 extern void lw6sys_checksum_update_xyz (u_int32_t * checksum,
-					lw6sys_xyz_t * xyz);
+					const lw6sys_xyz_t * xyz);
 
 /* sys-color.c */
 extern u_int8_t lw6sys_color_float2char (float f);
@@ -1071,6 +1078,8 @@ extern float lw6sys_math_angle_360 (int x, int y);
 extern float lw6sys_math_heartbeat (int64_t x, int period, float y1,
 				    float y2);
 extern int lw6sys_math_blink (int64_t x, int period);
+extern float lw6sys_math_lin2log (int lin_value, int base);
+extern int lw6sys_math_log2lin (float log_value, int base);
 
 /* sys-mem.c */
 #ifdef LW6_OPTIMIZE
@@ -1225,10 +1234,11 @@ extern void lw6sys_serialize_int16 (unsigned char *data, int16_t value);
 extern int16_t lw6sys_unserialize_int16 (unsigned char *data);
 
 /* sys-shape.c */
-extern int lw6sys_shape_check_min_max_whd (lw6sys_whd_t * shape,
-					   lw6sys_whd_t * min,
-					   lw6sys_whd_t * max);
-extern int lw6sys_shape_check_pos (lw6sys_whd_t * shape, lw6sys_xyz_t * pos);
+extern int lw6sys_shape_check_min_max_whd (const lw6sys_whd_t * shape,
+					   const lw6sys_whd_t * min,
+					   const lw6sys_whd_t * max);
+extern int lw6sys_shape_check_pos (const lw6sys_whd_t * shape,
+				   const lw6sys_xyz_t * pos);
 extern int lw6sys_shape_is_same (const lw6sys_whd_t * shape_a,
 				 const lw6sys_whd_t * shape_b);
 extern int lw6sys_shape_is_same_xy (const lw6sys_whd_t * shape_a,
@@ -1248,18 +1258,18 @@ extern void lw6sys_signal_send_quit ();
 extern int lw6sys_signal_poll_quit ();
 
 /* sys-sort.c */
-extern int lw6sys_sort_int_callback (lw6sys_list_t ** list_a,
-				     lw6sys_list_t ** list_b);
-extern int lw6sys_sort_int_desc_callback (lw6sys_list_t ** list_a,
-					  lw6sys_list_t ** list_b);
-extern int lw6sys_sort_float_callback (lw6sys_list_t ** list_a,
-				       lw6sys_list_t ** list_b);
-extern int lw6sys_sort_float_desc_callback (lw6sys_list_t ** list_a,
-					    lw6sys_list_t ** list_b);
-extern int lw6sys_sort_str_callback (lw6sys_list_t ** list_a,
-				     lw6sys_list_t ** list_b);
-extern int lw6sys_sort_str_desc_callback (lw6sys_list_t ** list_a,
-					  lw6sys_list_t ** list_b);
+extern int lw6sys_sort_int_callback (const lw6sys_list_t ** list_a,
+				     const lw6sys_list_t ** list_b);
+extern int lw6sys_sort_int_desc_callback (const lw6sys_list_t ** list_a,
+					  const lw6sys_list_t ** list_b);
+extern int lw6sys_sort_float_callback (const lw6sys_list_t ** list_a,
+				       const lw6sys_list_t ** list_b);
+extern int lw6sys_sort_float_desc_callback (const lw6sys_list_t ** list_a,
+					    const lw6sys_list_t ** list_b);
+extern int lw6sys_sort_str_callback (const lw6sys_list_t ** list_a,
+				     const lw6sys_list_t ** list_b);
+extern int lw6sys_sort_str_desc_callback (const lw6sys_list_t ** list_a,
+					  const lw6sys_list_t ** list_b);
 extern void lw6sys_sort (lw6sys_list_t ** list,
 			 lw6sys_sort_callback_func_t sort_func);
 
@@ -1299,6 +1309,8 @@ extern char *lw6sys_str_join (lw6sys_list_t * list, const char *glue);
 extern void lw6sys_str_toupper (char *str);
 extern void lw6sys_str_tolower (char *str);
 extern void lw6sys_str_truncate (char *str, int len);
+extern void lw6sys_str_truncate_middle (char *str, int len,
+					const char *middle);
 extern char *lw6sys_str_random (int len);
 extern char *lw6sys_str_random_words (int len);
 extern char *lw6sys_str_random_word (int len);
@@ -1323,6 +1335,8 @@ extern lw6sys_thread_handler_t
 			  void *callback_data);
 extern int lw6sys_thread_is_callback_done (lw6sys_thread_handler_t *
 					   thread_handler);
+extern int lw6sys_thread_wait_callback_done (lw6sys_thread_handler_t *
+					     thread_handler);
 extern int lw6sys_thread_get_id (lw6sys_thread_handler_t * thread_handler);
 extern void *lw6sys_thread_get_data (lw6sys_thread_handler_t *
 				     thread_handler);
