@@ -476,7 +476,7 @@ _lw6tsk_loader_poll (_lw6tsk_loader_data_t * loader_data)
 
 /**
  * lw6tsk_loader_push_ldr
- * 
+ *
  * @loader: loader object
  * @map_path: map-path config entry
  * @relative_path: relative map path
@@ -525,7 +525,7 @@ lw6tsk_loader_push_ldr (lw6tsk_loader_t * loader, const char *map_path,
 
 /**
  * lw6tsk_loader_push_gen
- * 
+ *
  * @loader: loader object
  * @seed: seed string used to create the map
  * @display_w: display width
@@ -534,7 +534,7 @@ lw6tsk_loader_push_ldr (lw6tsk_loader_t * loader, const char *map_path,
  * @magic_number: used to calibrate speed
  *
  * Pushes a load request to the loader. Will stop the current
- * load and push a new one. The request is forwarded to the 
+ * load and push a new one. The request is forwarded to the
  * pseudo-random map generation module.
  *
  * Return value: none.
@@ -571,6 +571,7 @@ lw6tsk_loader_push_gen (lw6tsk_loader_t * loader, const char *seed,
  * @level: loaded level (out param)
  * @game_struct: loaded struct (out param)
  * @game_state: loaded state (out param)
+ * @bench_value: the bench_value used (out param)
  * @loader: loader object
  *
  * Pops data from the loader, will allocate everything dynamically.
@@ -578,14 +579,14 @@ lw6tsk_loader_push_gen (lw6tsk_loader_t * loader, const char *seed,
  * game state (3 of them together). It's safe to use the received
  * level, display it right away, then wait for the rest. If things
  * are loaded fast enough, you just receive everything at once.
- * 
+ *
  * Return value: 1 if some data, 0 if none.
  */
 int
 lw6tsk_loader_pop (lw6map_level_t ** level,
 		   lw6ker_game_struct_t ** game_struct,
 		   lw6ker_game_state_t ** game_state,
-		   lw6tsk_loader_t * loader)
+		   int *bench_value, lw6tsk_loader_t * loader)
 {
   int ret = 0;
   _lw6tsk_loader_data_t *loader_data;
@@ -606,6 +607,10 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
     {
       (*game_state) = NULL;
     }
+  if (bench_value)
+    {
+      (*bench_value) = 0;
+    }
 
   if (level)
     {
@@ -627,6 +632,10 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
 	  loader_data->stage2.level = NULL;	// do not free!
 	  loader_data->stage2.game_struct = NULL;	// do not free!
 	  loader_data->stage2.game_state = NULL;	// do not free!
+	  if (bench_value)
+	    {
+	      (*bench_value) = loader_data->stage1.bench_value;
+	    }
 	  ret = 1;
 	}
     }
@@ -644,7 +653,7 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
  * try and identify the objects in their on per-process lists,
  * structures, Guile object, whatever they use.
  */
-static u_int32_t seq_id = 0;
+static volatile u_int32_t seq_id = 0;
 
 static void
 loader_data_free (_lw6tsk_loader_data_t * loader_data)
@@ -802,7 +811,7 @@ lw6tsk_loader_free (lw6tsk_loader_t * loader)
  * Return value: a dynamically allocated pointer, must be freed.
  */
 char *
-lw6tsk_loader_repr (lw6tsk_loader_t * loader)
+lw6tsk_loader_repr (const lw6tsk_loader_t * loader)
 {
   char *ret = NULL;
   _lw6tsk_loader_data_t *loader_data;
